@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: command.tcl
-#  Last change:  14 May 2007
+#  Last change:  25 September 2008
 #
 
 # this file is only source-ed in command-line mode (even if the graphical
@@ -80,12 +80,14 @@ proc ExecCommand {} {
 	    }
 	}
 	translate {
+	    CmdSetTranslateParams $COMMAND(params)
 	    if { [CmdReadFails $COMMAND(infmt) $COMMAND(inpath) \
 		               $COMMAND(in,params) $COMMAND(intypes)] || \
 		    [CmdWriteFails $COMMAND(format) $COMMAND(path) \
 			          $COMMAND(out,params) $COMMAND(filetypes)] } {
 		return 1
 	    }
+	    CmdRestoreTranslation
 	}
 	getrtimelog {
 	    if { [CmdCantStartRTimeLog Ignore Ignore] || \
@@ -147,7 +149,7 @@ proc ExecCommand {} {
 	    }
 	    set fmt $COMMAND(format)
 	    set ix [expr $Number($type)-1]
-	    set mdate pict
+	    set mdate pict ; set dhour 0
 	    if { $fmt == "GPX" } {
 		set datum "WGS 84"
 	    } else { set datum $Datum }
@@ -164,6 +166,9 @@ proc ExecCommand {} {
 		    date {
 			set mdate $rhs
 		    }
+		    dh {
+			set dhour $rhs
+		    }
 		    datum {
 			if { [EllipsdOf $rhs] == "" } {
 			    GMMessage "$MESS(unkndatum): $rhs"
@@ -186,7 +191,7 @@ proc ExecCommand {} {
 		    }
 		}
 	    }
-	    if { [set lts [GetFilesDates $pcs $mdate]] == "" || \
+	    if { [set lts [GetFilesDates $pcs $mdate $dhour]] == "" || \
 		     [set lts [GeoAdapt $type $ix $datum $lts]] == "" } {
 		GMMessage $MESS(missingdata)
 		return 1
@@ -198,6 +203,7 @@ proc ExecCommand {} {
 	    }
 	}
 	source {
+	    # file is assumed to be in system encoding
 	    if { [catch {source $COMMAND(path)}] } { return 1 }
 	    return wait
 	}
@@ -383,7 +389,7 @@ proc CmdReadFails {fmt path pars types} {
     # if  $path==stdin  use standard input unless $fmt is Shapefile in which
     #  case return failure
     # return 0 on success
-    global FILEFORMAT
+    global FILEFORMAT File
 
     if { [CmdProcParamsFails $fmt $pars] } { return 1 }
     switch -glob $fmt {
@@ -407,6 +413,7 @@ proc CmdReadFails {fmt path pars types} {
 	    } else { set cr 0 }
 	    if { [set f [CmdOpenFile $path in]] == -1 } { return 1 }
 	    InitInputFileVars $f $wh $cr 0
+	    set File($wh) $path
 	    if { [catch {set r [ImportFileFrom $f $wh $fmt]}] || $r == 1 } {
 		return 1
 	    }
@@ -426,7 +433,10 @@ proc CmdWriteFails {fmt path pars types} {
     switch -glob $fmt {
 	GPSMan {
 	    if { [set f [CmdOpenFile $path out]] == -1 } { return 1 }
-	    if { [llength $FILEFORMAT(GPSMan,types)] == [llength $types] } {
+	    if { [catch {set fts $FILEFORMAT(GPSMan,types)}] } {
+		set fts [lindex $FILEFORMAT(GPSMan,io_types) 1]
+	    }
+	    if { [llength $fts] == [llength $types] } {
 		if { [catch {SaveFileTo $f all Data}] } { return 1 }
 	    } else {
 		foreach t $types {
@@ -487,6 +497,41 @@ proc CmdProcParamsFails {fmt pars} {
     return 0
 }
 
+proc CmdSetTranslateParams {pars} {
+    # set globals for the translation
+    global CmdSAVED
+
+    foreach "p val" $pars {
+	switch -- $p {
+	    itoffset {
+		global FromTimeOffset
+		set CmdSAVED(FromTimeOffset) $FromTimeOffset
+		set FromTimeOffset $val
+	    }
+	    otoffset {
+		global TimeOffset
+		set CmdSAVED(TimeOffset) $TimeOffset
+		set TimeOffset $val
+	    }
+	}
+    }
+    return
+}
+
+proc CmdRestoreTranslation {} {
+    # restore any globals changed for the translation
+    global CmdSAVED
+
+    if { [info exists CmdSAVED] } {
+	foreach g [array names CmdSaved] {
+	    global $g
+	    set g $CmdSaved($g)
+	}
+	unset CmdSAVED
+    }
+    return
+}
+
 proc CmdRTimeDumpFails {path} {
     # start dumping real-time log continuously
     # return 0 on success
@@ -547,18 +592,21 @@ proc CmdShow {what} {
 		    in  $TXT(fread) \
 		    out $TXT(fwrite) \
 		    {in out} $TXT(fread)/$TXT(fwrite)]
-	    foreach p [lsort -dictionary [array names FILEFORMAT *,mode]] {
-		regsub {,mode$} $p "" f
+	    foreach f $FILEFORMAT(names) {
 		if { ! [catch {set dep $FILEFORMAT($f,depends)}] && \
 			! [eval $dep] } {
 		    puts "$f:\t$MESS(shpwrongfile)"
 		    continue
 		}
-		set m $mode($FILEFORMAT($p))
-		puts -nonewline "$f:\t$m, $FILEFORMAT($f,types)"
+		set m $mode($FILEFORMAT($f,mode))
 		if { [set t $FILEFORMAT($f,filetype)] == "data" } {
-		    puts ", $TXT(nameData)"
-		} else { puts "" }
+		    set suff " $TXT(nameData)"
+		} else { set suff "" }
+		if { [catch {set ts $FILEFORMAT($f,types)}] } {
+		    foreach "its ots" $FILEFORMAT($f,io_types) { break }
+		    puts "$f:\t$mode(in)\t $its$suff"
+		    puts "\t$mode(out)\t $ots$suff"
+		} else { puts "$f:\t$m\t $FILEFORMAT($f,types)$suff" }
 		set t 1
 		foreach how "in out" {
 		    if { ! [catch {set params $FILEFORMAT($f,$how,params)}] } {
