@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: command_parse.tcl
-#  Last change:  26 May 2007
+#  Last change:  25 September 2008
 #
 
 # this file is only source-ed in command-line mode
@@ -42,8 +42,13 @@ set COMMAND(USAGE) {Usage: gpsman [PREFIXES] COMMAND [ARGS]
     haslib gpsmanshp | Img
     getwrite IN-TYPES FORMAT [OUT-PARAMS] [OUT-TYPES] PATH
     readput FORMAT [IN-PARAMS] [IN-TYPES] PATH [OUT-TYPES]  (-rec not allowed!)
-    translate IN-FORMAT [IN-PARAMS] [IN-TYPES] IN-PATH \
-              OUT-FORMAT [OUT-PARAMS] [OUT-TYPES] OUT-PATH
+    translate IN-FORMAT [IN-PARAMS] [IN-TYPES] IN-PATH [HOW-PARAMS] \
+	 OUT-FORMAT [OUT-PARAMS] [OUT-TYPES] OUT-PATH
+           where HOW-PARAMS can be
+            itoffset=DHOUR: time offset to use in input file in GPSMan format,
+              defaults to time offset given in file
+            otoffset=DHOUR: time offset to use in output file in GPSMan format
+              defaults to time offset selected in the options
     getrtimelog PATH [INTERVAL]
     getfix PATH [TIMEOUT]
     getalmanac PATH
@@ -56,9 +61,11 @@ set COMMAND(USAGE) {Usage: gpsman [PREFIXES] COMMAND [ARGS]
 	 [OUT-FORMAT] [OUT-PARAMS] OUT-PATH PICT-PATHS
 	   where
 	    IN-TYPE: TR | GR (for WPs in GR)
-            PROC-PARAMS: [id=ID] [date=DMODE]
+            PROC-PARAMS: [id=ID] [date=DMODE] [dh=DHOUR]
              ID: identifier of item in data file, default is last read
-             DMODE: pict|fmod   date from EXIF (default), or file modified time
+             DMODE: pict|exif|fmod   date from picture EXIF (default), EXIF
+               file, or file last modified time
+             DHOUR: difference in hours to apply to file dates to get TR dates
 	    OUT-FORMAT: GPX
 	    OUT-PARAMS may include: datum=DATUM sy=SYMBOL prefix=STRING
                STRING: is prefix for WP names, default is P
@@ -265,8 +272,9 @@ proc BadCommandLine {} {
 	    set COMMAND(rectypes) $out_ts
 	}
 	translate {
-	    # IN-FORMAT [IN-PARAMS] [IN-TYPES] IN-PATH OUT-FORMAT \
-            #    [OUT-PARAMS] [OUT-TYPES] OUT-PATH
+	    # IN-FORMAT [IN-PARAMS] [IN-TYPES] IN-PATH [HOW-PARAMS]
+	    #  OUT-FORMAT [OUT-PARAMS] [OUT-TYPES] OUT-PATH
+	    # see proc CmdBadTranslateHowParams for HOW-PARAMS
 	    if { $nargs < 4 } {
 		puts stderr "Missing arguments"
 		return 1
@@ -278,13 +286,21 @@ proc BadCommandLine {} {
 		puts stderr "Missing input path"
 		return 1
 	    }
-	    if { [CmdFileFmtParamsTypes in $infmt $in_ps $in_ts] == 0 || \
-		     [set outfmt [CmdFFormat [lindex $tail 1]]] == "" } {
+	    if { [CmdFileFmtParamsTypes in $infmt $in_ps $in_ts] == 0 } {
 		return 1
 	    }
 	    set COMMAND(infmt) $COMMAND(format)
+	    set tail [lreplace $tail 0 0]
+	    foreach "params tail" [CmdParseParams $tail] { break }
+	    if { [set outfmt [CmdFFormat [lindex $tail 0]]] == "" || \
+		     [set params \
+			  [CmdBadTranslateHowParams $params $infmt $outfmt]] \
+		     == 0 } {
+		return 1
+	    }
+	    set COMMAND(params) $params
 	    foreach "out_ps out_ts tail" \
-		[CmdParseParamsTypes [lreplace $tail 0 1]] {}
+		[CmdParseParamsTypes [lreplace $tail 0 0]] {}
 	    if { $out_ts == "" } { set out_ts $COMMAND(filetypes) }
 	    set COMMAND(intypes) $COMMAND(filetypes)
 	    if { [llength $tail] != 1 } {
@@ -402,7 +418,7 @@ proc BadCommandLine {} {
 	    # IMGPATH TRANSF LATD LONGD LATD LONGD [LATD LONGD] DATUM
 	    #   X Y X Y [X Y] PROJ [PARAMS]
 	    # making only a preliminary check on the correction of the
-	    #  arguments as projections.tcl was not yet loaded
+	    #  arguments as projections.tcl is not yet loaded
 	    set COMMAND(image) [lindex $argv 0]
 	    set COMMAND(transf) [set tr [lindex $argv 1]]
 	    if { $nargs < 12 } {
@@ -804,31 +820,43 @@ proc CmdFileFmtParamsTypes {how fmt pars ts args} {
 	return 0
     }
     # check types
-    set fts $FILEFORMAT($fmt,types)
+    if { [catch {set fts $FILEFORMAT($fmt,types)}] } {
+	if { $how == "in" } {
+	    set e 0
+	} else { set e 1 }
+	set fts [lindex $FILEFORMAT($fmt,io_types) $e]
+    }
     switch $FILEFORMAT($fmt,filetype) {
 	unique {
 	    if { $ts != "" && $ts != "all" && $ts != $fts } {
+		puts stderr "Bad type(s) $ts; should be $fts"
 		return 0
 	    }
 	}
 	single {
 	    if { $ts == "all" || [llength $ts] != 1 || \
-		    [lsearch -exact $fts $ts] == -1 } { return 0 }
+		    [lsearch -exact $fts $ts] == -1 } {
+		puts stderr "Bad type(s) $ts; should be one of $fts"
+		return 0
+	    }
 	    set fts $ts
 	}
 	data {
 	    if { $ts != "" && $ts != "all" } {
 		set fs ""
 		foreach f $ts {
-		    if { [lsearch -exact $fts $f] == -1 } { return 0 }
+		    if { [lsearch -exact $fts $f] == -1 } {
+			puts stderr "Bad type(s) $ts; cannot contain $f"
+			return 0
+		    }
 		    lappend fs $f
 		}
 		set fts $fs
 	    }
 	}
     }
-    if { [lsearch -exact $fts LAP] != -1 && ! $SUPPORTLAPS } {
-	return 0
+    if { [set ix [lsearch -exact $fts LAP]] != -1 && ! $SUPPORTLAPS } {
+	set fts [lreplace $fts $ix $ix]
     }
     if { $args != "" } {
 	foreach t $fts {
@@ -860,17 +888,49 @@ proc CmdIncompatibleTypes {in_ts out_ts} {
     return 0
 }
 
+proc CmdBadTranslateHowParams {pps infmt outfmt} {
+    # check the transformation parameters of the translate command that may
+    #  impose constraints on the input- and output-formats
+    # HOW-PARAMS can be
+    #   itoffset=DHOUR: time offset to use in input file in GPSMan format,
+    #      defaults to time offset given in file
+    #   otoffset=DHOUR: time offset to use in output file in GPSMan format
+    #      defaults to time offset selected in the options
+    # return 0 on error or list with transformation parameters if any
+
+    set tprs ""
+    foreach "lhs rhs" $pps {
+	switch -- $lhs {
+	    itoffset -  otoffset {
+		if { [catch {set bad [expr abs($rhs) > 14]}] } {
+		    puts stderr "Bad time offset in: $lhs=$rhs"
+		    return 0
+		}
+		if { $infmt != "GPSMan" || $outfmt != "GPSMan" } {
+		    puts stderr "Time offset changes only in GPSMan files"
+		    return 0
+		}
+	    }
+	}
+	lappend tprs $lhs $rhs
+    }
+    return $tprs
+}
+
 proc CmdBadGeoPictsParams {pps outps} {
     # check the processing- and output-parameters of the geopict command
     # the output-parameters may contain paramaters needed by the output format
-    #  PROC-PARAMS: [id=ID] [date=DMODE]
+    #  PROC-PARAMS: [id=ID] [date=DMODE] [dh=DHOUR]
     #     ID: identifier of item in data file, default is last read in
-    #     DMODE: pict | fmod   date from EXIF (default), or file modified time
+    #     DMODE: pict|exif|fmod   date from picture EXIF (default), EXIF
+    #         file, or file last modified time
+    #     DHOUR: difference in hours to apply to file dates to get TR dates
     #  OUT-PARAMS: apart from those needed by $fmt
     #              [datum=DATUM] [sy=SYMBOL] [prefix=STRING]
     #               STRING: defaults to "P"
     # return "error" or pair with list of format parameters and
     #  list with all other parameters
+    global COMMAND
 
     set ops ""
     foreach "lhs rhs" $pps {
@@ -882,11 +942,20 @@ proc CmdBadGeoPictsParams {pps outps} {
 		}
 	    }
 	    date {
-		if { $rhs != "fmod" && $rhs != "pict" } {
-		    puts stderr "Bad mode for date; must be fmod or pict"
+		if { [lsearch -exact {exif fmod pict} $rhs] == -1 } {
+		    puts stderr "Bad mode for date; must be fmod, exif or pict"
 		    return error
 		}
 	    }
+	    dh {
+		if { ! [regexp {^-?[1-9][0-9]?$} $rhs] || abs($rhs) > 23 } {
+		    puts stderr "Bad hour difference; must be integer -23..23"
+		    return error
+		}
+		if { $COMMAND(intypes) != "TR" } {
+		    puts stderr "Hour difference only meaningful with a track"
+		}
+	    }
 	    default {
 		puts stderr "Unknown parameter $lhs"
 		return error
