@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: compute.tcl
-#  Last change:  30 April 2007
+#  Last change:  24 October 2008
 #
 # Includes contributions by
 #  - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
@@ -300,8 +300,9 @@ proc ComputeDist {p1 p2 datum} {
     set lo1 [expr $lod1*0.01745329251994329576]
     set la2 [expr $lad2*0.01745329251994329576]
     set lo2 [expr $lod2*0.01745329251994329576]
-    return [expr 1e-3*[lindex [EllipsdData $datum] 0]* \
-	         acos(cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2))]
+    set x [expr cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2)]
+    if { $x >= 1 } { return 0 }
+    return [expr 1e-3*[lindex [EllipsdData $datum] 0]*acos($x)]
 }
 
 proc ComputeBear {p1 p2 datum} {
@@ -354,8 +355,10 @@ proc ComputeDistBear {p1 p2 datum} {
     set lo2 [expr $lod2*0.01745329251994329576]
     set a [lindex [EllipsdData $datum] 0]
            # distance (km)
-    set d [expr 1e-3*$a*acos(cos($lo1-$lo2)*cos($la1)*cos($la2)+ \
-	                 sin($la1)*sin($la2))]
+    set x [expr cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2)]
+    if { $x < 1 } {
+	set d [expr 1e-3*$a*acos($x)]
+    } else { set d 0 }
            # bearing
     set da [expr $la2-$la1] ; set do [expr $lo2-$lo1]
     if { [expr abs($da)] < 1e-20 } {
@@ -406,8 +409,9 @@ proc ComputeDistFD {p1 p2} {
     set lo1 [expr $lod1*0.01745329251994329576]
     set la2 [expr $lad2*0.01745329251994329576]
     set lo2 [expr $lod2*0.01745329251994329576]
-    return [expr 1e-3*$DatumA*acos(cos($lo1-$lo2)*cos($la1)*cos($la2)+ \
-	                      sin($la1)*sin($la2))]
+    set x [expr cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2)]
+    if { $x >= 1 } { return 0 }
+    return [expr 1e-3*$DatumA*acos($x)]
 }
 
 proc ComputeDistBearFD {p1 p2} {
@@ -425,8 +429,10 @@ proc ComputeDistBearFD {p1 p2} {
     set la2 [expr $lad2*0.01745329251994329576]
     set lo2 [expr $lod2*0.01745329251994329576]
            # distance (km)
-    set d [expr 1e-3*$DatumA*acos(cos($lo1-$lo2)*cos($la1)*cos($la2)+ \
-	                 sin($la1)*sin($la2))]
+    set x [expr cos($lo1-$lo2)*cos($la1)*cos($la2)+sin($la1)*sin($la2)]
+    if { $x < 1 } {
+	set d [expr 1e-3*$DatumA*acos($x)]
+    } else { set d 0 }
            # bearing
     set da [expr $la2-$la1] ; set do [expr $lo2-$lo1]
     if { [expr abs($da)] < 1e-20 } {
@@ -684,7 +690,7 @@ proc ChangeLPsDatum {lps odatum datum pformt} {
 
     if { $odatum == $datum } { return $lps }
     if { [set gd [BadDatumFor $pformt $datum Ignore]] != 0 } {
-	GMMessage [format $MESS(cantchggriddatum) $gdatum]
+	GMMessage [format $MESS(cantchggriddatum) $gd]
 	return -1
     }
     set l ""
