@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,15 +17,17 @@
 #      along with this program.
 #
 #  File: config.tcl
-#  Last change:  25 July 2006
+#  Last change:  7 May 2008
 #
 
 ## the following values can be set from the options dialog of the interface
 
- # language: see lang*.tcl files, ALLMONTH array below, main.tcl KNOWNLANGS
+ # language: see lang*.tcl files, the ENCODED array in metadata.tcl, the
+    #   language names and the ALLMONTH array in i18n-utf8.tcl, and the
+    #   KNOWNLANGS list in main.tcl
     # currently available: engl for English, port for Portuguese, deutsch for
     #   German, it for Italian, fr for French, nl for Dutch, id for Indonesian,
-    #   es for Spanish
+    #   es for Spanish, ru for Russian
 
 set LANG engl
 
@@ -91,6 +93,9 @@ set DEFAULTSYMBOL WP_dot
     #  and symbol display options (GPSMan convention; see symbols.tcl)
 set DEFAULTDISPOPT s_name
 
+  # default for whether items read from a file should be displayed on map
+set SHOWFILEITEMS 0
+
   # default line widths for routes, tracks and lines
 set DEFTRTWIDTH 2
 set DEFTTRWIDTH 2
@@ -295,21 +300,6 @@ set PAGEWIDTH(b4) 250m ; set PAGEHEIGHT(b4) 353m
 set PAGEWIDTH(b5) 176m ; set PAGEHEIGHT(b5) 250m
 set PAGEWIDTH(letter) 211m ; set PAGEHEIGHT(letter) 279m
 
-  # possible abbreviations for months in all known languages
-  # English abbreviations must not be deleted
-set ALLMONTH(1) "Jan Gen jan Ene"
-set ALLMONTH(2) "Feb Fev feb"
-set ALLMONTH(3) "Mar Mr mrt"
-set ALLMONTH(4) "Apr Abr Avr apr"
-set ALLMONTH(5) "May Mai Mag mei Mei"
-set ALLMONTH(6) "Jun Giu jun"
-set ALLMONTH(7) "Jul Lug jul"
-set ALLMONTH(8) "Aug Ago Aou aug Agt"
-set ALLMONTH(9) "Sep Set sep"
-set ALLMONTH(10) "Oct Okt Out Ott okt"
-set ALLMONTH(11) "Nov nov Nop"
-set ALLMONTH(12) "Dec Dez Dic dec Des"
-
   # output formats (in Tcl/Tk syntax, similar to C) for floating-point
   #  coordinates in seconds, minutes, degrees, and grades
   # changes here will not increase the data accuracy!
