@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,14 +17,15 @@
 #      along with this program.
 #
 #  File: elevation.tcl
-#  Last change:  7 September 2006
+#  Last change:  14 August 2008
 #
 # This file contains mostly code contributed by Alessandro Palmas
-#   (alpalmas@tin.it)
+#   (alpalmas _AT_ tin.it)
 #
 # Includes contributions by
 #   - Miguel Filgueiras marked "MF change"/"MF contribution"
-#   - Martin Buck (m@rtin-buck.de) marked "MB contribution"
+#   - Martin Buck (m _AT_ rtin-buck.de) marked "MB contribution"
+#   - Benoit Steiner (benetsteph _AT_ free.fr) marked "BS contribution"
 #
 
 proc GMRTHgraph {w} {
@@ -42,7 +43,8 @@ proc GMRTHgraph {w} {
 	set tmpname [$frb.frbx.box get $i];# get the wp name of ith WP
 	set tmpwpindex [IndexNamed WP $tmpname];# get its index (-1 if undef)
 	if { $tmpwpindex >= 0 } { set alTot $WPAlt($tmpwpindex) }
-	lappend lll [list $dbTot $alTot]
+	# MF change: added start segment flag
+	lappend lll [list $dbTot $alTot 0]
 	# since each leg gives the distance to the next wp, we must save the
 	# current dbtot to be associated to next wp
 	set dbTot [expr $dbTot + $tmp2]
@@ -51,7 +53,8 @@ proc GMRTHgraph {w} {
     set tmpname [$frb.frbx.box get $tmp];# get the wp name of ith WP
     set tmpwpindex [IndexNamed WP $tmpname];# get its index (-1 if undef)
     if { $tmpwpindex >= 0 } { set alTot $WPAlt($tmpwpindex) }
-    lappend lll [list $dbTot $alTot]
+    # MF change: added start segment flag
+    lappend lll [list $dbTot $alTot 0]
     # MF change: added type argument
     Hgraph $lll elevation
     return
@@ -102,19 +105,28 @@ proc Hrescale {c newwidth newheight} {
 
 proc Hgraph {k what args} {
     # MF contribution
+    #  - when plotting altitudes, $k is now a list of triples with
+    #   distance or time, altitude, and a start segment flag; this
+    #   flag is used to interrupt the plot
     #  - added new arguments:
     #    $what in {elevation, climbrate, speed}
     #    $args either void or "time" for a time axis in which case $k
-    #      is a list of pairs with seconds and y value
+    #      is a either list of pairs with seconds and speed, or
+    #      a list of triples with seconds, altitude, and start segment flag
     #      if $what=="climbrate", $args=="time"
     #  - avoiding problems if window is resized by replacing use of
     #   HGpxwp array by tags in graph lines
     #  - allowing for more than one plot window at the same time
     #  - some simplifications for efficiency
+    #  - using tags and lists with distance/time and altitude for
+    #   retrieving and displaying this information later on
+    #  - button to extend the ticks in the horizontal axis to the top of
+    #   the window and restore them
     #----
     global MESS TXT BITMAP
     # MF contribution
-    global NoImgLib ImgOutFormats DPOSX DPOSY MapWidth MAPH2 PlotWNo
+    global NoImgLib ImgOutFormats DPOSX DPOSY MapWidth MAPH2 PlotWNo \
+	HGinfo
 
     if { $args == "time" } {
 	set totdist 0
@@ -123,7 +135,7 @@ proc Hgraph {k what args} {
 
     # in list k {x y} couples from a track
     # check to have enough points for a graph
-    if {[llength $k] <3} {
+    if { [llength $k] < 3 } {
 	GMMessage $MESS(missingdata)
 	return true
     }
@@ -147,6 +159,9 @@ proc Hgraph {k what args} {
 	set ymin 99999
 	set xmax -99999
 	set ymax -99999
+	# MF contribution: default value for initial time-stamp
+	set secs0 ""
+	#-----
 	# get max amd min of x and y
 	set valids 0
 	if { $totdist } {
@@ -170,9 +185,9 @@ proc Hgraph {k what args} {
 	} else {
 	    # MF contrib
 	    # time axis: x-values replaced by differences from first value
-	    set secs0 "" ; set kk ""
+	    set kk ""
 	    foreach a $k {
-		foreach "x y" $a {}
+		foreach "x y newsegm" $a { break }
 		if { [regexp \
 		      {^ *-?[0-9]+(\.[0-9]+)?([eE]-?[1-9][0-9]*)? *$} $y] && \
 		     [regexp {^ *[0-9]+ *$} $x] } {
@@ -185,7 +200,7 @@ proc Hgraph {k what args} {
 		    if {$y > $ymax} {set ymax $y}
 		    incr valids
 		}
-		lappend kk [list $x $y]
+		lappend kk [list $x $y $newsegm]
 	    }
 	    set k $kk
 	}
@@ -195,7 +210,8 @@ proc Hgraph {k what args} {
 	return
     }
     # the last couple must be wrong to stop (force last print)
-    lappend k {99999 *}
+    # MF change: added segment starter flag
+    lappend k {99999 * 0}
     # now find the right quota lines to plot
     set yexcursion [expr $ymax-$ymin]
     if {$yexcursion > 10000.0} {
@@ -221,11 +237,12 @@ proc Hgraph {k what args} {
 
     #go graphic
     if { [winfo exists $w] } {
-	destroy $w
+	# MF change: using proc HgraphClose
+	HgraphClose $w
     }
     toplevel $w
     # MF contribution: added usual things in other GPSMan toplevels
-    wm protocol $w WM_DELETE_WINDOW "destroy $w"
+    wm protocol $w WM_DELETE_WINDOW "HgraphClose $w"
     wm title $w "$TXT($what)/GPS Manager"
     wm transient $w .
     wm geometry $w +$DPOSX+$DPOSY
@@ -235,7 +252,7 @@ proc Hgraph {k what args} {
     # includes MB contributions (expand and fill options)
     pack $w.gf -expand yes -fill both
 
-    set c [canvas $w.gf.c -height [expr $MY+20] -width $MX \
+    set c [canvas $w.gf.c -height [expr $MY+20] -width [expr $MX+2] \
 	       -highlightthickness 0]
     pack $c -expand yes -fill both
     # MB contribution
@@ -248,8 +265,8 @@ proc Hgraph {k what args} {
     set bf [frame $w.bf]
     pack $bf -side bottom
 
-    set b [button $w.bf.b -text Ok -command "destroy $w"]
-    pack $b
+    # MF change: using proc HgraphClose
+    set b [button $w.bf.b -text Ok -command "HgraphClose $w"]
     # MF change: use of Img lib
     if { $NoImgLib } {
 	set p [button $w.bf.p -text "$TXT(saveto) PS" \
@@ -263,12 +280,20 @@ proc Hgraph {k what args} {
 	    $m add command -label $f -command "SaveCanvas $c {} $f file"
 	}
     }
-    # MF contrib
+    # MF contrib: save canvas and extend/restore ticks in horizontal axis
     button $w.bf.pp -text $TXT(print) \
 		-command "SaveCanvas $w.gf.c {} PS printer"
-    pack $b $p $w.bf.pp -side left
+    button $w.bf.btick -text $TXT(vertgridlines) -command "HgraphVertGrid $w"
+    pack $p $w.bf.pp $w.bf.btick $b -side left
     #----
 
+    # MF contrib
+    # prepare to record information related to tags
+    foreach ix [array names HGinfo $c,*] {
+	unset HGinfo($ix)
+    }
+    set infolist "" ; set infotag 0
+    #----
     # normalize list k
     # and put in z a list of point to plot
     set bad "false"
@@ -277,42 +302,65 @@ proc Hgraph {k what args} {
     set first 1
     foreach a $k {
 	incr count
+	# MF change: getting x, y and start segment flag
+	foreach "x tmp newsegm" $a { break }
 	# extraction of x, with check
-	set x [lindex $a 0]
-	if { ! [regexp \
-		    {^ *-?[0-9]+(\.[0-9]+)?([eE]-?[1-9][0-9]*)? *$} $x] } { \
-            continue
-	}
+	# MF change: merging the tests on x and y in the same if
 	# extraction of y, with check
 	# only the first bad elevation wp is used (start bad zone),
 	#  the others are ignored
-	set tmp [lindex $a 1]
 	if { ! [regexp \
-		    {^ *-?[0-9]+(\.[0-9]+)?([eE]-?[1-9][0-9]*)? *$} $tmp] } { \
-	    if { "$bad" == "false" } {
+		    {^ *-?[0-9]+(\.[0-9]+)?([eE]-?[1-9][0-9]*)? *$} $x] || \
+	       ! [regexp \
+		      {^ *-?[0-9]+(\.[0-9]+)?([eE]-?[1-9][0-9]*)? *$} $tmp] } {
+	    if { $bad == "false" } {
 		set bad "true"
-		if { $z == "" } { continue };#nothing to plot
 		if { [llength $z] < 4 } { continue };#not enough data to plot
-		eval $c create line $z -tags primo=$first
+		# MF contrib: add tag and information list
+		eval $c create line $z -tags {[list primo=$first itg=$infotag]}
+		set HGinfo($c,$infotag) $infolist
+		incr infotag ; set infolist [lrange $infolist end-1 end]
 		set z [lrange $z end-1 end]
-		set first $count
+		set first [expr $count-1]
 	    }
 	} else {
-	    set x [Hnormalize $x $xmin $scalx]
+	    # MF contrib: record information
+	    lappend infolist $x $tmp
+	    #-----
+	    set x [expr int([Hnormalize $x $xmin $scalx])]
 	    set y [Hnormalize $tmp $ymin $scaly]
-	    set y [expr $MY-$y]
+	    set y [expr int($MY-$y)]
 	    if { $bad == "true"} {
 		set bad "false"
-		lappend z [expr int($x)] [expr int($y)]
-		if { $z == "" } { continue }
+		lappend z $x $y
 		if { [llength $z] < 4 } { continue }
-		set item [eval $c create line $z -fill red \
-			      -stipple $BITMAP(brokenline) -tags "profile"]
-		$c addtag primo=$first withtag $item 
+		# MF: add tag and information list
+		eval $c create line $z -fill red -stipple $BITMAP(brokenline) \
+		   -tags {[list profile primo=$first last=$count itg=$infotag]}
+		set HGinfo($c,$infotag) $infolist
+		incr infotag ; set infolist [lrange $infolist end-1 end]
 		set z ""
 		set first $count
+	    } elseif { $newsegm == 1 } {
+		# MF contrib: deal with segment starter
+		if { [llength $z] > 2 } {
+		    # plot line linking previous points
+		    eval $c create line $z \
+			-tags {[list primo=$first itg=$infotag]}
+		    set HGinfo($c,$infotag) [lreplace $infolist end-1 end]
+		    incr infotag ; set infolist [lrange $infolist end-3 end]
+		}
+		# plot broken line between last and current points
+		set x0 [lindex $z end-1] ; set y0 [lindex $z end]
+		$c create line $x0 $y0 $x $y -fill DeepPink \
+		    -stipple $BITMAP(brokenline) \
+                    -tags [list profile primo=[expr $count-1] itg=$infotag]
+		set HGinfo($c,$infotag) $infolist
+		incr infotag ; set infolist [lrange $infolist end-1 end]
+		set z ""
+		set first $count		
 	    }
-	    lappend z [expr int($x)] [expr int($y)]
+	    lappend z $x $y
 	}
     };#foreach
 
@@ -320,6 +368,14 @@ proc Hgraph {k what args} {
 	# measures in climb rate do not correspond to points
 	bind $c <Button-1> "HGtest1 $c %x %y"
 	bind $c <Shift-Button-1> "HGtest2 $c %x %y"
+	# MF change: BS contribution is only for altitudes
+	if { $what == "elevation" } {
+	    # BS contribution:
+	    bind $c <Control-Button-1> \
+		"HGtest3 $c %x %y $totdist [list $secs0]"
+	    #=====
+	}
+	#-----
     }
     ###
 
@@ -345,27 +401,32 @@ proc Hgraph {k what args} {
 	if {$xexcursion > 10000.0} {
 	    set deltax [expr int($xexcursion/4.0)]
 	} else {
-	    foreach mx "5000 2000 1000 500 250 100 50 10 0" \
-		deltax "2000 1000  250 100  50  25 10  5 1" {
+	    foreach mx "5000 2000 1000 500 250 100 50 10 5 2   0" \
+		deltax "2000 1000  250 100  50  25 10  5 1 0.5 0.1" {
 		    if {$xexcursion > $mx } { break }
 		}     	
 	}
 
-	for {set x 0} {$x < $xmax} {incr x [expr $deltax]} {
+	for {set x 0} {$x < $xmax} { set x [expr $x+$deltax] } {
 	    if {($x<$xmax)&&($x>$xmin)} {
 		set tmp [Hnormalize ($x $xmin $scalx)]
 		set tmp [expr int($tmp)]
-		# MF contribution: lowering these items
-		set it \
-		    [$c create line $tmp $MY $tmp [expr $MY - 10] -fill "tan"]
+		# MF contribution: lowering these items and new tag
+		set it [$c create line $tmp $MY $tmp [expr $MY - 10] \
+			    -fill "tan" -tags vgline]
 		$c lower $it
+		# MF contribution: show value
+		set it [$c create text $tmp [expr $MY+5] -anchor n \
+			    -text $x -fill red]
+		$c lower $it
+		#======
 	    }
 	}
     } else {
 	# MF contrib
 	# time axis
-	set secs0 [expr $secs0%86400]
-	set time0 [FormatTime $secs0]
+	set secs0t [expr $secs0%86400]
+	set time0 [FormatTime $secs0t]
 	if { [string length $time0] == 5 } {
 	    set hour0 0 ; scan $time0 %0d:%0d min0
 	    set time0 "00:$time0"
@@ -374,23 +435,26 @@ proc Hgraph {k what args} {
 	}
 	if { [set hrs [expr $xmax/3600]] > 4 } {
 	    # mark only full hours
-	    set xhr0 [set x [expr ($hour0+1)*3600-$secs0]]
+	    set xhr0 [set x [expr ($hour0+1)*3600-$secs0t]]
 	    set deltax 3600
 	    set min0 0 ; set min_mx 0 ; set min_d 0
 	} else {
 	    if { $hrs > 1 } {
-		# mark hours and half hours
-		set min_mx 30 ; set min_d 30
+		# mark hours and quarters
+		set min_mx 15 ; set min_d 15
+	    } elseif { ($xmax-$hrs*3600)/60 > 5 } {
+		# mark hours and each 5 minutes
+		set min_mx 55 ; set min_d 5
 	    } else {
-		# mark hours and each 10 minutes
-		set min_mx 50 ; set min_d 10
+		# mark hours and each minute
+		set min_mx 59 ; set min_d 1
 	    }
 	    if { $min0 >= $min_mx } {
 		set min0 $min_mx
-		set x [expr ($hour0+1)*3600-$secs0]
+		set x [expr ($hour0+1)*3600-$secs0t]
 	    } else {
 		set min0 [expr $min0-$min0%$min_d]
-		set x [expr 60*($hour0*60+$min0+$min_d)-$secs0]
+		set x [expr 60*($hour0*60+$min0+$min_d)-$secs0t]
 	    }
 	    set xhr0 $x ; set deltax [expr $min_d*60]
 	}
@@ -405,11 +469,16 @@ proc Hgraph {k what args} {
 	    set it [$c create text $tmp $MY -anchor n \
 			-text [format "%02d:%02d" $hour0 $min0] -fill red]
 	    $c lower $it
-	    set it [$c create line $tmp $MY $tmp [expr $MY - 10] -fill "tan"]
+	    set it [$c create line $tmp $MY $tmp [expr $MY-10] \
+			-fill "tan" -tags vgline]
 	    $c lower $it
 	    if { [incr x $deltax] > $xmax } { break }
 	}
     }
+    # MF contrib: make an invisible tick in the horizontal axis for
+    #  keeping track of its normal upper vertical coordinate
+    $c create line 0 [expr $MY-10] 0 $MY -tags hvgline -state hidden
+    #---
     # MF change: time values are self-documented, placing extreme values
     #   replaced "h. max"/"h. min" by "max"/"min"; lowering the items
     set xextrs 50
@@ -444,9 +513,9 @@ proc HGtest2 {c x y}  {
     return
 }
 
-proc HGtest1 {c x y}  {
+proc HGtest1 {c x y} {
 
-    # MF contrib:
+    # MF contribution:
     #  - avoid problems if window was resized by replacing use of
     #   HGpxwp array by tags in graph lines
     #  - maximum x and y must depend on current window size
@@ -527,9 +596,167 @@ proc HGtest1 {c x y}  {
     return
 }
 
+# BS contribution: based on proc HGtest1, display info on plot points
+proc HGtest3 {c x y dist_or_time secs0} {
+    # MF change
+    global HGinfo DTUNIT SUBDTUNIT
+    #======
+
+    foreach "mx my" [$c coords currentsize] { break }
+
+    #search nearest $x associated with wp
+    # - delete any similar line that is overlapped by it
+    # - find overlap with a graph line, assuming that there is at most one
+    # MF change: make sure it has the tag itg=*
+    
+    set ptno -1
+    foreach it [$c find overlapping $x $my $x 0] {
+	set ts [$c gettags $it]
+	if { [lsearch -exact $ts oldlt] != -1 } {
+	    $c delete $it
+	} elseif { [set i [lsearch -glob $ts itg=*]] != -1 } {
+	    # solid line
+	    regsub itg= [lindex $ts $i] "" infotag
+	    set i [lsearch -glob $ts primo=*]
+	    scan [lindex $ts $i] primo=%d ptno
+	    if { [set i [lsearch -glob $ts last=*]] != -1 } {
+		regsub last= [lindex $ts $i] "" ptnext
+	    } else { set ptnext -1 }
+	    set gline $it
+	}
+    }
+    if { $ptno == -1 } {
+	# - no graph line is intersected: clean and return
+	return
+    }
+
+    # BS changes start here
+
+    set before_x 0 ; set after_x 0 ; set lastx 0 ; set lasty 0
+    set before_y 0 ; set after_y 0 ; set lastcox 0 ; set lastcoy 0
+
+    # search the point on the graph closest to the selected area
+    set pts -1
+    foreach "xg yg" [$c coords $gline] "cox coy" $HGinfo($c,$infotag) {
+	if { $xg > $x } {
+	    set after_x $xg ; set after_y $yg 
+	    set before_x $lastx; set before_y $lasty
+	    if { $x-$before_x <= $after_x-$x } 	{
+		set alt $lastcoy ; set xval $lastcox
+		set pts [expr $ptno-1]
+		set x $before_x ; set y $before_y 	
+	    } else {
+		if { $ptnext == -1 } {
+		    set pts $ptno
+		} else { set pts $ptnext }
+		set alt $coy ; set xval $cox
+		set x $after_x; set y $after_y
+	    }
+	    break
+	}
+ 	set lastx $xg ; set lasty $yg ; set lastcox $cox ; set lastcoy $coy
+ 	incr ptno
+    }
+    if { $pts == -1 } {
+	# cursor was to the right of last line
+	set pts [expr $ptno-1]
+	set alt $coy ; set xval $cox
+    }
+    
+    # BS: Display coordinates of the point
+
+    # Displays (altitude and distance) or (altitude alone) depending on the
+    #  selected graphic
+
+    # MF change:
+    #  - showing user units
+    #  - using append to avoid long lines
+    #  - altitude and distance/time are retrieved above
+
+    # Avoided an error when clicked on the last chart point
+    # (at the right of the chart)
+    if {$xval != ""} {
+	#Avoids writing too right of the graph	   		
+	if {$x > $mx-60} {
+	    set x_text [expr $mx-60]
+	}  else { set x_text [expr $x+20] } 
+
+	# The position of the legend depends on the curve 
+	if { $after_y >= $before_y } {
+	    set y_text [expr $y-5]
+	} else {
+	    set y_text [expr $y+30]
+	}
+   
+	# Avoids writing too high or too low on the graph
+	if {$y_text > $my-40} {
+	    set y_text [expr $my-40]
+	}
+	if {$y_text < 20} {
+	    set y_text 20
+	} 	
+
+	append comment $pts "\nalt=" [format %5.0f $alt] $SUBDTUNIT
+	if { $dist_or_time == 1 } {
+	    append comment "\nd:" [format %5.3f $xval] $DTUNIT
+	} elseif { $secs0 != "" } {
+	    append comment "\n" [FormatTime [expr round($xval+$secs0)%86400]]
+	}
+
+	# The position of the legend depends on the curve
+
+	# MF ccontrib: clear old information near the legend
+	set its [$c find overlapping [expr $x_text-30] [expr $y_text-30] \
+		     [expr $x_text+110] [expr $y_text+60]]
+	#---
+
+	# Display the selected point
+	$c create oval  [expr $x-3] [expr $y-3] [expr $x+3] [expr $y+3] \
+	    -outline tan -fill tan -tags oldlt
+	$c create text  $x_text $y_text -text $comment -anchor "w" \
+	    -justify "left" -fill "red" -tag oldlt
+
+	# BS: end
+	# MF ccontrib: clear old information near the legend
+	foreach it $its {
+	    set ts [$c gettags $it]
+	    if { [lsearch $ts oldlt] != -1 } { $c delete $it }
+	}
+    }
+    return
+}
+
+# MF contribution
+proc HgraphClose {w} {
+    # close elevation graph window and delete information on it
+    global HGinfo
+
+    foreach n [array names HGinfo $w.*,*] { unset HGinfo($n) }
+    destroy $w
+    return
+}
+
+# MF contribution
+proc HgraphVertGrid {w} {
+    # expand to window top or restore the ticks in horizontal axis
+
+    if { ! [winfo exists [set c $w.gf.c]] || \
+	     [set its [$c find withtag vgline]] == "" } { return }
+    if { [lindex [$c coords [lindex $its 0]] 3] == 0 } {
+	# resizing the canvas will change this value
+	set ny [lindex [$c coords hvgline] 1]
+    } else { set ny 0 }
+    foreach it $its {
+	set ncs [lreplace [$c coords $it] 3 3 $ny]
+	eval $c coords $it $ncs
+    }
+    return
+}
+
 # MF contribution
 proc ClimbRateData {salts} {
-    # produce climb rate data from list of pairs with seconds and altitude
+    # produce climb rate data from list of triples with seconds, altitude
+    #  and start segment flag
     # a filter kindly provided by Paul Scorer (P.Scorer@leedsmet.ac.uk)
     #  is applied to the altitude values if there is enough data
     #  (at least 10 altitude values, so that 2 filtered values can be
@@ -544,7 +771,8 @@ proc ClimbRateData {salts} {
     set secs0 "" ; set where 1
     set rates "" ; set secs ""
     foreach p $salts {
-	foreach "s a" $p {}
+	foreach "s a newsegm" $p { break }
+	# start segment flag not used
 	if { [regexp \
 		  {^ *-?[0-9]+(\.[0-9]+)?([eE]-?[1-9][0-9]*)? *$} $a] && \
 		 [regexp {^ *[0-9]+ *$} $s] } {
@@ -608,6 +836,7 @@ proc ClimbRateData {salts} {
     }
     return [list $scrs $n $secs0 $sa $rmin $rmax]
 }
+
 #----
 
 ############
