@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,15 +17,15 @@
 #      along with this program.
 #
 #  File: files.tcl
-#  Last change:  16 April 2007
+#  Last change:  30 August 2008
 #
 # See also files_foreign.tcl
 #  and metadata.tcl for properties of known file formats
 #
 # Includes contributions by
-#   - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
-#   - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
-#   - Valere Robin (valere.robin@wanadoo.fr) marked "VR contribution"
+#   - Brian Baulch (baulchb _AT_ onthenet.com.au) marked "BSB contribution"
+#   - Matt Martin (matt.martin _AT_ ieee.org) marked "MGM contribution"
+#   - Valere Robin (valere.robin _AT_ wanadoo.fr) marked "VR contribution"
 #
 
 array set FCOMMAND {
@@ -500,9 +500,22 @@ proc SaveTRComp {file w} {
 	if { [SlowOpAborted] } { return }
 	puts $file "$n\t$d\t$la\t$lo\t$a\t$l\t$tl\t$dt\t$s\t$b"
     }
-    foreach k "frt.td frt.tt frsp.max frsp.min" {
+    foreach k "frt.td frt.tt" {
 	puts $file [$w.$k cget -text]
     }
+    if { [winfo exists $w.frtng] } {
+	foreach k "frtng.td frtng.tt" {
+	    puts $file [$w.$k cget -text]
+	}
+    }
+    foreach k "frsp.avg frsp.max frsp.min" {
+	puts $file [$w.$k cget -text]
+    }
+    if { [winfo exists $w.frmxnalt] } {
+	foreach k "frmxnalt.mx frmxnalt.mn frcad.cumul frcad.cumuld" {
+	    puts $file [$w.$k cget -text]
+	}
+    }
     puts $file "[$w.frd0.toend cget -text] [$w.frd0.max cget -text]"
     puts $file ""
     return
@@ -837,6 +850,7 @@ proc RestoreState {} {
 	    MapPFNeedsDatum File
 
     if { [file size $USvState] == 0 } { return }
+    # assumed to be in system encoding
     source $USvState
     if { [catch {set saved}] } {
 	GMMessage [format $MESS(corruptsstate) $USvState]
@@ -930,12 +944,12 @@ proc SaveCanvas {cv bounds fmt dest} {
     # when printing, a temporary file named "print.tmp" is created in the
     #  user GPSMan-data directory
     global PRINTCMD PAPERSIZE PAGEWIDTH PAGEHEIGHT GFMode GFRot \
-	    GFPaper GFLegend GFVisible GFScale GFPrintOption MESS TXT \
-	    MAPCOLOUR Map MpW MAPSCLENGTH USERDIR MapFont FixedFont
+	GFPaper GFLegend GFVisible GFScale GFPrintOption MESS TXT MAPCOLOUR \
+	Map MpW MAPSCLENGTH USERDIR MapFont FixedFont SHOWFILEITEMS
 
     set leg "=$TXT(legend)"
     set cms [list $TXT(colour) $TXT(grey) $TXT(mono)]
-    set GFVisible 0 ; set GFMode $TXT(colour)
+    set GFVisible $SHOWFILEITEMS ; set GFMode $TXT(colour)
     switch $fmt {
 	PS {
 	    set vs "GFLegend GFMode GFRot GFPaper"
@@ -1101,7 +1115,7 @@ proc OpenInputFileFails {what fmt} {
     #  $what in $TYPES or $what=="LAP" or $what=="Data"
     #  $fmt is such that "in" is in $FILEFORMAT($fmt,mode)
     # return 0 unless operation is to be cancelled
-    global CREATIONDATE GFVisible TXT MESS FILEFORMAT
+    global CREATIONDATE GFVisible TXT MESS FILEFORMAT SHOWFILEITEMS
 
     set params "" ; set parwidgts ""
     if { ! [catch {set pars $FILEFORMAT($fmt,in,params)}] } {
@@ -1137,7 +1151,7 @@ proc OpenInputFileFails {what fmt} {
 	}
     }
     # mapping items is always an option
-    set GFVisible 0
+    set GFVisible $SHOWFILEITEMS
     lappend params GFVisible
     lappend parwidgts "@$TXT(mapitems)"
     while 1 {
@@ -1180,11 +1194,11 @@ proc InitInputFileVars {f what cr vis} {
     #  $cr set if creation date is in use
     #  $vis set if must display items read in
     global LFileLNo LFileCreat LFileBuffFull LFileEOF LFileDefs LFileVisible \
-	    LChannel TXT
+	    LFileTimeOff LChannel TXT
 
     SlowOpWindow $TXT(fread)
     set LChannel($what) $f
-    set LFileLNo($f) 0 ; set LFileCreat($f) $cr
+    set LFileLNo($f) 0 ; set LFileCreat($f) $cr ; set LFileTimeOff($f) ""
     set LFileBuffFull($f) 0 ; set LFileEOF($f) 0
     set LFileDefs($f) 0 ; set LFileVisible($f) $vis
     return 0
@@ -1196,11 +1210,11 @@ proc CloseInputFile {what} {
     #  $what in $TYPES or $what=="LAP"
     global LFilePFrmt LFileDatum LFileLNo LFileCreat \
 	    LFileId LFileOther LFileBuff LFileBuffFull LFileEOF LFileDefs \
-	    LFileVisible LChannel
+	    LFileVisible LFileTimeOff LChannel
 
     set f $LChannel($what)
     if { $f != "stdin" } { close $f }
-    foreach v "LFilePFrmt($f) LFileDatum($f) \
+    foreach v "LFilePFrmt($f) LFileDatum($f) LFileTimeOff($f) \
 	    LFileLNo($f) LFileCreat($f) LFileDefs($f) LFileId($f) \
 	    LFileOther($f) LFileBuff($f) LFileBuffFull($f) \
 	    LFileEOF($f) LFileVisible($f) LChannel($what)" {
@@ -1210,6 +1224,54 @@ proc CloseInputFile {what} {
     return
 }
 
+# encodings in Tcl
+
+proc TclEncodingName {enc} {
+    # tries to convert $enc to a Tcl encoding name
+    global MESS
+
+    set lenc [string tolower $enc]
+    switch -glob -- $lenc {
+	iso* {
+	    regsub {^iso[-_]} $lenc iso enc
+	}
+	utf8 {
+	    return utf-8
+	}
+	utf16* {
+	    # not supported by Tcl 8.4
+	    set enc utf-16
+	}
+	latin1 -  us-ascii {
+	    return iso8859-1
+	}
+	latin[2-4] {
+	    set enc iso8859-[string index $lenc 5]
+	}
+	latin[56] {
+	    set enc iso8859-[expr [string index $lenc 5]+4]
+	}
+	latin[89] {
+	    set enc iso8859-[expr [string index $lenc 5]+6]
+	}
+	latin10 {
+	    set enc iso8859-16
+	}
+	mac* -  x11controlchars {
+	    # keep the original name for uppercase letters
+	}
+	default {
+	    set enc $lenc
+	}
+    }
+    if { [lsearch -exact [encoding names] $enc] == -1 } {
+	GMMessage [format $MESS(unknownenc) $enc]
+    }
+    return $enc
+}
+
+# buffered reading
+
 proc ReadFileNL {file} {
     # buffered read from file a line (may be empty) at a time
     # uses and sets:
@@ -1257,6 +1319,8 @@ proc ReadFile {file} {
     return $LFileBuff($file)
 }
 
+# reading utilities
+
 proc ChopInString {m s} {
    # deletes prefix of length $m and leading spaces and tabs from string $s
 
@@ -1274,6 +1338,8 @@ proc CleanLine {m importing} {
     return $m
 }
 
+# parsing
+
 proc MakeComment {commt} {
     # try to change comment to fit to acceptable character set and length;
     #  on failure return ""
@@ -1378,9 +1444,9 @@ proc FilePTComm {file f cf line} {
 
 proc FindArgs {commd line file} {
     # parse arguments of command when reading file in GPSMan format
-    global LFilePFrmt LFileDatum LFileLNo LFileCreat \
-	    LFileId LFileOther LFileEOF LFileDefs LFilePath \
-	    LFileOrigin LFileScale LFileIxPath MESS
+    global LFilePFrmt LFileDatum LFileLNo LFileCreat LFileId LFileOther \
+	LFileEOF LFileDefs LFilePath LFileOrigin LFileScale LFileIxPath \
+	LFileTimeOff MESS FromTimeOffset
 
     switch $commd {
 	RT {
@@ -1426,17 +1492,24 @@ proc FindArgs {commd line file} {
 	format {
 	    if { [set pf [FindPFormat $line]] != "BAD" } {
 		set line [ChopInString $pf $line]
-		if { [scan $line "%f" off] == 1 } {
-		    regsub {[+-]?[0-9]+\.?[0-9]*} $line "" line
-		    set line [string trimleft $line "\ \t"]
-		    if { [DatumRefId $line] != -1 } {
-			set LFilePFrmt($file) $pf
-			set LFileDatum($file) $line
-			set LFileDefs($file) 7
-			# don't know what to do with time-offset...
-			return format
+		if { [scan $line "%f" off] == 1 && abs($off) < 14.5 } {
+		    if { $LFileTimeOff($file) != "" && \
+			     $off != $LFileTimeOff($file) } {
+			GMMessage $MESS(twotimeoffsets)
+		    } else {
+			regsub {[+-]?[0-9]+\.?[0-9]*} $line "" line
+			set line [string trimleft $line "\ \t"]
+			if { [DatumRefId $line] != -1 } {
+			    set LFilePFrmt($file) $pf
+			    if { $FromTimeOffset != "" } {
+				set LFileTimeOff($file) $FromTimeOffset
+			    } else { set LFileTimeOff($file) $off }
+			    set LFileDatum($file) $line
+			    set LFileDefs($file) 7
+			    return format
+			}
+			GMMessage "$MESS(unkndatum): $line"
 		    }
-		    GMMessage "$MESS(unkndatum): $line"
 		}
 	    }
 	}
@@ -1706,10 +1779,20 @@ proc LoadWPs {file outRT importing how} {
     # if ! $outRT && ! $importing assume $LFileId($file) has the identifier
     #  of the RT being loaded
     global LFileLNo LFileBuffFull LFileCreat LFilePFrmt \
-	    LFileOther LFileDatum LFileEOF LFileVisible LFileWPs LFileIxs \
-	    LFileRTStages LFileId PosnLength DEFAULTSYMBOL DEFAULTDISPOPT \
-	    CREATIONDATE MESS DataIndex
+	LFileOther LFileDatum LFileEOF LFileVisible LFileWPs LFileIxs \
+	LFileRTStages LFileId LFileTimeOff PosnLength DEFAULTSYMBOL \
+	DEFAULTDISPOPT CREATIONDATE MESS DataIndex TimeOffset DateFormat
 
+
+    if { ! $importing } {
+	if { $LFileCreat($file) && $LFileTimeOff($file) == "" } {
+	    GMMessage $MESS(notimeoffset)
+	    set LFileTimeOff($file) 0
+	}
+	set adjtimeoff [expr $TimeOffset != $LFileTimeOff($file)]
+	set adjsecs [expr int(3600*($LFileTimeOff($file)-$TimeOffset))]
+    } else { set adjtimeoff 0 }
+    
     set wps "" ; set ix -1 ; set count 0
     while { 1 } {
 	if { [SlowOpAborted] } { return "" }
@@ -1745,7 +1828,7 @@ proc LoadWPs {file outRT importing how} {
 		    return ""
 		}
 		default {
-		    incr count -1
+		    if { $count > 0 } { incr count -1 }
 		}
 	    }
 	    continue
@@ -1789,12 +1872,19 @@ proc LoadWPs {file outRT importing how} {
 	if { ! [CheckComment Ignore $commt] } {
 	    set commt [MakeComment $commt]
 	}
-	if { $LFileCreat($file) } {
-	    set date [lindex $as 2] ; set i 3
-	    if { ! [CheckDate GMMessage $date] } { return "" }
-	} else {
-	    set date [Now] ; set i 2
-	}
+	set i 2
+	if { $LFileCreat($file) && [incr i] && \
+		 [set date [lindex $as 2]] != "" } {
+	    if { [set sd [ScanDate $date]] == "" } {
+		GMMessage [format $MESS(baddateas) $date]
+		return ""
+	    }
+	    if { $adjtimeoff } {
+		set secs [expr [eval DateToSecs $sd]+$adjsecs]
+		set sd [DateIntsFromSecs $secs]
+		set date [eval FormatDate $DateFormat $sd]
+	    }
+	} else { set date [Now] }
 	set posn [ReadPosn $as $i $file]
 	if { $posn == -1 } { return "" }
 	incr i $PosnLength
@@ -1812,7 +1902,7 @@ proc LoadWPs {file outRT importing how} {
 	set data [FormData WP $fs [list $name $commt $LFilePFrmt($file) $posn \
 			             $LFileDatum($file) $date $hs]]
 	if { $chgdname != "" } {
-	    set data [AddOldNameToObs $data $chgdname]
+	    set data [AddOldNameToObs WP $data $chgdname]
 	}
 	set data [InsertAttrPairs $as $data]
 	# check for a NB
@@ -1937,7 +2027,17 @@ proc LoadTPs {file importing e0} {
     #  $e0 is the expected contents of first field (either "" or "T")
     # return list with list of TR points and list of indices (!=0) of TPs
     #  starting segments (always "" when importing)
-    global LFileLNo LFileBuffFull LFilePFrmt LFileDatum LFileEOF MESS
+    global LFileLNo LFileBuffFull LFilePFrmt LFileDatum LFileEOF LFileTimeOff \
+	TimeOffset DateFormat MESS
+
+    if { ! $importing } {
+	if { $LFileTimeOff($file) == "" } {
+	    GMMessage $MESS(notimeoffset)
+	    set LFileTimeOff($file) 0
+	}
+	set adjtimeoff [expr $TimeOffset != $LFileTimeOff($file)]
+	set adjsecs [expr int(3600*($LFileTimeOff($file)-$TimeOffset))]
+    } else { set adjtimeoff 0 }
 
     set tps ""
     set tpn 0 ; set segsts ""
@@ -2008,8 +2108,16 @@ proc LoadTPs {file importing e0} {
 	    set ad [list $ad $dep]
 	    set ns "latd longd latDMS longDMS date secs alt depth"
 	}
-	set date [CheckConvDate [string trim [lindex $fs 1] " "]]
-	if { $date == "" } { return "" }
+	if { [set sd [ScanDate [string trim [lindex $fs 1] " "]]] == "" } {
+	    GMMessage [format $MESS(baddateas) [lindex $fs 1]]
+	    return ""
+	}
+	set secs [eval DateToSecs $sd]
+	if { $adjtimeoff } {
+	    set secs [expr $secs+$adjsecs]
+	    set sd [DateIntsFromSecs $secs]
+	}
+	set date [list [eval FormatDate $DateFormat $sd] $secs]
 	set posn [ReadPosn $fs 2 $file]
 	if { $posn == -1 } { return "" }
 	if { $LFilePFrmt($file) != "DMS" } {
@@ -2157,18 +2265,31 @@ proc BadLAPRead {file importing how} {
     # parse LAP data from file in GPSMan format
     #  $how in {normal, inGR}: keep data on all LAPs, keep data for LAPs
     #    with indices in $LFileIxs($file,LAP)
-    global LFileLNo LFileDatum LFileId LFileOther LFilePFrmt LFileIxs MESS \
-	SUPPORTLAPS
+    global LFileLNo LFileDatum LFileId LFileOther LFilePFrmt LFileIxs \
+	LFileTimeOff TimeOffset DateFormat MESS SUPPORTLAPS
 
     if { ! $SUPPORTLAPS } {
 	GMMessage $MESS(lapncnsdrd)
 	return 0
     }
     set id $LFileId($file)
+    if { $LFileTimeOff($file) == "" } {
+	GMMessage $MESS(notimeoffset)
+	set LFileTimeOff($file) 0
+    }
+    if { [set sd [ScanDate $id]] == "" } {
+	GMMessage [format $MESS(baddateas) $id]
+	return ""
+    }
+    set secs [eval DateToSecs $sd]
+    if { $TimeOffset != $LFileTimeOff($file) } {
+	set secs [expr $secs+int(3600*($LFileTimeOff($file)-$TimeOffset))]
+	set id [eval FormatDate $DateFormat [DateIntsFromSecs $secs]]
+    }
+    set start [list $id $secs]
     set n [llength [set as $LFileOther($file)]]
     foreach "dur dist begp endp cals trix" $as { break }
-    if { $n != 6 || [set start [CheckConvDate $id]] == "" || \
-	     ! [CheckTime GMMessage $dur] || \
+    if { $n != 6 || ! [CheckTime GMMessage $dur] || \
 	     ( $dist != "" && ! [CheckFloat GMMessage $dist] ) || \
 	     ( $begp != "" && [set begp [ReadPosn $begp 0 $file]] == -1 ) || \
 	     ( $endp != "" && [set endp [ReadPosn $endp 0 $file]] == -1 ) || \
@@ -2357,10 +2478,10 @@ proc LoadFileFrom {f what} {
     #  $what in $TYPES or $what=="LAP" or $what==Data
     #  (see proc LoadAll)
     # return 0 on error
-    global LChannel CREATIONDATE
+    global LChannel CREATIONDATE SHOWFILEITEMS
 
     InitWPRenaming
-    InitInputFileVars $f $what $CREATIONDATE 0
+    InitInputFileVars $f $what $CREATIONDATE $SHOWFILEITEMS
     set r [LoadAll $f]
     CloseInputFile $what
     EndWPRenaming
@@ -2453,7 +2574,8 @@ proc LoadMapFixedBk {path} {
     #    lcsp is list of canvas coordinates (NW) and path for each subsidiary
     #     image not in grid
     global LFileLNo LFileBuffFull LFileEOF LFilePath LFileDatum LFileDefs \
-	    LFileProj LFileTransf LFileOrigin LFileScale LFileIxPath MESS TXT
+	LFileProj LFileTransf LFileOrigin LFileScale LFileIxPath LFileTimeOff \
+	MESS TXT
 
     if { $path == "" } {
 	set f [GMOpenFile $TXT(loadfrm) MapBkInfo r]
@@ -2466,6 +2588,7 @@ proc LoadMapFixedBk {path} {
     set r -1
     if { $f != ".." } {
 	set LFileLNo($f) 0 ; set LFileBuffFull($f) 0 ; set LFileEOF($f) 0
+	set LFileTimeOff($f) ""
 	if { [FindCommand $f] != "mapback" } {
 	    set r 0
 	} else {
@@ -2518,7 +2641,8 @@ proc LoadMapFixedBk {path} {
 	}
 	foreach v "LFileLNo($f) LFileBuffFull($f) LFileEOF($f) LFilePath($f) \
 		LFileDefs($f) LFileDatum($f) LFileProj($f) LFileTransf($f) \
-		LFileOrigin($f) LFileScale($f) LFileIxPath($f)" {
+		LFileOrigin($f) LFileScale($f) LFileIxPath($f) \
+                LFileTimeOff($f)" {
 	    catch { unset $v }
 	}
 	close $f
@@ -2536,7 +2660,7 @@ proc LoadMapInfo {path} {
     #     name and value for projection and transformation
     # for files generated by 6.1.2 or older $pfdatum defaults to $datum
     global LFileLNo LFileBuffFull LFileEOF LFileDatum LFileDefs \
-	    LFileProj LFileTransf LFilePFrmt LFileScale MESS TXT
+	    LFileProj LFileTransf LFilePFrmt LFileScale LFileTimeOff MESS TXT
 
     if { $path == "" } {
 	set f [GMOpenFile $TXT(loadfrm) MapInfo r]
@@ -2549,6 +2673,7 @@ proc LoadMapInfo {path} {
     set r -1
     if { $f != ".." } {
 	set LFileLNo($f) 0 ; set LFileBuffFull($f) 0 ; set LFileEOF($f) 0
+	set LFileTimeOff($f) ""
 	if { [FindCommand $f] != "mapinfo" } {
 	    GMMessage $MESS(badmapinfo)
 	} else {
@@ -2577,7 +2702,7 @@ proc LoadMapInfo {path} {
 	ResetCursor .
 	foreach v "LFileLNo($f) LFileBuffFull($f) LFileEOF($f) \
 		LFileDefs($f) LFileDatum($f) LFileProj($f) LFileTransf($f) \
-		LFilePFrmt($f) LFileScale($f)" {
+		LFilePFrmt($f) LFileScale($f) LFileTimeOff($f)" {
 	    catch { unset $v }
 	}
 	close $f
@@ -2586,13 +2711,13 @@ proc LoadMapInfo {path} {
 }
 
 array set LSqIStates {
-    start     {format datum pformt}
-    start,nxt {point pformt datum}
-    pformt    {pformt}
-    pformt,nxt {datum}
-    datum     {datum}
-    datum,nxt {pformt}
-    point     {}
+    start       {format datum pformat}
+    start,nxt   {point pformat datum}
+    pformat     {pformat}
+    pformat,nxt {datum}
+    datum       {datum}
+    datum,nxt   {pformat}
+    point       {}
 }
 
 proc LoadLeastSquaresInfo {} {
@@ -2600,27 +2725,39 @@ proc LoadLeastSquaresInfo {} {
     #  a map image using a least squares fit
     # file starts with optional datum and position format commands, or a
     #  format command, (defaults are "WGS 84" and DDD), followed by a line
-    #  for each point with fields separated by tabulations containing the
-    #  position, in the selected/default datum and format, and the
-    #  pixel coordinates (x, y, with y increasing downwards)
-    # the total number of points must
-    # return 0 on failure, or a pair with list of latd,longd,datum, and list
-    #  of pairs with pixel coordinates (x, y, in Tcl sign convention with
-    #  origin at upper left corner)
-    global LSqIStates LFileLNo LFileEOF LFileBuffFull LFileDatum PosnLength \
-	TXT MESS MAPTRANSFNPTS
+    #  for each point with fields separated by tabulations; such lines
+    #  either start with a $FCOMMAND(WP) field, followed by fields with
+    #  an existing WP name and the pixel coordinates (x, y, with y
+    #  increasing downwards), or have a position, in the selected/default
+    #  datum and format, and the pixel coordinates (as before)
+    # the minimum number of points is given by the global
+    #    $MAPTRANSFNPTS(LeastSquares) defined in metadata.tcl
+    # return 0 on failure, or a list with list of latd, longd and datum,
+    #  a list of pairs with pixel coordinates (x, y, in Tcl sign convention
+    #  with origin at upper left corner), a list with waypoints names (empty
+    #  for explicit positions), and the input file path
+    global LSqIStates LFileLNo LFileEOF LFileBuffFull LFileDatum LFileDefs \
+	LFileDatum LFilePFrmt PosnLength TXT MESS MAPTRANSFNPTS FCOMMAND File \
+	WPPosn WPDatum GFShowInfo GFVisible SHOWFILEITEMS
 
-    if { [set f [GMOpenFile $TXT(loadfrm) MapBkInfo r]] == ".." } {
+    set GFVisible $SHOWFILEITEMS
+    set prms {GFShowInfo GFVisible}
+    set pws [list "@$TXT(showfitinfo)" "@$TXT(mapfitWPs)"]
+    set f [GMOpenFileParms $TXT(loadfrm) MapBkInfo r $prms $pws]
+    if { $f == ".." } {
 	return 0
     }
+    set fpath $File(MapBkInfo)
     set LFileLNo($f) 0 ; set LFileBuffFull($f) 0 ; set LFileEOF($f) 0
+    set LFileDefs($f) 0
     # defaults
     set LFileDatum($f) "WGS 84" ; set LFilePFrmt($f) DDD
     set state start ; set err 0
-    set llds "" ; set xys ""
+    set ldds "" ; set xys "" ; set names ""
     while { ! $LFileEOF($f) } {
 	if { [set line [CleanLine [ReadFile $f] 0]] == "" } { continue }
-	if { [string first ! $line] == 0 } {
+	if { [string first ! $line] == 0 && \
+		 [string first $FCOMMAND(WP) $line] != 0 } {
 	    set c [ProcCommand $line $f]
 	    if { [set ix [lsearch -exact $LSqIStates($state) $c]] == -1 } {
 		incr err ; break
@@ -2629,28 +2766,47 @@ proc LoadLeastSquaresInfo {} {
 	} else {
 	    set state point
 	    set fs [split $line \t]
-	    if { [set p [ReadPosn $fs 0 $f]] == -1 } { incr err ; break }
-	    set x [lindex $fs $PosnLength]
-	    set y [lindex $fs [expr $PosnLength+1]]
+	    if { [lindex $fs 0] == $FCOMMAND(WP) } {
+		set name [string trim [lindex $fs 1]]
+		if { ! [CheckName GMMessage $name] } { incr err ; break }
+		if { [set ix [IndexNamed WP $name]] == -1 } {
+		    GMMessage [format $MESS(undefinedWP) $name]
+		    incr err ; break
+		}
+		set p $WPPosn($ix)
+		set datum $WPDatum($ix)
+		set fix 2
+	    } elseif { [set p [ReadPosn $fs 0 $f]] != -1 } {
+		set name ""
+		set datum  $LFileDatum($f)
+		set fix $PosnLength
+	    } else { incr err ; break }
+	    set x [lindex $fs $fix]
+	    set y [lindex $fs [expr $fix+1]]
 	    if { ! [CheckSignedFloat GMMessage $x] || \
 		     ! [CheckSignedFloat GMMessage $y] } {
 		incr err ; break
 	    }
-	    lappend llds [list [lindex $p 0] [lindex $p 1] $LFileDatum($f)]
+	    lappend ldds [list [lindex $p 0] [lindex $p 1] $datum]
 	    lappend xys [list $x $y]
+	    lappend names $name
 	}
     }
     close $f
     if { $err } {
 	GMMessage "$MESS(loaderr) $LFileLNo($f)"
-	return 0
-    }
-    if { [regexp {^>=([0-9]+)$} $MAPTRANSFNPTS(LeastSquares) x n] && \
-	     [lindex $llds [expr $n-1]] == "" } {
+	set r 0
+    } elseif { [regexp {^>=([0-9]+)$} $MAPTRANSFNPTS(LeastSquares) x n] && \
+		   [lindex $xys [expr $n-1]] == "" } {
 	GMMessage [format $MESS(needNpoints) $n]
-	return 0
+	set r 0
+    } else {
+	set r [list $ldds $xys $names $fpath]
     }
-    return [list $llds $xys]
+    foreach v "LNo EOF BuffFull Datum Defs Datum PFrmt" {
+	catch { unset LFile${v}($f) }
+    }
+    return $r
 }
 
 ## BSB contribution
@@ -2668,6 +2824,6 @@ proc LoadAutoMapInfo {} {
 	    set ImageIndex($index) [split $line "\t"]
 	}
     }
-return
+    return
 }
 
