@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,20 +17,27 @@
 #      along with this program.
 #
 #  File: garmin_protocols.tcl
-#  Last change:  31 May 2007
+#  Last change:  27 September 2008
 #
 
-# description of Garmin protocols based on Garmin GPS Interface
-#  Specification Version 1 Rev. 2
+# description of Garmin protocols based on
+#
+#- Garmin GPS Interface Specification Version 1 Rev. 2
 # updated for:
 #   Garmin GPS Interface Specification Version 1 Rev. 3
 #   Garmin GPS Interface Specification Version 1 Rev. A
 #   Garmin GPS Interface Specification Version 1 Rev. B
-#   Garmin GPS Interface Specification Version 1 Rev. C
+#   Garmin GPS Interface Specification Version 1 Rev. C, May 2006
+#
+#- Garmin Fleet Management Interface Control Specification, 001-00096-00 Rev. A
+#   January 2, 2007
+#
+#- GPS 15H & 15L TECHNICAL SPECIFICATIONS, 190-00266-01, Rev. D, February 2006
+#
 
 # Garmin USB protocol is implemented assuming that the USB port is driven by
 #  the garmin_gps Linux kernel driver by Hermann Kneissel and part of the
-#  official 2.6 Linux kernel releases
+#  official >=2.6 Linux kernel releases
 
    # ASCII codes (decimal)
 set DLE 16
@@ -43,15 +50,16 @@ set DLECHR [binary format "c" $DLE]
 
    # protocol tags
 array set PROTTAG {
-    P Physical  L Link  A Application  D Data  T nospec
+    P Physical  L Link  A Application  D Data  T Transmission
 }
 
    # categories of known product specific protocols
-set PSPROTOCOLS {Link DevCmd WP WPCat RT TR LAP Prx AL DtTm
-                 FlightBook Posn PVT}
+set PSPROTOCOLS {Link Baud DevCmd WP WPCat RT TR LAP Prx AL DtTm
+                 FleetManagement FlightBook Posn PVT}
 
    # application protocol categories
 array set PROTCAT {
+    T001  Baud
     A010  DevCmd
     A011  DevCmd
     A100  WP
@@ -65,6 +73,8 @@ array set PROTCAT {
     A500  AL
     A600  DtTm
     A601  nospec
+    A602  FleetManagement
+    A603  FleetManagement
     A650  FlightBook
     A700  Posn
     A800  PVT
@@ -79,11 +89,14 @@ array set PROTCAT {
     A906  LAP
     A907  nospec
     A908  nospec
+    A912  nospec
     A913  nospec
     A914  nospec
+    A915  nospec
     A916  nospec
     A917  nospec
     A918  nospec
+    A919  nospec
     A1000 RUN
     A1002 WKO
     A1003 WKOOcc
@@ -97,17 +110,21 @@ array set PROTCAT {
     A1011 nospec
 }
 
-   # protocol requirements
+   # protocol requirements for each application protocol
+   #  a prefix "?" indicates a non-mandatory requirement (only after all
+   #  mandatory ones)
+   #  a "D?" is used when there is no information
 array set PROTREQ {
     N/A   ""
     P000  ""
     L000  ""
     L001  ""
     L002  ""
+    T001  ""
     A010  ""
     A011  ""
     A100  WPData
-    A101  WPCatData
+    A101  {WPCatData ?D? ?D?}
     A200  {RTHeader RTWPData}
     A201  {RTHeader RTWPData RTLinkData}
     A300  TRData
@@ -117,6 +134,8 @@ array set PROTREQ {
     A500  ALData
     A600  DtTmData
     A601  D?
+    A602  FMData
+    A603  FMData
     A650  ""
     A700  PosnData
     A800  PVTData
@@ -131,11 +150,14 @@ array set PROTREQ {
     A906  LAPData
     A907  {D? D? D? D?}
     A908  D?
-    A913  ""
+    A912  D?
+    A913  D?
     A914  ""
+    A915  D?
     A916  ""
     A917  D?
     A918  D?
+    A919  ""
     A1000 RUNData
     A1002 WKOData
     A1003 WKOOcc
@@ -188,10 +210,12 @@ array set RPID {
 
    # definitions of Link product specific protocols
 set PSPDEF(L001) {{CmdData 10} {XfrCmpl 12} {DtTmData 14} {PosnData 17}
-                  {PrxWPData 19} {Records 27} {RTHeader 29} {RTWPData 30}
-                  {ALData 31} {TRData 34} {WPData 35} {PVTData 51}
+                  {PrxWPData 19} {Records 27} {RqstData 28} {RTHeader 29}
+                  {RTWPData 30} {ALData 31} {TRData 34} {WPData 35}
+                  {UIdData 38} {BaudRqstData 48} {BaudAcptData 49} {PVTData 51}
                   {RTLinkData 98} {TRHeader 99} {FlightBook_Record 134}
-                  {LAPData 149} {WPCatData 152} {RUNData 990} {WKOData 991}
+                  {FMILegStopAt 135} {FMILegPutMess 136} {LAPData 149}
+                  {WPCatData 152} {FMIPacket 161} {RUNData 990} {WKOData 991}
                   {WKOOcc 992} {FUPData 993} {WKOLimits 994} {CRSData 1061}
                   {CRSLap 1062} {CRSPoint 1063} {CRSTRHeader 1064}
                   {CRSTRData 1065} {CRSLimits 1066}}
@@ -200,16 +224,41 @@ set PSPDEF(L002) {{ALData 4} {CmdData 11} {XfrCmpl 12} {DtTmData 20}
                   {PosnData 24} {PrxWPData 27} {Records 35} {RTHeader 37}
                   {RTWPData 39} {WPData 43}}
 
+    # packet ids in Fleet Management Interface packets
+array set FMIPSP {
+    FMIEnable 0
+    FMIPrdReq 1
+    FMIPrdData 2
+    FMIProtSupp 3
+    FMIGetAckTxtMess 32
+    FMIPutTxtMess 33
+    FMIPutAckTxtMess 34
+    FMIPutYesNoTxtMess 35
+    FMIGetTxtMess 36
+    FMIPutAckTxtMess 37
+    FMIA602StopAt 256
+    FMIA603StopAt 257
+    FMIA603RqstETA 516
+    FMIA603GetETA 517
+    FMIA603PutETARec 518
+    FMIA603PutStopSt 528
+    FMIA603GetStopSt 529
+    FMIA603PutStStRec 530
+    FMIA603PutAArrival 548
+    FMIA630Delete 560
+}
+
     # packet ids not described in the specifications:
     #   114: appears before a PVTData packet in the Quest
 
     # definition of product specific device commands
 set PSCMDDEF(A010) {{Abort 0} {XfrAL 1} {XfrPosnData 2} {XfrPrx 3} {XfrRT 4}
-                  {XfrDtTmData 5} {XfrTR 6} {XfrWP 7} {TurnOff 8} {StartPVT 49}
-                  {StopPVT 50} {XfrFlightBook 92} {XfrLAP 117} {XfrWPCat 121}
-                  {XfrRUN 450} {XfrWKO 451} {XfrWKOOcc 452} {XfrFUP 453}
-                  {XfrWKOLimits 454} {XfrCRS 561} {XfrCRSLap 562}
-                  {XfrCRSPoint 563} {XfrCRSTrack 564} {XfrCRSLimits 565}}
+                  {XfrDtTmData 5} {XfrTR 6} {XfrWP 7} {TurnOff 8} {RqstUId 14}
+                  {StartPVT 49} {StopPVT 50} {AckPing 58} {XfrFlightBook 92}
+                  {XfrLAP 117} {XfrWPCat 121} {XfrRUN 450} {XfrWKO 451}
+                  {XfrWKOOcc 452} {XfrFUP 453} {XfrWKOLimits 454} {XfrCRS 561}
+                  {XfrCRSLap 562} {XfrCRSPoint 563} {XfrCRSTrack 564}
+                  {XfrCRSLimits 565}}
 set PSCMDDEF(A011) {{Abort 0} {XfrAL 1} {XfrRT 8} {XfrPrx 17} {XfrDtTmData 20}
                   {XfrWP 21} {TurnOff 26}}
 
@@ -230,11 +279,6 @@ array set PDTSIZE {
 set PDTYPE(ACK) union=int,byte
 set PDTYPE(NAK) union=int,byte
 
-      # sending byte according to Garmin specifications version 3
-      #  and accepting either int or byte as in versions <= 3
-# set PDTYPE(ACK) union=byte,int
-# set PDTYPE(NAK) union=byte,int
-
     # protocols for which no output is available (as in the Garmin specs,
     #  or because of no support or no complete specification available)
     # list of pairs with item type and either empty (for any) or list of
@@ -242,11 +286,16 @@ set PDTYPE(NAK) union=int,byte
 
 set PROTNOOUTPUT {{TR {{TR A302} {TRData D304}}} {Prx {}} {AL {}}}
 
+   ## RT/TR Header protocols with a numeric identifier
+set PRTNUMID {D200 D201}
+set PTRNUMID {D311}
+
 array set PDTYPE {
     PArray  starray=char,word
     PrdReq  ignored
     PrdData    {int int string ignored}
     PrdExtData ignored
+    UIdData {longword ignored}
     Records  int
     D100  {charray=6 semicircle unused=4 charray=40}
     D101  {charray=6 semicircle unused=4 charray=40 float byte}
@@ -300,6 +349,19 @@ array set PDTYPE {
 	   float byte}
     D600  {byte byte word int byte byte}
     D601  nospec
+    D602  _multiple
+    D602_a  {longword string<200}
+    D602_b  {longword byte unused=3 byte=16 string<200}
+    D602_c  {longword byte unused=3 byte=16 longword}
+    D602_d  {longword semicircle string<200}
+    D603  _multiple
+    D603_a  {longword longword string<200}
+    D603_b  {longword}
+    D603_c  {longword semicircle longword string<200}
+    D603_d  {longword word word}
+    D603_e  {longword longword longword semicircle}
+    D603_f  {longword longword}
+    D603_g  {longword}
     D650  {longword longword semicircle semicircle longword longword float
            float float boolean string string string string string}
     D700  radian
@@ -327,11 +389,32 @@ array set PDTYPE {
     D1011 nospec
     D1012 nospec
     D1013 nospec
+    FMILegPutMess {string<200}
+    FMILegStopAt  {semicircle string<51}
 }
 
-## RT/TR Header protocols with a numeric identifier
-set PRTNUMID {D200 D201}
-set PTRNUMID {D311}
+array set FMIPDTYPE {
+    FMIEnable {}
+    FMIPrdReq {}
+    FMIPrdData         PrdData
+    FMIProtSupp        PArray
+    FMIGetAckTxtMess   D602_c
+    FMIPutTxtMess      D602_a
+    FMIPutAckTxtMess   D602_b
+    FMIPutYesNoTxtMess D602_b
+    FMIGetTxtMess      D603_a
+    FMIPutAckTxtMess   D603_b
+    FMIA602StopAt      D602_c
+    FMIA603StopAt      D603_c
+    FMIA603PutStopSt   D603_d
+    FMIA603GetStopSt   D603_d
+    FMIA603PutStStRec  D603_b
+    FMIA603RqstETA     {}
+    FMIA603GetETA      D603_e
+    FMIA603PutETARec   D603_b
+    FMIA603PutAArrival D603_f
+    FMIA630Delete      D603_g
+}
 
     # product identifiers; new entries should also be added to recmodels.tcl
     #  numbers followed by a letter are defined here to support older
@@ -396,6 +479,7 @@ array set PRODID {
     "GPS 92" 112
     "GPS 12CX" 116
     "GPS III Plus" 119
+    "GPSMAP 162" 126
     "GPSMAP 295" 128
     "GPS 12 Map" 129
     eTrex  130
@@ -409,14 +493,15 @@ array set PRODID {
     "eTrex Euro"  156
     "eTrex Vista" {169 420}
     "GPS 76" 173
-    "GPSMAP 76" 177
+    "GPSMAP 76" {177 439}
     "eTrex Legend" {179 411}
     "GPSMAP 76S" 194
     "Rino 110"   197
     "Rino 120"   209
+    "eTrex LegendJ" 219
     "Quest" 231
-    "GPS 72" 247
-    "Geko 201" 248
+    "GPS 72" {247 430}
+    "Geko 201" {248 574}
     "Geko 301" 256
     "Rino 130" 264
     "GPS 18USB" 273
@@ -431,13 +516,22 @@ array set PRODID {
     "ForeTrex" 314
     "eTrex Vista C" 315
     "eTrex Legend C" 315
+    "StreetPilot c320" {382 497}
+    "StreetPilot 2720" 404
     "eTrex Venture" 419
     "eTrex Legend Cx" 421
     "EDGE205" 450
     "EDGE305" 450
+    "StreetPilot c340" 481
     "Forerunner 205" 484
     "Forerunner 305" 484
+    "StreetPilot c330" 497
     "StreetPilot i2" 532
+    "eTrex Legend HCx" 694
+    "eTrex Vista HCx" 694
+    "eTrex Venture HC" {695 786}
+    "eTrex H" 696
+    "eTrex Summit HC" 786
 }
 
     # product names and how to obain its product specific protocols
@@ -504,6 +598,7 @@ array set PNAME {
     111  eMap
     112  "GPS 92"
     116  "GPS 12CX"
+    126  "GPSMAP 162"
     128  "GPSMAP 295"
     129  "GPS 12 Map"
     130  eTrex
@@ -522,6 +617,7 @@ array set PNAME {
     194  "GPSMAP 76S"
     197  "Rino 110"
     209  "Rino 120"
+    219  "eTrex LegendJ"
     231  "Quest"
     247  "GPS 72"
     248  "Geko 201"
@@ -537,14 +633,25 @@ array set PNAME {
     295  "eTrex Summit"
     308  "GPSMap60"
     314  "ForeTrex"
-    315  "eTrex Vista/Legend C"
+    315  "eTrex Legend/Vista C"
+    382  "StreetPilot c320"
+    404  "StreetPilot 2720"
     411  "eTrex Legend"
     419  "eTrex Venture"
     420  "eTrex Vista"
     421  "eTrex Legend Cx"
+    430  "GPS 72"
+    439  "GPSMAP 76"
     450  "EDGE205/305"
+    481  "StreetPilot c340"
     484  "Forerunner 205/305"
+    497  "StreetPilot c320/c330"
     532  "StreetPilot i2"
+    574  "Geko 201"
+    694  "eTrex Legend/Vista HCx"
+    695  "eTrex Venture HC"
+    696  "eTrex H"
+    786  "eTrex Summit/Venture HC"
 }
 
 # the descriptions below are valid for all versions except:
@@ -560,6 +667,8 @@ array set PNAME {
 #  285+ version >= 3.0
 #  484 version < 2.6 (just a guess)
 #  484+ version >= 2.6
+#  694 version < 2.4 (just a guess)
+#  694+ version >= 2.4
 
       # the pairs in the following entries have a comparison to be made
       #  to the receiver version and the identifier to be used if the
@@ -572,6 +681,7 @@ array set PRTCLVERSION {
     285 {{{>= 300} 285+}}
     289 {{{>= 240} 289+}}
     484 {{{>= 260} 484+}}
+    694 {{{>= 240} 694+}}
 }
 
 array set PRTCLDEF {
@@ -629,6 +739,7 @@ array set PRTCLDEF {
     112  diff
     116  array
     119  array
+    126  diff
     128  see=111
     129  array
     130  diff
@@ -647,6 +758,7 @@ array set PRTCLDEF {
     194  see=177
     197  diff
     209  see=197
+    219  diff
     231  array
     247  see=116
     248  array
@@ -665,14 +777,26 @@ array set PRTCLDEF {
     308  see=289+
     314  array
     315  array
+    382  array
+    404  array
     411  diff
     419  array
     420  see=411
     421  array
+    430  see=177
+    439  diff
     450  array
+    481  array
     484  diff
     484+ diff
+    497  array
     532  array
+    574  see=248
+    694  diff
+    694+ diff
+    695  see=694+
+    696  see=248
+    786  see=694+
 }
 
 ### there is no information on which receivers use the PVT protocol
@@ -848,6 +972,7 @@ array set PSPID {
     177,nospec A900+A902+A903
 
     231,Link L001
+    231,Baud T001
     231,DevCmd A010
     231,WP A100
     231,WPData D110
@@ -869,7 +994,7 @@ array set PSPID {
     231,PosnData D700
     231,PVT A800
     231,PVTData D800
-    231,nospec T+A601+D601+A900+A902+A903+A904+A905
+    231,nospec A601+D601+A900+A902+A903+A904+A905
 
     248,Link L001
     248,DevCmd A010
@@ -893,6 +1018,7 @@ array set PSPID {
     248,PVTData D800
 
     273,Link L001
+    273,Baud T001
     273,DevCmd A010
     273,WP N/A
     273,RT N/A
@@ -953,6 +1079,7 @@ array set PSPID {
     283,LAPData D906
 
     285+,Link L001
+    285+,Baud T001
     285+,DevCmd A010
     285+,WP A100
     285+,WPData D110
@@ -977,7 +1104,7 @@ array set PSPID {
     285+,PVTData D800
     285+,LAP A906
     285+,LAPData D906
-    285+,nospec T+A601+D601+A802+D802A900+A902+A903+A904+A907+D907+D908+D909+D910
+    285+,nospec A601+D601+A802+D802A900+A902+A903+A904+A907+D907+D908+D909+D910
 
     291,Link L001
     291,DevCmd A010
@@ -1003,6 +1130,7 @@ array set PSPID {
     291,nospec A601+D601+A900+A902+A903+A904
 
     292,Link L001
+    292,Baud T001
     292,DevCmd A010
     292,WP A100
     292,WPData D110
@@ -1048,6 +1176,7 @@ array set PSPID {
     314,nospec A802+D802+A903
 
     315,Link L001
+    315,Baud T001
     315,DevCmd A010
     315,WP A100
     315,WPData D109
@@ -1070,6 +1199,52 @@ array set PSPID {
     315,PVTData D800
     315,nospec A601+D601+A900+A902+A903+A904+A907+D907+D908+D909+D910+A914
 
+    382,Link L001
+    382,Baud T001
+    382,DevCmd A010
+    382,WP A100
+    382,WPData D110
+    382,RT N/A
+    382,TR N/A
+    382,Prx N/A
+    382,AL A500
+    382,ALData D501
+    382,DtTm A600
+    382,DtTmData: D600
+    382,Posn A700
+    382,PosnData D700
+    382,PVT A800
+    382,PVTData D800
+    382,nospec A101+D120+D110+D210+A601+D601+A802+D802+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A912+D912+A913+D913+A916+A917+D917
+
+    404,Link L001
+    404,Baud T001
+    404,DevCmd A010
+    404,WP A100
+    404,WPData D110
+    404,WPCat A101
+    404,WPCatData D120
+    404,RT A201
+    404,RTHeader D202
+    404,RTWPData D110
+    404,RTLinkData D210
+    404,TR A301
+    404,TRHeader D310
+    404,TRData D302
+    404,Prx A400
+    404,PrxWPData D110
+    404,AL A500
+    404,ALData D501
+    404,DtTm A600
+    404,DtTmData D600
+    404,Posn A700
+    404,FleetManagement A602
+    404,FMData D602
+    404,PosnData D700
+    404,PVT A800
+    404,PVTData D800
+    404,nospec A601+D601+A802+D802+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A912+D912+A913+D913+A915+D915+A916+A917+D917+A918+D918
+
     419,Link L001
     419,DevCmd A010
     419,WP A100
@@ -1093,6 +1268,7 @@ array set PSPID {
     419,nospec A900,A902,A903
 
     421,Link L001
+    421,Baud T001
     421,DevCmd A010
     421,WP A100
     421,WPData D110
@@ -1116,6 +1292,7 @@ array set PSPID {
     421,nospec A601+D601+A900+A902+A903+A904+A907+D907+D908+D909+D910+A908+D911+A914+A916+A917+D917+A918+D918
 
     450,Link L001
+    450,Baud T001
     450,DevCmd A010
     450,WP A100
     450,WPData D110
@@ -1137,7 +1314,46 @@ array set PSPID {
     450,PVTData D800
     450,nospec A601+D601+A801+D801+A902+A903+A907+D907+D908+D909+D910+A918+D918+A1000+D1009+A906+D1011+A1002+D1008+A1003+D1003+A1004+D1004+A1005+D1005+A1006+D1006+A1007+D1007+A1008+D1012+A1009+D1013
 
+    481,Link L001
+    481,Baud T001
+    481,DevCmd A010
+    481,WP A100
+    481,WPData D110
+    481,RT N/A
+    481,TR N/A
+    481,Prx N/A
+    481,AL A500
+    481,ALData D501
+    481,DtTm A600
+    481,DtTmData: D600
+    481,FleetManagement A602+A603
+    481,FMData D602+D603
+    481,Posn A700
+    481,PosnData D700
+    481,PVT A800
+    481,PVTData D800
+    481,nospec A101+D120+D110+D210+A601+D601+A802+D802+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A912+D912+A913+D913+A916+A917+D917+A918+D918+A919
+
+    497,Link L001
+    497,Baud T001
+    497,DevCmd A010
+    497,WP A100
+    497,WPData D110
+    497,RT N/A
+    497,TR N/A
+    497,Prx N/A
+    497,AL A500
+    497,ALData D501
+    497,DtTm A600
+    497,DtTmData: D600
+    497,Posn A700
+    497,PosnData D700
+    497,PVT A800
+    497,PVTData D800
+    497,nospec A101+D120+D110+D210+A601+D601+A802+D802+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A912+D912+A913+D913+A916+A917+D917+A918+D918+A919
+
     532,Link L001
+    532,Baud T001
     532,DevCmd A010
     532,WP A100
     532,WPData D110
@@ -1180,14 +1396,19 @@ array set PSDIFF {
    136  {177 {nospec A802+D802+A900+A902+A903}}
    111+ {111 {WPData D109} {RTWPData D109} {PrxWPData D109}}
    112  {59 {WPData D152} {RTWPData D152} {ALData D501}}
+   126  {145 {nospec A900+A902+A903}}
    155  {145 {nospec A900+A902+A903+A904}}
    197  {177 {Prx N/A}}
+   219  {248 {nospec A900+A902+A903}}
    256  {248 {nospec A802}}
-   264  {291 {nospec T001+A802+D802+A900+A902+A903}}
-   289+ {289 {nospec A601+D601+A900+A902+A903+A904+A907+D908+D909+D910+A914+A1010+A1011}}
+   264  {291 {Baud T001} {nospec A802+D802+A900+A902+A903}}
+   289+ {289 {nospec A601+D601+A900+A902+A903+A904+A907+D907+D908+D909+D910+A914+A1010+A1011}}
    411  {419 {nospec A802+D802+A900+A902+A903}}
-   484  {450 {AL N/A} {nospec A601+D601+A902+A903+A907+D908+D908+D909+D910+A1000+D1009+A906+D1011+A1000+D1009+A1002+D1008+A1003+D1003+A1004+D1004+A1005+D1005+A1006+D1006+A1007+D1007+A1008+D1012+A1009+D1013}}
-   484+ {450 {nospec A601+D601+A801+D801+A902+A903+A907+D908+D908+D909+D910+A918+D918+A1000+D1009+A906+D1015+A1002+D1008+A1003+D1003+A1004+D1004+A1005+D1005+A1006+D1006+A1007+D1007+A1008+D1012+A1009+D1013+A1013+D1014}}
+   439  {177 {nospec A800+D801+A802+D802+A900+A902+A903}}
+   484  {450 {AL N/A} {nospec A601+D601+A902+A903+A907+D907+D908+D909+D910+A1000+D1009+A906+D1011+A1000+D1009+A1002+D1008+A1003+D1003+A1004+D1004+A1005+D1005+A1006+D1006+A1007+D1007+A1008+D1012+A1009+D1013}}
+   484+ {450 {nospec A601+D601+A801+D801+A902+A903+A907+D907+D908+D909+D910+A918+D918+A1000+D1009+A906+D1015+A1002+D1008+A1003+D1003+A1004+D1004+A1005+D1005+A1006+D1006+A1007+D1007+A1008+D1012+A1009+D1013+A1013+D1014}}
+   694  {421 {nospec A601+D601+A801+D801+A900+A902+A903+A904+A907+D907+D908+D909+D910+A908+D911+A914+A916+A917+D917+A918+D918}}
+   694+ {421 {nospec A601+D601+A801+D801+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A914+A916+A917+D917+A918+D918}}
 }
 
 ## descriptions, positions in Garmin structures of GPSMan data
