@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 #      along with this program.
 #
 #  File: gendials.tcl
-#  Last change:  16 April 2007
+#  Last change:  27 September 2008
 #
 # Includes contributions by
-#  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
-#  - Stefan Heinen (stefan.heinen@djh-freeweb.de) marked "SH contribution"
+#  - Brian Baulch (baulchb_AT_onthenet.com.au) marked "BSB contribution"
+#  - Stefan Heinen (stefan.heinen_AT_djh-freeweb.de) marked "SH contribution"
 #
 
   # modal dialogs
@@ -33,7 +33,7 @@ proc GMMessage {mess args} {
     # single button: OK; binding: return
     global COLOUR EPOSX EPOSY TXT UNIX CMDLINE
 
-    if { $CMDLINE} {
+    if { $CMDLINE } {
 	puts stderr $mess
 	flush stderr
 	return
@@ -42,8 +42,32 @@ proc GMMessage {mess args} {
 	SlowOpMessage $mess
 	return
     }
+    if { [winfo exists .mess] } {
+	# add new message
+	foreach s [pack slaves .mess.fr] {
+	    if { $s == ".mess.fr.ok" } { break }
+	    set last $s
+	}
+	if { ! [regexp {^\.mess\.fr\.text(.*)$} $last x n] } {
+	    BUG bad last message field in .mess
+	    return
+	}
+	if { $n == "" } {
+	    set n 1
+	} else {
+	    if { $n == 4 } {
+		.mess.fr.text4 configure -text $mess
+		update idletasks
+		return
+	    }
+	    incr n
+	}
+	label .mess.fr.text$n -text $mess
+	pack .mess.fr.text$n -side top -pady 5 -before .mess.fr.ok
+	update idletasks
+	return
+    }
     # this avoids bugs but may create havoc with grabs
-    destroy .mess
     set gs [grab current]
     toplevel .mess
     if { ! $UNIX } {
@@ -62,6 +86,8 @@ proc GMMessage {mess args} {
     label .mess.fr.text -text $mess
     button .mess.fr.ok -text Ok -command [list DestroyRGrabs .mess $gs]
     pack .mess.fr -side top
+    # changes in packing order must be reflected above when adding
+    #  new messages to existing window
     pack .mess.fr.title .mess.fr.text .mess.fr.ok -side top -pady 5
     RaiseWindow .mess
     update idletasks
@@ -111,10 +137,13 @@ proc GMConfirm {mess} {
 }
 
 proc GMSelect {mess blist vlist} {
-    # create modal dialog for selecting one element from list $blist
-    #  with associated return values in $vlist
-    # buttons are created for each list element
-    #  bindings: return for first, delete for last element
+    # create modal dialog for selecting values from $vlist under names in
+    #  $blist; if an element in $blist has the form  @LIST  then the
+    #  corresponding $vlist element is a list with one less element than LIST
+    # menubuttons are created for each @LIST element whose label is the
+    #  first element of LIST, buttons being used for the other elements
+    #  bindings: return for first, delete for last element, or their
+    #   first elements in case of @LIST
     # (see proc GMChooseFrom for selection using a listbox)
     global GMResSel COLOUR EPOSX EPOSY TXT
 
@@ -127,27 +156,49 @@ proc GMSelect {mess blist vlist} {
     wm title .messres "$TXT(selection)/GPS Manager"
     wm transient .messres .
     wm geometry .messres +$EPOSX+$EPOSY
-    bind .messres <Key-Return> "set GMResSel [lindex $vlist 0]"
-    bind .messres <Key-Delete> "set GMResSel [lindex $vlist end]"
+    set e [lindex $blist 0]
+    if { [string first "@" $e] == 0 } {
+	set e [lindex [lindex $vlist 0] 0]
+    } else { set e [lindex $vlist 0] }
+    bind .messres <Key-Return> "set GMResSel $e"
 
     frame .messres.fr -borderwidth 5 -bg $COLOUR(selbg)
     label .messres.fr.title -text "???" -relief sunken
     label .messres.fr.text -text $mess
     frame .messres.fr.frsel
-    set max 4 ; set c 0 ; set r 0
+    set max 4 ; set c 0 ; set r 0 ; set lval "" ; set menus 0
     foreach e $blist v $vlist {
-	button .messres.fr.frsel.b$e -text $e -command "set GMResSel $v"
-	grid .messres.fr.frsel.b$e -column $c -row $r -sticky ew
+	set b .messres.fr.frsel.b$r$c
+	if { [regexp {^@(.+)$} $e x e] } {
+	    if { [llength $e] != [llength $v]+1 } {
+		BUG GMSelect bad lengths of @LIST lists
+	    }
+	    incr menus
+	    set lval [lindex $v 0]
+	    menubutton $b -text [lindex $e 0] -menu $b.m
+	    menu $b.m
+	    foreach x [lreplace $e 0 0] y $v {
+		$b.m add command -label $x -command "set GMResSel $y"
+	    }
+	} else {
+	    set lval $v
+	    button $b -text $e -command "set GMResSel $v"
+	}
+	grid $b -column $c -row $r -sticky ew
 	if { [incr c] >= $max } {
 	    set c 0 ; incr r
 	}
     }
+    bind .messres <Key-Delete> "set GMResSel $lval"
+
     pack .messres.fr -side top
     pack .messres.fr.title .messres.fr.text .messres.fr.frsel -side top -pady 5
     set gs [grab current]
     update idletasks
     grab .messres
-    RaiseWindow .messres
+    if { $menus } {
+	Raise .messres
+    } else { RaiseWindow .messres }
     tkwait variable GMResSel
     DestroyRGrabs .messres $gs
     update idletasks
@@ -321,11 +372,14 @@ proc GMChooseParams {mess vars descs} {
 
 ##### information window
 
-proc DisplayInfo {mess} {
+proc DisplayInfo {mess args} {
     # display information on a dialog
     # the dialog is created if it not exists, otherwise the message
     #  will be added to it
-    global CMDLINE COLOUR EPOSX EPOSY TXT FixedFont
+    #  $args may be "" or  "tabs" followed by tabs list (man 3tk text) in
+    #     which negative numbers are to be converted from chars to screen
+    #     distances
+    global CMDLINE COLOUR EPOSX EPOSY TXT FixedFont DInfo
 
     if { $CMDLINE } { return }
 
@@ -341,7 +395,7 @@ proc DisplayInfo {mess} {
 	label .gminfo.fr.title -text $TXT(info) -relief sunken
 
 	frame $frt -relief flat -borderwidth 0
-	text $frt.txt -width 70 -font $FixedFont -wrap word \
+	text $frt.txt -width 80 -font $FixedFont -wrap word \
 	    -exportselection 1 -yscrollcommand "$frt.tscrl set"
 	bind $frt.txt <space> "$frt.txt yview scroll 1 pages ; break"
 	bind $frt.txt <Key-Delete> "$frt.txt yview scroll -1 pages ; break"
@@ -361,8 +415,42 @@ proc DisplayInfo {mess} {
 	grid config $frb.ok -column 1 -row 0
 	pack .gminfo.fr.title $frt $frb -side top -pady 5
 	pack .gminfo.fr
+
+	# info on this window
+	catch {unset DInfo}
+	# to help setting tabs, make public the "ex" in pixels
+	set x20 "xxxxxxxxxxxxxxxxxxxx"
+	set DInfo(ex) [expr round([font measure $FixedFont $x20]/20.0)]
+	# number of next free tag; tags will have names started by "itg"
+	set DInfo(nxttag) 1
     }
-    $frt.txt insert end "$mess\n"
+    if { $args != "" } {
+	set tags ""
+	switch -- [lindex $args 0] {
+	    tabs {
+		set tlst ""
+		foreach x [lindex $args 1] {
+		    if { [regexp {^-([0-9]+)$} $x m n] } {
+			# to pixels
+			set x [expr $n*$DInfo(ex)]
+		    }
+		    lappend tlst $x
+		}
+		if { [catch {set tgname $DInfo($tlst)}] } {
+		    set tgname itg$DInfo(nxttag)
+		    incr DInfo(nxttag)
+		    $frt.txt tag configure $tgname -tabs $tlst
+		    set DInfo($tlst) $tgname
+		}
+		lappend tags $tgname
+	    }
+	    default {
+		BUG bad args to DisplayInfo
+		return
+	    }
+	}
+	$frt.txt insert end "$mess\n" $tags
+    } else { $frt.txt insert end "$mess\n" }
     $frt.txt see end
     update idletasks
     return
@@ -373,7 +461,7 @@ proc SaveDisplayInfo {wtxt} {
     global TXT
 
     if { [set txt [$wtxt get 1.0 end]] == "" || \
-	     [set f [GMOpenFile $TXT(saveto) Plot w]] == ".." } { return }
+	     [set f [GMOpenFile $TXT(saveto) Info w]] == ".." } { return }
     puts $f $txt
     close $f
     return
@@ -886,21 +974,24 @@ proc GMSetupParams {w vars descs} {
 		}
 		label $w.f$i.l$v -text $lab
 		pack $w.f$i.l$v -side left
+		set k 0
 		foreach o $lst {
-		    radiobutton $w.f$i.r$o -text $o -variable $v \
+		    radiobutton $w.f$i.r$k -text $o -variable $v \
 			    -value $o -anchor w -selectcolor $COLOUR(check)
-		    pack $w.f$i.r$o -side left -padx 2
+		    pack $w.f$i.r$k -side left -padx 2
+		    incr k
 		}
-		$w.f$i.r[lindex $lst 0] invoke
+		$w.f$i.r0 invoke
 	    }
 	    default {
-		set d 1
+		set k 0
 		foreach o $os {
-		    radiobutton $w.f$i.r$o -text $o -variable $v \
+		    radiobutton $w.f$i.rdef$k -text $o -variable $v \
 			    -value $o -anchor w -selectcolor $COLOUR(check)
-		    if { $d } { $w.f$i.r$o invoke ; set d 0 }
-		    pack $w.f$i.r$o -side left -padx 2
+		    pack $w.f$i.rdef$k -side left -padx 2
+		    incr k
 		}
+		$w.f$i.rdef0 invoke
 	    }
 	}
 	pack $w.f$i -side top -fill x -expand 1
