@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: geod.tcl
-#  Last change:  17 April 2006
+#  Last change:  15 September 2008
 #
 
 ## Most of the geodetic information herein taken or adopted from
@@ -39,30 +39,33 @@
 #
 ## Some geodetic information kindly provided by
 #      Luisa Bastos, Universidade do Porto
+#      Attila Berenyi (berenyi.attila _AT_ gmail.com)
 ##
 #
 ## Some more definitions taken from:
-#      - the PROJ4.0 package by Gerald I. Evenden (gie@kai.er.usgs.gov)
+#      - the PROJ4.0 package by Gerald I. Evenden (gie _AT_ kai.er.usgs.gov)
 #      - (Austrian Datum), http://homepage.ntlworld.com/anton.helm/bmn_mgi.html
 #      - GPSTrackMaker by Odilon Ferreira (www.gpstm.com)
+#      - Hungarian Datum 72: http://ftp/gps/honlap-jan2002.pdf, September 2008
 ##
 #
 ## New way of representing datums with GDATUM and ELLPSDDEF arrays, and
 #   proc EllipsdData based on contribution by Stefan Heinen
-#   (stefan.heinen@djh-freeweb.de)
+#   (stefan.heinen _AT_ djh-freeweb.de)
 ##
 
 proc EllipsdData {datum} {
     # based on contribution by Stefan Heinen
     # yield the ellipsoid data for datum as a list with
-    #    a - semi-major axis
-    #    f - flattening
+    #    a - semi-major axis (as float)
+    #    f - flattening (as float)
     #    dx, dy, dz - translation of center
     global GDATUM ELLPSDDEF
 
     set d [lrange $GDATUM($datum) 0 3]
     set def $ELLPSDDEF([lindex $d 0])
-    return [lreplace $d 0 0 [lindex $def 0] [expr 1.0/[lindex $def 1]]]
+    return [lreplace $d 0 0 \
+		[expr 1.0*[lindex $def 0]] [expr 1.0/[lindex $def 1]]]
 }
 
 proc EllipsdOf {datum} {
@@ -123,9 +126,9 @@ proc FillDatumMenu {menu commdargs args} {
 		   "European 1950; Portugal+Spain" "European 1950; Tunisia"] \
 		"European 1979" \
 		"Finland Hayford" "Graciosa Base SW 1948" "Hermannskogel" \
-		"Hermannskogel; old Yugoslavia" "Hjorsey 1955" "Ireland 1965" \
-		"Lisboa" "NGO 1948" Norsk \
-	        "NTF (Nouvelle Triangulation de France)" \
+		"Hermannskogel; old Yugoslavia" "Hjorsey 1955" \
+	        "Hungarian Datum 1972" "Ireland 1965" "Lisboa" "NGO 1948" \
+	        Norsk "NTF (Nouvelle Triangulation de France)" \
 		"NTF (NTF ellipsoid)" \
 		"Observatorio 1966" \
 		@ [list "Ord Srvy Grt Britn" \
@@ -1335,6 +1338,10 @@ array set GDATUM {
 "Deutsches Hauptdreiecksnetz" { "Bessel 1841"
     598.1 73.7 418.2
     gm164 ""}
+
+"Hungarian Datum 1972" { "GRS 67"
+    56.91 -70.18 -9.49
+    gm165 "ftp/gps/honlap-jan2002.pdf"}
 }
 
 ###### known ellipsoids
@@ -1386,7 +1393,7 @@ proc FillEllipsoidMenu {menu commdargs} {
 ## ellipsoid definitions
 # indexed by name
 # each list has:
-#  - a (semi-major axis in metre), invf (inverse of flattening)
+#  - a (semi-major axis in metre, float), invf (inverse of flattening)
 #  - comment
 
 ## those after "WGS 66" until "Walbeck" were taken from PROJ4.0
@@ -1394,9 +1401,9 @@ proc FillEllipsoidMenu {menu commdargs} {
 array set ELLPSDDEF {
 "Airy 1830" {6377563.396 299.3249646 "used in Great Britain"}
 
-"Andrae 1876" {6377104.43 300 "used in Denmark, Iceland"}
+"Andrae 1876" {6377104.43 300.0 "used in Denmark, Iceland"}
 
-"Appl. Physics. 1965" {6378137 298.25 ""}
+"Appl. Physics. 1965" {6378137.0 298.25 ""}
 
 "Australian National" {6378160.0   298.25 ""}
 
@@ -1417,7 +1424,7 @@ array set ELLPSDDEF {
 
 "Comm. des Poids et Mesures 1799" {6375738.7 334.29 ""}
 
-"Delambre 1810" {6376428 311.5 "used in Belgium"}
+"Delambre 1810" {6376428.0 311.5 "used in Belgium"}
 
 "Engelis 1985" {6378136.05 298.2566 ""}
 
@@ -1435,64 +1442,64 @@ array set ELLPSDDEF {
 "Everest (Sabah Sarawak)" {6377298.556    300.8017
  "also known as: Everest (E. Malaysia, Brunei"}
 
-"Fischer 1960 (Mercury)" {6378166   298.3 ""}
+"Fischer 1960 (Mercury)" {6378166.0   298.3 ""}
 
-"Fischer 1968" {6378150 298.3 ""}
+"Fischer 1968" {6378150.0 298.3 ""}
 
-"GRS 67" {6378160   298.247167427 "used in Australia"}
+"GRS 67" {6378160.0   298.247167427 "used in Australia and Hungary"}
 
-"GRS 75" {6378140   298.257 ""}
+"GRS 75" {6378140.0   298.257 ""}
 
 "GRS 80" {6378137.0   298.257222101 "used in Australia"}
 
 "Helmert 1906" {6378200.0   298.3 ""}
 
-"Hough 1956" {6378270   297 ""}
+"Hough 1956" {6378270.0   297.0 ""}
 
 "Hough 1960" {6378270.0   297.0 ""}
 
-"IAU 1976" {6378140 298.257 ""}
+"IAU 1976" {6378140.0 298.257 ""}
 
 "Indonesian 1974" {6378160.0   298.247 ""}
 
 "International 1924" {6378388.0   297.0 "used in Europe, New Zealand"}
 
-"Israeli" {6377973 293.466001939}
+"Israeli" {6377973.0 293.466001939}
 
-"Kaula 1961" {6378163 298.24 ""}
+"Kaula 1961" {6378163.0 298.24 ""}
 
 "Krassovsky 1940" {6378245.0 298.3
  "used in Russia; also known as: Krassovsky 1942)"}
 
-"Lerch 1979" {6378139 298.257 ""}
+"Lerch 1979" {6378139.0 298.257 ""}
 
-"MERIT 1983" {6378137 298.257 ""}
+"MERIT 1983" {6378137.0 298.257 ""}
 
-"Maupertius 1738" {6397300 191 ""}
+"Maupertius 1738" {6397300.0 191.0 ""}
 
 "Modified Airy" {6377340.189 299.3249646 ""}
 
 "Modified Fischer 1960" {6378155.0   298.3 ""}
 
-"NWL9D" {6378145 298.25 "Naval Weapons Lab., 1965"}
+"NWL9D" {6378145.0 298.25 "Naval Weapons Lab., 1965"}
 
-"NTF" {6378025 303.20855706 "Nouvelle Triangulation de France"}
+"NTF" {6378025.0 303.20855706 "Nouvelle Triangulation de France"}
 
-"Plessis 1817" {6376523 308.640997 "used in France"}
+"Plessis 1817" {6376523.0 308.640997 "used in France"}
 
-"SGS85" {6378136 298.257 "Soviet Geodetic System 85"}
+"SGS85" {6378136.0 298.257 "Soviet Geodetic System 85"}
 
 "South American 1969" {6378160.0   298.25 ""}
 
-"Southeast Asia" {6378155 298.3 ""}
+"Southeast Asia" {6378155.0 298.3 ""}
 
-"WGS 60" {6378165   298.3 ""}
+"WGS 60" {6378165.0   298.3 ""}
 
-"WGS 66" {6378145   298.25 "used in USA/DoD"}
+"WGS 66" {6378145.0   298.25 "used in USA/DoD"}
 
 "WGS 72" {6378135.0   298.26 "used in USA/DoD"}
 
 "WGS 84" {6378137.0   298.257223563 ""}
 
-"Walbeck" {6376896 302.780 ""}
+"Walbeck" {6376896.0 302.780 ""}
 }
