@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: know.tcl
-#  Last change:  6 April 2006
+#  Last change:  3 September 2008
 #
-# Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
+# Includes contributions by Brian Baulch (baulchb_AT_onthenet.com.au)
 #  marked "BSB contribution"
 #
 
@@ -662,7 +662,7 @@ proc ReplaceWPName {name posndat} {
 }
 
 proc SamePosn {ix data} {
-    # check whether WP with given index has the same position as the
+    # check whether the WP with given index has the same position as the
     #  WP with given data even if the datums used are different
     # return either 1, or list with lat, long (in DDD), and datum
     #  for the position of 2nd WP (but in the datum of 1st)
@@ -674,8 +674,7 @@ proc SamePosn {ix data} {
     if { $WPDatum($ix) != $d } {
 	set p [ToDatum [lindex $p 0] [lindex $p 1] $d $WPDatum($ix)]
     }
-    if { [lindex $p 0] == [lindex $WPPosn($ix) 0] && \
-	    [lindex $p 1] == [lindex $WPPosn($ix) 1] } { return 1 }
+    if { [ComputeDist $p $WPPosn($ix) $WPDatum($ix)] < 0.003 } { return 1 }
     return [lreplace $p 2 end $WPDatum($ix)]
 }
 
@@ -688,11 +687,11 @@ proc AddToNB {nb txt} {
     return $txt
 }
 
-proc AddOldNameToObs {data name} {
-    # add old name to remark field of WP
+proc AddOldNameToObs {wh data name} {
+    # add old name to remark field of item of type $wh
     global TXT DataIndex
 
-    set in $DataIndex(WPObs)
+    set in $DataIndex(${wh}Obs)
     set nb [lindex $data $in]
     return [lreplace $data $in $in [AddToNB $nb "$TXT(oname): $name"]]
 }
@@ -718,7 +717,7 @@ proc StoreWP {ix name data todispl} {
 	    return $name
 	}
 	# replace name
-	set data [AddOldNameToObs $data $name]
+	set data [AddOldNameToObs WP $data $name]
 	set name [ReplaceWPName $name $pd]
 	set data [lreplace $data 0 0 $name]
     }
