@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,17 +17,17 @@
 #      along with this program.
 #
 #  File: langdeutsch.tcl
-#  Last change:  30 April 2007
+#  Last change:  30 September 2008
 # German language file by Andreas Lange (Andreas.C.Lange@GMX.de)
 #  last input from him inserted: 31 January 2002
 #
 # Support by Sabine Broda (sbb@ncc.up.pt) since 2002
-#  last input from her inserted:  8 May 2006
+#  last input from her inserted:  30 September 2008
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
 
-# only 3 chars long names; check also ALLMONTH in file gpsman
+# only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "Jan Feb Mr Apr Mai Jun Jul Aug Sep Okt Nov Dez"
 
 set DLUNIT(KM,dist) km
@@ -143,7 +143,7 @@ array set MESS {
     fillbuffRT  "Laden des RT Puffers"
     noACKNAK  "Paket erhalten, ACK/NAK erwartet; GPS Verbindung berprfen!"
     badplatform "Keine Ein-/Ausgabe auf der seriellen Schnittstelle auf dieser Platform"
-    badserial "Kann serielle Schnittstelle %s nicht ffnen"
+    badserial "Kann Gert %s nicht ffnen"
     nodata    "Kein %se im Empfnger"
     badimage "Ungltige Bild-Datei"
     mapadjust "Bitte plazieren Sie die WPe auf der Karte; Ok zum Beenden"
@@ -167,7 +167,7 @@ array set MESS {
     serial2 "Inkorrekter Befehl zurckgegeben"
     checksum1 "Inkorrekte Kopf-Prfsumme"
     checksum2 "Prfsummen-Fehler"
-    receiver "Keine serielle Verbindung!"
+    receiver "Keine Verbindung zum Gert!"
     importonly1 "Kann nur einen Typ Daten importieren"
     exportonly1 "Kann nur einen Typ Daten exportieren"
     outdatedprefs "Prferenz-Datei berholt, bitte jetzt berprfen"
@@ -210,7 +210,7 @@ array set MESS {
     cantchkprot "Kann mit diesem Protokoll nicht festgestellt werden"
     mustconn1st "Zuerst die Verbindung zum Empfnger berprfen"
     rltmnotsupp "Echtzeit-Aufzeichnung wird vom Protokoll dieses Empfngers nicht untersttzt"
-    timeoffnotint "Zeitdifferenz muss eine Ganzzahl sein"
+    timeoffnotint "Zeitdifferenz muss eine Ganzzahl sein oder mit .5 enden"
     abbrevinuse "Abkrzung bereits vergeben"
     nameinuse  "Name ist bereits vergeben"
     badgriddatum "Das Datum fr das Gitternetz %s ist %s"
@@ -294,8 +294,17 @@ array set MESS {
     abbrevhasspaces "Abkrzungen drfen keine Leerzeichen haben"
     getAL "Empfangen des Almanachs"
     needNpoints "Mindestens %s Punkten mu ausgewhlt werden!"
+    twotimeoffsets "Verschiedene Zeitdifferenzen in Datei"
+    notimeoffset "Keine Zeitdifferenz in Datei; Defaultwert ist 0"
+    baddateas "Ungltiges Datum: %s"
+    unknownenc "Unbekannte Zeichenkodierung %s"
+    chgbaudto "Baudrate wird bis %s gendert; bitte warten..."
+    baudchgfailed "Baudratennderung ohne Erfolg"
+    busytrylater "Andere Vorgnge in Bearbeitung; bitte spter versuchen!"
+    obssplit "Teilungsergebnis von %s in der Gruppe mit Name \"%s\""
 }
 
+
 set TXT(RTcompflds) "# WP {$DTUNIT} Grad {$ALUNIT} Etappe Bezeichnung"
 set TXT(TRcompflds) \
     "TP {} {} {} {$ALUNIT} {$DTUNIT} {$DTUNIT} h:m:s {$SPUNIT} Grad"
@@ -489,8 +498,8 @@ array set TXT {
     optMAPCOLOUR,anim  "Karten-Animation"
     optMAPCOLOUR,emptygrid  "Leeres Bild"
     optMAPCOLOUR,fullgrid   "Bestehendes Bild"
-    opt_Files "Seriell Schnittstelle & Dateien"
-    optDEFSPORT "Seriell Schnittstelle"
+    opt_Files "Gert & Dateien"
+    optDEFSPORT "Gert"
     optPERMS   "Dateirechte"
     optPAPERSIZE "Papiergre"
     red   Rot
@@ -1210,6 +1219,30 @@ array set TXT {
     alm_health "Gesundheit"
     lstsqs  "Kleinsten Quadrate"
     lstsqsfile "Kl. Quadrate Datei"
+    totdstng "Gesamte Entfernung, ohne Lcken"
+    tottimeng "Gesamte Zeit, ohne Lcken"
+    SYcross "Fadenkreuz"
+    SYcross_3p "Fadenkreuz 3p"
+    mapfitWPs "WPe-Anpassung in der Karte zeigen"
+    showfitinfo "Anpassungsinformation zeigen"
+    xtcoord "xt"
+    ytcoord "yt"
+    delta   "d"
+    residual "rt"
+    rmsxydev "rms(x,y-Abweichungen)"
+    resstderr "Standardfehler der Abweichung"
+    chgdev "Gert wechseln"
+    maxalt "Maximalhhe"
+    minalt "Mindesthhe"
+    alt_cumul "Anstiegssumme"
+    alt_cumuld "Abstiegssumme"
+    optSHOWFILEITEMS "Normalerweise werden gelesene Elemente in der Karte gezeigt"
+    vertgridlines "Gittervertikale"
+    convert  "Konvertieren"
+    split    "Zerteilen"
+    bysel  "an ausgewhlten Punkten"
+    byseg  "an Segmenten"
+    openits "%s ffnen"
 }
 
     # the following definitions must be coherent with $TXT
