@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,16 +17,16 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  17 April 2007
+#  Last change:  15 September 2008
 #
 # Includes contributions by
-#  - Brian Baulch (baulchb@onthenet.com.au)
-#  - Matt Martin (matt.martin@ieee.org)
-#  - Jean H Theoret (ve2za@rac.ca)
-#  - Valere Robin (valere.robin@wanadoo.fr)
-#  - David Gardner (djgardner@users.sourceforge.net)
+#  - Brian Baulch (baulchb _AT_ onthenet.com.au)
+#  - Matt Martin (matt.martin _AT_ ieee.org)
+#  - Jean H Theoret (ve2za _AT_ rac.ca)
+#  - Valere Robin (valere.robin _AT_ wanadoo.fr)
+#  - David Gardner (djgardner _AT_ users.sourceforge.net)
 
-# only 3 chars long names; check also ALLMONTH in file gpsman
+# only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec"
 
 set DLUNIT(KM,dist) km
@@ -141,7 +141,7 @@ array set MESS {
     fillbuffRT  "Loading RT buffer"
     noACKNAK  "Got packet when expecting ACK/NAK; check GPS connection"
     badplatform   "No I/O with serial port in this platform"
-    badserial "Cannot open serial port %s"
+    badserial "Cannot open device %s"
     nodata    "No %ss in receiver"
     badimage "Bad image file"
     mapadjust "Please place WPs on map; click Ok when finished"
@@ -167,7 +167,7 @@ array set MESS {
     serial2 "Incorrect Command returned"
     checksum1 "Incorrect Header Checksum"
     checksum2 "Data Checksum error"
-    receiver "No serial connection!"
+    receiver "Not connected to device!"
     importonly1 "Can only import 1 kind of data"
     exportonly1 "Can only export 1 kind of data"
     outdatedprefs "Preferences file outdated; please check it now"
@@ -207,7 +207,7 @@ array set MESS {
     baddistunit "Bad distance unit for map scale in preferences file"
     badgridzone "Invalid grid zone"
     outofgrid "Position out of grid scope"
-    timeoffnotint "Time offset must be an integer"
+    timeoffnotint "Time offset must be an integer or end in .5"
     cantchkprot "Cannot check under current protocol"
     mustconn1st "Check connection with receiver first"
     rltmnotsupp "Real time log not supported by protocol in this receiver"
@@ -293,6 +293,14 @@ array set MESS {
     cantwrtmbaks "Cannot write user map backgrounds file"
     abbrevhasspaces "Short name cannot have blanks"
     needNpoints "You must give at least %s points!"
+    twotimeoffsets "Different time offsets in file"
+    notimeoffset "No time offset in file; assuming 0"
+    baddateas "Bad date: %s"
+    unknownenc "Unknown character encoding %s"
+    chgbaudto "Trying to change baud rate to %s; please wait..."
+    busytrylater "Other operations under way; please try later"
+    baudchgfailed "Could not change baud rate"
+    obssplit "Results of splitting %s named \"%s\""
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -392,6 +400,8 @@ array set TXT {
     savecomp "Save computation"
     totdst   "Total distance"
     tottime   "Total time"
+    totdstng   "Total distance, no gaps"
+    tottimeng  "Total time, no gaps"
     track   Track
     chophd   "Chop head"
     choptl   "Chop tail"
@@ -509,8 +519,8 @@ array set TXT {
     optDEFTRTWIDTH "RT line width"
     optDEFTTRWIDTH "TR line width"
     optDEFTLNWIDTH "LN width"
-    opt_Files "Serial port and files"
-    optDEFSPORT "Serial port"
+    opt_Files "Device and files"
+    optDEFSPORT "Device"
     optSAVESTATE "Save state on exit"
     optDELSTATE "Delete files after restoring state"
     optPERMS   "File permissions"
@@ -669,6 +679,8 @@ array set TXT {
     SYcntct_sumo "Sumo"
     SYcoast_guard "Coast guard"
     SYcontrolled "Controlled Area"
+    SYcross "Cross hair"
+    SYcross_3p "Cross hair 3p"
     SYcrossing "Crossing"
     SYdam "Dam"
     SYdanger "Danger"
@@ -1289,6 +1301,27 @@ array set TXT {
     alm_health "health"
     lstsqs  "Least Squares"
     lstsqsfile "Least Squares file"
+    mapfitWPs "Display fit WPs on map"
+    showfitinfo "Show fit information"
+    xtcoord "xt"
+    ytcoord "yt"
+    delta   "d"
+    residual "rt"
+    rmsxydev "rms(x,y-deviations)"
+    resstderr "residual std error"
+    chgdev "Change device"
+    alt_cumul "Cummulative ascent"
+    alt_cumuld "Cummulative descent"
+    maxalt "Maximum altitude"
+    minalt "Minimum altitude"
+    optSHOWFILEITEMS "By default display on map items read in"
+    vertgridlines "Vert Grid Lines"
+    convert  "Convert"
+    split    "Split"
+    bysel  "by selected points"
+    byseg  "by segments"
+    openits "Open %s"
+    PRJEOV  EOV
 }
 
     # the following definitions must be coherent with $TXT
