@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,19 +17,20 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  20 April 2007
+#  Last change:  18 September 2008
 #
-# French language file by Valre Robin (valere.robin@wanadoo.fr)
+# French language file by Valre Robin (valere.robin _AT_ wanadoo.fr)
 #  Last change by him:  11 November 2001
-#  last input from him inserted:  20 April 2007
+#  last input from him inserted:  18 September 2008
 #
-# Includes contributions by Jean H Theoret (ve2za@rac.ca)
-# Includes typo corrections by Laurent Bonnaud (bonnaud@lis.inpg.fr)
+# Includes contributions by Jean H Theoret (ve2za _AT_ rac.ca)
+# Includes contributions by Benoit Steiner (benetsteph _AT_ free.fr)
+# Includes typo corrections by Laurent Bonnaud (bonnaud _AT_ lis.inpg.fr)
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
-# only 3 chars long names; check also ALLMONTH in file gpsman
+# only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "Jan Fev Mar Avr Mai Jun Jul Aou Sep Oct Nov Dec"
 
 set DLUNIT(KM,dist) km
@@ -133,7 +134,7 @@ array set MESS {
     fillbuffRT  "Chargement des buffers de RT"
     noACKNAK  "Rception d'un paquet au lieu de ACK/NAK; vrifier la connexion GPS"
     badplatform   "Pas de port d'entre/sortie"
-    badserial "Ouverture du port srie %s impossible"
+    badserial "Impossibilit d'ouvrir le priphrique %s"
     nodata    "Pas de %ss dans le rcepteur"
     badimage "Fichier image erron"
     mapadjust "Placer les points d'itinraire sur la carte puis cliquer sur Ok"
@@ -157,7 +158,7 @@ array set MESS {
     serial2 "Commande incorrecte"
     checksum1 "Checksum de l'en-tte erron"
     checksum2 "Checksum sur les donnes erron"
-    receiver "Pas de liaison srie!"
+    receiver "Priphrique non connect!"
     importonly1 "Importation d'une seule sorte de donnes"
     exportonly1 "Exportation d'une seule sorte de donnes"
     outdatedprefs "Fichier des prfrences prim ;  vrifier maintenant"
@@ -197,7 +198,7 @@ array set MESS {
     baddistunit "Unit de distance errone pour l'chelle de la carte dans le fichier de prfrences"
     badgridzone "Zone de grille errone"
     outofgrid "Position en dehors du domaine de la grille"
-    timeoffnotint "La valeur de temps doit tre un entier"
+    timeoffnotint "Le dcalage horaire doit tre un entier ou se terminer par .5"
     cantchkprot "Vrification impossible avec le protocole courant"
     mustconn1st "Connexion avec le rcepteur  vrifier"
     rltmnotsupp "Journalisation en temps rel non supporte par ce rcepteur"
@@ -283,6 +284,14 @@ array set MESS {
     abbrevhasspaces "Nom court ne peut pas avoir des blancs"
     getAL  "Acquisition de l'almanach"
     needNpoints "Merci de fournir au moins %s points!"
+    twotimeoffsets "Fichier contenant des dcalages horaires diffrents"
+    notimeoffset "Pas d'information de dcalage horaire, suppos nul"
+    baddateas "Mauvaise format de date: %s"
+    unknownenc "Code de caractre inconnu : %s"
+    chgbaudto "Essai de changement de la vitesse  %s; merci d'attendre..."
+    baudchgfailed "Changement de la vitesse de transfert impossible"
+    busytrylater "Opration en cours; merci d'essayer plus tard"
+    obssplit "Resultat de la fragmentation de la %s nomme \"%s\""
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -474,8 +483,8 @@ array set TXT {
     optMAPCOLOUR,anim  "Animation sur la carte"
     optMAPCOLOUR,emptygrid  "Image vide"
     optMAPCOLOUR,fullgrid   "Image existante"
-    opt_Files "Port srie et fichiers"
-    optDEFSPORT "Port Srie"
+    opt_Files "Priphriques et fichiers"
+    optDEFSPORT "Priphrique"
     optSAVESTATE "Sauvegarde de l'tat en quittant"
     optDELSTATE "Destruction des fichiers aprs avoir restaur l'tat"
     optPERMS   "Permission du fichier"
@@ -1244,6 +1253,32 @@ array set TXT {
     alm_health "sant"
     lstsqs "Moindres carrs"
     lstsqsfile "Fichier des moindres carrs"
+    alt_cumul "Dnivell cumul positif"
+    optSHOWFILEITEMS "Affichage par dfaut des donnes lues"
+    totdstng   "Distance totale, sans les sauts"
+    tottimeng  "Temps total, sans les sauts"
+    SYcross "Croix"
+    SYcross_3p "Croix 3p"
+    mapfitWPs "Affichage des WPs d'ajustement sur la carte"
+    showfitinfo "Affichage des informations d'ajustement"
+    xtcoord "xt"
+    ytcoord "yt"
+    delta   "d"
+    residual "rt"
+    rmsxydev "moyenne quadratique ou rms(x,y-deviations)"
+    resstderr "erreur standard residuelle"
+    chgdev "Changement de priphrique"
+    maxalt "Altitude maximum"
+    minalt "Altitude minimum"
+    alt_cumul "Montes cumules"
+    alt_cumuld "Descentes cumules"
+    optSHOWFILEITEMS "Par dfaut, affichage sur la carte des donnes lues"
+    vertgridlines "Lignes verticales"
+    convert  "Conversion"
+    split    "Fragmentation"
+    bysel  "par points choisis"
+    byseg  "par segments"
+    openits "Ouvrir %s"
 }
 
     # the following definitions must be coherent with $TXT
