@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,15 +17,15 @@
 #      along with this program.
 #
 #  File		: langid.tcl
-#  Last change	:  19 April 2007
+#  Last change	:  14 September 2008
 #
 # Indonesian language file by Tri Agus Prayitno (acuss@bk.or.id)
-#  last input from him inserted:  19 April 2007
+#  last input from him inserted:  14 September 2008
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
-# only 3 chars long names; check also ALLMONTH in file gpsman
+# only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "Jan Feb Mar Apr Mei Jun Jul Agt Sep Okt Nop Des"
 
 set DLUNIT(KM,dist) km
@@ -133,7 +133,7 @@ array set MESS {
     fillbuffRT  "Memanggil penyangga RT"
     noACKNAK  "Menerima paket saat mengharapkan ACK/NAK; periksa koneksi GPS"
     badplatform   "Tidak ada I/O dengan port serial pada platform ini"
-    badserial "Tidak bisa membuka serial %s"
+    badserial "Tidak bisa membuka alat %s"
     nodata    "Tidak ada %ss pada pesawat"
     badimage "File gambar tidak benar"
     mapadjust "Masukkan WP pada peta; dan klik Ok jika sudah selesai"
@@ -157,7 +157,7 @@ array set MESS {
     serial2 "Pengembalian perintah salah"
     checksum1 "Header Checksum salah"
     checksum2 "Data Checksum error"
-    receiver "Tidak ada koneksi serial!"
+    receiver "Tidak tersambung ke alat!"
     importonly1 "Hanya dapat mengimpor 1 jenis data"
     exportonly1 "Hanya dapat mengekspor 1 jenis data"
     outdatedprefs "File konfigurasi sudah basi; mohon periksa sekarang"
@@ -197,7 +197,7 @@ array set MESS {
     baddistunit "Satuan jarak salah untuk sekala peta pada file konfigurasi"
     badgridzone "Zona grid salah"
     outofgrid "Posisi berada di luar rentang grid"
-    timeoffnotint "Ofset waktu harus berupa integer"
+    timeoffnotint "Zona waktu harus dengan bilangan asli atau berakhiran .5"
     cantchkprot "Tidak bisa memeriksa dalam protokol ini"
     mustconn1st "Silakan periksa dulu koneksi ke pesawat GPS"
     rltmnotsupp "Log real-time tidak didukung oleh protokol pada pesawat GPS ini"
@@ -274,6 +274,14 @@ array set MESS {
     distlarge "Jarak terlalu besar!"
     timeconsmg "Operasi ini sangat lama: lanjutkan?"
     needNpoints "Anda harus memasukkan minimal %s titik!"
+    twotimeoffsets "Beda zona waktu dalam file"
+    notimeoffset "Tanpa beda zona waktu dalam file; asumsi 0"
+    baddateas "Tanggal tidak benar: %s"
+    unknownenc "Enkoding karakter tak dikenal %s"
+    chgbaudto "Mencoba mengubah baud rate ke %s; mohon tunggu..."
+    baudchgfailed "Tidak bisa mengubah baud rate"
+    busytrylater "Ada perinta lain yang sedang berjalan, silakan coba lagi nanti"
+    obssplit "Hasil pemisahan %s bernama \"%s\""
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} drj {$ALUNIT} tahap label"
@@ -471,8 +479,8 @@ array set TXT {
     optMAPFONTSIZE "Ukuran huruf pada peta"
     optDEFMAPPROJ "Proyeksi peta"
     optDEFMAPPFRMT "Koordinat peta"
-    opt_Files "Port serial dan file"
-    optDEFSPORT "Port serial"
+    opt_Files "Alat dan file"
+    optDEFSPORT "Alat"
     optSAVESTATE "Simpan keadaan saat keluar"
     optDELSTATE "Hapus file setelah mengembalikan keadaan"
     optPERMS   "Hak akses file"
@@ -1102,6 +1110,26 @@ array set TXT {
     optLNSREACT "Reaksi LN thd mouse"
     syhlpbx "Gunakan klik-kanan untuk\nmengubah daftar elemen"
     lstsqsfile "File Least Squares"
+    totdstng   "Jarak total, tanpa gap"
+    tottimeng  "Waktu total, tanpa gap"
+    SYcross "Tanda plus"
+    SYcross_3p "Tanda plus 3p"
+    mapfitWPs "Tampilkan WP yang masuk peta"
+    showfitinfo "Tampilkan informasi yang masuk peta"
+    rmsxydev "rms(deviasi x,y)"
+    resstderr "std error residual"
+    chgdev "Ganti alat"
+    maxalt "Ketinggian maksimal"
+    minalt "Ketinggian minimal"
+    alt_cumul "Ketinggian pendakian kumulatif"
+    alt_cumuld "Ketinggin penurunan kumulatif"
+    optSHOWFILEITEMS "Secara default tampilkan pada item peta yang dibaca"
+    vertgridlines "Garis Grid Vert"
+    convert  "Konversi"
+    split    "Pisahkan"
+    bysel  "menurut titik terpilih"
+    byseg  "menurut segmen"
+    openits "Buka %s"
 }
 
     # the following definitions must be coherent with $TXT
