@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,14 +17,14 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  19 April 2007
+#  Last change:  24 September 2008
 #  Italian language file by Alessandro Palmas (alpalmas@tin.it)
-#  last input from him inserted:  19 April 2007
+#  last input from him inserted:  24 September 2008
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
-# only 3 chars long names; check also ALLMONTH in file gpsman
+# only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "Gen Feb Mar Apr Mag Giu Lug Ago Set Ott Nov Dic"
 
 set DLUNIT(KM,dist) km
@@ -131,7 +131,7 @@ array set MESS {
     fillbuffWP  "Carico WP buffer"
     fillbuffRT  "Carico RT buffer"
     noACKNAK  "Ricevuto pachetto dati mentre aspettavo ACK/NAK; controllare la connessione con il GPS"
-    badserial "Non posso aprire comunicazione su seriale %s"
+    badserial "Non riesco ad aprire il dispositivo %s"
     nodata    "Non ci sono %s nel ricevitore"
     badimage "File immagine scorretto"
     mapadjust "Posizionare i WP sulla mappa; click su Ok quando si ha finito"
@@ -153,7 +153,7 @@ array set MESS {
     serial2 "Ricevuto Comando scorretto"
     checksum1 "Header Checksum scorretto"
     checksum2 "Data Checksum error"
-    receiver "Assenza di connessione seriale!"
+    receiver "Non connesso al dispositivo!"
     importonly1 "Posso importare solo un tipo di dati"
     exportonly1 "Posso esportare solo un tipo di dati"
     outdatedprefs "File di preferenze vecchio; controllarlo al pi presto"
@@ -199,8 +199,7 @@ array set MESS {
     outofgrid "Posizione fuori griglia"
     mustconn1st "Controllare prima la connessione con il ricevitore"
     rltmnotsupp "Registrazione in Tempo Reale non supportata dal protocollo del ricevitore"
-    timeoffnotint "La differenza oraria deve essere un intero"
-
+    timeoffnotint "La differenza oraria deve essere un intero o terminare in .5"
     createdir "Creare la directory %s e ripartire"
     oktomkdir "Confermi la creazione della directory %s?"
     projnameabbr "Si diano un nome esteso ed un nome breve alla nuova proiezione"
@@ -282,6 +281,14 @@ array set MESS {
     cantwrtmbaks "Impossibile scrivere file mappe background"
     abbrevhasspaces "I nomi corti non debbono contenere spazi"
     needNpoints "Fornire almeno %s punti"
+    twotimeoffsets "Differenti offset tempo nel file"
+    notimeoffset "Nessun offset tempo nel file; presunto 0"
+    baddateas "Data erronea: %s"
+    unknownenc "Codifica carattere %s sconosciuta"
+    chgbaudto "Provo a cambiare baud rate a %s; attendere prego ..."
+    baudchgfailed "Non riesco a cambiare baud rate"
+    busytrylater "Altra operazione in corso; prego riprovare pi tardi"
+    obssplit "Risultato della suddivisione: %s chiamato \"%s\""
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -460,8 +467,8 @@ array set TXT {
     optMAPCOLOUR,anim       "Animazione su mappa"
     optMAPCOLOUR,emptygrid  "Immagine vuota"
     optMAPCOLOUR,fullgrid   "Immagine esistente"
-    opt_Files "Serial port and files"
-    optDEFSPORT "I/O seriale"
+    opt_Files "Dispositivi e file"
+    optDEFSPORT "Device"
     optPERMS   "Permessi file"
     optPAPERSIZE "Formato carta"
     red   Rosso
@@ -1189,6 +1196,30 @@ array set TXT {
     alm_health "salute"
     lstsqs "Minimi Quadrati"
     lstsqsfile "file Min Quadrati"
+    totdstng   "Distanza totale, senza separazioni"
+    tottimeng  "Tempo totale, senza separazioni"
+    SYcross "Mirino"
+    SYcross_3p "Mirino 3p"
+    mapfitWPs "Mostra WP usati per minimi quadrati"
+    showfitinfo "Mostra info sui minimi quadrati"
+    xtcoord "xt"
+    ytcoord "yt"
+    delta   "d"
+    residual "rt"
+    rmsxydev "rms(deviazioni x,y)"
+    resstderr "errore std residuo"
+    chgdev "Cambia dispositivo"
+    maxalt "Altitudine massima"
+    minalt "Altitudine minima"
+    alt_cumul "Altezza cumulativa di salita"
+    alt_cumuld "Discesa cumulativa"
+    optSHOWFILEITEMS "Mostra di default sulla mappa gli oggetti leti da file"
+    vertgridlines "Linee Vert Griglia"
+    convert  "Converti"
+    split    "Dividi"
+    bysel  "per punti selezionati"
+    byseg  "per segmenti"
+    openits "Apri %s"
 }
 
     # the following definitions must be coherent with $TXT
