@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,15 +17,15 @@
 #      along with this program.
 #
 #  File: langnl.tcl
-#  Last change:  20 April 2007
+#  Last change:  22 September 2008
 #  Dutch language file by Rob Buitenhuis (rob@buitenhs.demon.nl)
-#  last input from him inserted: 20 April 2007
+#  last input from him inserted: 22 September 2008
 #
 # 
 #  file langengl.tcl is consulted first; no need for duplicating entries here
 
 
-# only 3 chars long names; check also ALLMONTH in file gpsman
+# only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "jan feb mrt apr mei jun jul aug sep okt nov dec"
 
 set DLUNIT(KM,dist) km
@@ -140,7 +140,7 @@ array set MESS {
     fillbuffRT  "Laden van de RT buffer"
     noACKNAK  "Packet ontvangen, verwachte ACK/NAK; GPS verbindung controleren!"
     badplatform "Geen I/O via seriele poort op dit platform"
-    badserial "Kan seriele poort %s niet openen"
+    badserial "Kan device %s niet openen"
     nodata    "Geen %s's in ontvanger"
     badimage "Niet geldig beeld-bestand"
     mapadjust "Plaats a.u.b. WP's op de kaart; Ok om te stoppen"
@@ -164,7 +164,7 @@ array set MESS {
     serial2 "Onjuist commando verkregen"
     checksum1 "Onjuiste header checksum"
     checksum2 "checksum-fout in de gegevens"
-    receiver "Geen seriele verbinding!"
+    receiver "Niet verbonden met device!"
     importonly1 "Kan slechts 1 type gegevens importeren"
     exportonly1 "Kan slechts 1 type gegevens exporteren"
     outdatedprefs "Instellingen-bestand verouderd, controleer het nu a.u.b."
@@ -202,7 +202,7 @@ array set MESS {
     baddistunit "Niet geldige eenheid voor de kaartschaal in het instellingenbestand"
     badgridzone "Niet geldige grid-zone"
     outofgrid "Positie buiten de definitie van het bereik van het grid"
-    timeoffnotint "Tijdsverschil moet een geheel getal zijn"
+    timeoffnotint "Tijdsverschuiving moet integer zijn of eindigen op .5"
     cantchkprot "Kan met dit protocol niet gecontroleerd worden"
     mustconn1st "Eerst de verbinding met de ontvanger controleren"
     rltmnotsupp "Ware tijd wordt niet ondersteund door het protocol in deze ontvanger"
@@ -291,6 +291,14 @@ array set MESS {
     abbrevhasspaces "Afgekorte naam mag geen spaties bevatten"
     getAL   "Verkrijgen almanak"
     needNpoints "U moet tenminste %s punten opgeven!"
+    twotimeoffsets "Verschillende tijdsverschuiving in file"
+    notimeoffset "Geen tijdsverschuiving in file; veronderstel 0"
+    baddateas "Slechte datum: %s"
+    unknownenc "Onbekende karakter-encoding %s"
+    chgbaudto "Probeer de baud rate te veranderen naar %s; wacht aub..."
+    baudchgfailed "Kon baud rate niet veranderen"
+    busytrylater "Bezig met andere bewerkingen; aub later herhalen"
+    obssplit "Resultaat opsplitsen van %s met naam \"%s\""
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} graad {$ALUNIT} et. beschr."
@@ -487,8 +495,8 @@ array set TXT {
     optMAPCOLOUR,anim  "Kaart-animatie"
     optMAPCOLOUR,emptygrid  "Blanco afbeelding"
     optMAPCOLOUR,fullgrid   "Bestaand afbeelding"
-    opt_Files "Seriele poort en bestanden"
-    optDEFSPORT "Seriele poort"
+    opt_Files "Device en files"
+    optDEFSPORT "Device"
     optPERMS   "Bestandsrechten"
     optPAPERSIZE "Papiergrootte"
     red   Rood
@@ -1222,6 +1230,30 @@ array set TXT {
     alm_health "geldigheid"
     lstsqs "Kl. kwadraten"
     lstsqsfile "Kl. kwadr. bestand"
+    totdstng   "Totale afstand, zonder onderbrekingen"
+    tottimeng  "Totale tijd, zonder onderbrekingen"
+    SYcross "Kruis"
+    SYcross_3p "Kruis 3p"
+    mapfitWPs "Toon WPs vd fit op kaart"
+    showfitinfo "Toon informatie vd fit"
+    xtcoord "xt"
+    ytcoord "yt"
+    delta   "d"
+    residual "rt"
+    rmsxydev "rms(x,y-deviaties)"
+    resstderr "resulterende std fout"
+    chgdev "Verander device"
+    maxalt "Maximum hoogte"
+    minalt "Minimum hoogte"
+    alt_cumul "Cummulatief klimhoogte"
+    alt_cumuld "Cummulatief afdaling"
+    optSHOWFILEITEMS "Toon standaard de ingelezen zaken"
+    vertgridlines "Vert Grid Lijnen"
+    convert  "Converteer"
+    split    "Splits"
+    bysel  "via geselecteerde punten"
+    byseg  "via segmenten"
+    openits "Open %s"
 }
 
     # the following definitions must be coherent with $TXT
