@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,12 +17,12 @@
 #      along with this program.
 #
 #  File: langport.tcl
-#  Last change:  16 April 2007
+#  Last change:  30 September 2008
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
-# only 3 chars long names; check also ALLMONTH in file gpsman
+# only 3 chars long names; check also ALLMONTH in file i18n-utf8.tcl
 set MONTHNAMES "Jan Fev Mar Abr Mai Jun Jul Ago Set Out Nov Dez"
 
 set DLUNIT(KM,dist) km
@@ -136,7 +136,7 @@ array set MESS {
     fillbuffRT  "A carregar depsito de RTs"
     noACKNAK  "Pacote recebido em vez de ACK/NAK; verifique a ligao ao GPS"
     badplatform   "Esta plataforma no suporta E/S na porta srie"
-    badserial "Sem acesso  porta srie %s"
+    badserial "Sem acesso  porta %s"
     nodata    "O receptor no tem %ss"
     badimage "Ficheiro de imagem no aceite"
     mapadjust "Coloque os PTs no mapa; carregue depois em Ok"
@@ -162,7 +162,7 @@ array set MESS {
     serial2 "Recebido comando errado"
     checksum1 "Soma de verificao do cabealho errada"
     checksum2 "Soma de verificao de dados errada"
-    receiver "Sem ligao srie!" 
+    receiver "Sem ligao  porta!" 
     importonly1 "S pode importar 1 tipo de dados"
     exportonly1 "S pode exportar 1 tipo de dados"
     outdatedprefs "Ficheiro de opes tem de ser actualizado"
@@ -202,7 +202,7 @@ array set MESS {
     baddistunit "Unidade de distncia errada para escala do mapa nas opes"
     badgridzone "Zona de grelha errada"
     outofgrid "Posio no coberta pela grelha"
-    timeoffnotint "Diferena horria tem de ser inteira"
+    timeoffnotint "Diferena horria tem de ser inteira ou terminar em .5"
     cantchkprot "Este protocolo no permite verificar"
     mustconn1st "Primeiro verifique a ligao ao receptor"
     rltmnotsupp "Este protocolo neste receptor no faz registo em tempo real"
@@ -289,6 +289,14 @@ array set MESS {
     cantwrtmbaks "No posso escrever no ficheiro de mapas"
     abbrevhasspaces "Abreviatura no pode ter espaos"
     needNpoints "Precisa de pelo menos %s pontos!"
+    twotimeoffsets "Mais que uma diferena horria no ficheiro"
+    notimeoffset "Falta diferena horria no ficheiro; usarei 0"
+    baddateas "Data errada: %s"
+    unknownenc "Codificao de caracteres desconhecida: %s"
+    chgbaudto "A mudar baud rate para %s; por favor espere..."
+    busytrylater "Outras operaes em curso; tente mais tarde"
+    baudchgfailed "Mudana de baud rate falhou"
+    obssplit "Resultados de cortar %s com nome \"%s\""
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grau {$ALUNIT} etapa etiq"
@@ -385,6 +393,8 @@ array set TXT {
     savecomp "Guardar clculos"
     totdst   "Distncia total"
     tottime   "Tempo total"
+    totdstng   "Distncia total, s/ falhas"
+    tottimeng  "Tempo total, s/ falhas"
     track   Trajecto
     chophd   "Cortar cabea"
     choptl   "Cortar cauda"
@@ -500,8 +510,8 @@ array set TXT {
     optDEFTRTWIDTH "Espessura RT"
     optDEFTTRWIDTH "Espessura TR"
     optDEFTLNWIDTH "Espessura LN"
-    opt_Files "Porta srie e ficheiros"
-    optDEFSPORT "Porta srie"
+    opt_Files "Porta e ficheiros"
+    optDEFSPORT "Porta"
     optSAVESTATE "Guardar estado ao sair"
     optDELSTATE "Apagar ficheiros de estado"
     optPERMS   "Permisses de ficheiro"
@@ -644,6 +654,8 @@ array set TXT {
     SYcntct_spike "Espeto"
     SYcntct_sumo "Sumo"
     SYcoast_guard "Guarda costeira"
+    SYcross "Mira"
+    SYcross_3p "Mira 3p"
     SYcrossing "Passadeira"
     SYdam "Barragem"
     SYdanger "Perigo"
@@ -1234,6 +1246,26 @@ array set TXT {
     alm_health "sade"
     lstsqs  "Min Quadrados"
     lstsqsfile "Min Quad ficheiro"
+    mapfitWPs "Mostrar PTs de ajuste no mapa"
+    showfitinfo "Mostrar informao de ajuste"
+    xtcoord "xt"
+    ytcoord "yt"
+    delta   "d"
+    residual "rt"
+    rmsxydev "media_quadr(x,y-desvios)"
+    resstderr "erro std residual"
+    chgdev "Alterar porta"
+    alt_cumul "Altitude subida acumulada"
+    alt_cumuld "Altitude descida acumulada"
+    maxalt "Altitude mxima"
+    minalt "Altitude mnima"
+    optSHOWFILEITEMS "Normalmente mostrar no mapa elementos lidos"
+    vertgridlines "Linhas Verticais"
+    convert  "Converter"
+    split    "Cortar"
+    bysel  "por pontos seleccionados"
+    byseg  "em segmentos"
+    openits "Abrir %s"
 }
 
     # the following definitions must be coherent with $TXT
