@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: lowrance_patches.tcl
-#  Last change:  17 September 2004
+#  Last change:  27 September 2008
 #
 # this file contains patches to keep the Lowrance support code (in files
 #  lowrance.tcl, lowrance_nmea.tcl, lowrance_symbols.tcl) compatible
@@ -479,4 +479,18 @@ global GPSMANDAYS PDTYPE WPName WPSymbol WPNum WPCommt WPPosn WPDatum WPDate \
     }
 }
 
+# needing an args for compatibility with LoadGRElsIn
+
+proc GetGPSIn {wh ixs args} {
+    # get data of type $wh (in {WP, RT}), but only to replace items with
+    #  given indices $ixs (that may contain -1, meaning that new items
+    #  can be created)
+    #  $args not used but needed for compatibility with proc LoadGRElsIn
+    global GetSet
+
+    set GetSet($wh) $ixs
+    DoGetGPS $wh
+    return
+}
+
 
