@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,27 +17,31 @@
 #      along with this program.
 #
 #  File: main.tcl
-#  Last change:  14 June 2007
+#  Last change:  28 October 2008
 #
 # Includes contributions by
-#  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
-#  - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
-#  - Valere Robin (valere.robin@wanadoo.fr) marked "VR contribution"
-#  - David Gardner (djgardner@users.sourceforge.net) marked "DJG contribution"
+#  - Brian Baulch (baulchb _AT_ onthenet.com.au) marked "BSB contribution"
+#  - Matt Martin (matt.martin _AT_ ieee.org) marked "MGM contribution"
+#  - Valere Robin (valere.robin _AT_ wanadoo.fr) marked "VR contribution"
+#  - David Gardner (djgardner _AT_ users.sourceforge.net) marked
+#    "DJG contribution"
 #
 
-set VERSIONDATE(day) 14
-set VERSIONDATE(month) 6
-set VERSIONDATE(year) 2007
+set VERSIONDATE(day) 28
+set VERSIONDATE(month) 10
+set VERSIONDATE(year) 2008
+
+set VERSION 6.4
 
       # these tests here prevent errors in the lang*.tcl files
 if { [lsearch -exact "KM NAUTMILE STATMILE" $DISTUNIT] == -1 } {
-    puts "Bad value in variable DISTUNIT: $DISTUNIT (see file gpsman.tcl)"
+    puts stderr \
+	"Bad value in variable DISTUNIT: $DISTUNIT (see file gpsman.tcl)"
     exit 1
 }
 
 if { [lsearch -exact "M FT" $ALTUNIT] == -1 } {
-    puts "Bad value in variable ALTUNIT: $ALTUNIT (see file gpsman.tcl)"
+    puts stderr "Bad value in variable ALTUNIT: $ALTUNIT (see file gpsman.tcl)"
     exit 1
 }
 
@@ -88,9 +92,13 @@ set ALSCALE $ALSCALEFOR($ALTUNIT)
 set MAPDISTS $MAPDISTSFOR($DISTUNIT)
 set MAPFTSIZES "Tcl/Tk 9 10 11 12 14 18 24 36"
 
+# needed for error dialogs
+
+set WindowStack ""
+
 # knonw languages
 
-set KNOWNLANGS {deutsch engl es fr id it nl port}
+set KNOWNLANGS {deutsch engl es fr id it nl port ru}
 
 # known date formats are the indices of this array (for their widths in chars)
 array set DATEW {
@@ -102,45 +110,22 @@ array set DATEW {
     YYYY/MM/DD 19
 }
 
-# names of known languages in their own language
-array set TXT {
-    LANGdeutsch  Deutsch
-    LANGengl   English
-    LANGes     Espaol
-    LANGfr     Franais
-    LANGid     {Bahasa Indonesia}
-    LANGit     Italiano
-    LANGnl     Nederlands
-    LANGport   Portugus
-}
-
 # other source files
 
   # source the English messages; other language files can omit translations
-source [file join $SRCDIR langengl.tcl]
+SourceEnc [file join $SRCDIR langengl.tcl]
 
 foreach f $SRCFILESBEGIN {
-       source [file join $SRCDIR $f.tcl]
+       SourceEnc [file join $SRCDIR $f.tcl]
 }
 
 # other tests
 
-         # year from which seconds are reckoned; MUST BE < 1990
-         #     not necessarily a leap year
-         #     dates with years less than YEAR0 will not be accepted
-         #     NB: Garmin protocol dates start at 1990 January 1st
-         #         Lowrance dates start at 1992 January 1st
-set YEAR0 1988
-
-if { int($TimeOffset) != $TimeOffset } {
-    GMMessage $MESS(timeoffnotint)
+if { int($TimeOffset) != $TimeOffset && int(2*$TimeOffset) != 2*$TimeOffset } {
+    GMMessage $MESS(timeoffnotint) wait
     exit 1
 }
 
-set VERSION 6.3.2
-
-set WindowStack ""
-
 # fonts needed for proc AboutInfo
 
 set FontSize [font actual default -size]
@@ -157,6 +142,28 @@ if { $FIXEDFONTSIZE != "Tcl/Tk" } {
 
 ##
 
+proc UserDefinitions {} {
+    # set up user definitions as they may be needed when revising options
+    global UDatums UEllipsoids UBackgrnds UProjs UFile USERDIR
+
+    # user definitions:
+    # projections, datums and ellipsoids, map backgrounds, WP categories
+    set UDatums "" ; set UEllipsoids "" ; set UBackgrnds ""
+
+    if { [file readable [set UFile(datum,ell) [file join $USERDIR datums]]] } {
+	SetUpUserDatums
+    }
+    SetUpNZGrids
+    set UProjs {}
+    if { [file readable [set UFile(proj,grid) [file join $USERDIR projs]]] } {
+	SetupUserProjs
+    }
+    if { [file readable [set UFile(backgrs) [file join $USERDIR mapbaks]]] } {
+	SetUpUserBackgrnds
+    }
+    return
+}
+
 proc AboutInfo {w} {
     # create widgets for displaying information about GPSMan in window $w
     # all widgets will be inside frame $w.fr and are packed
@@ -181,25 +188,27 @@ proc AboutInfo {w} {
     scrollbar $frc.tscrl -command "$frc.txt yview"
     $frc.txt insert 1.0 "Copyright (c) $VERSIONDATE(year) \
 Miguel Filgueiras / DCC-FC & LIACC / Universidade do Porto\n\
-*   $TXT(errorsto) mig@ncc.up.pt\n\
+*   $TXT(errorsto) mig_AT_ncc.up.pt\n\
 $TXT(contrib):\n\
-*   Brian Baulch (baulchb@onthenet.com.au)\n\
-*   Andreas Lange (Andreas.C.Lange@GMX.de)\n\
-*   Alessandro Palmas (alpalmas@tin.it)\n\
-*   Valre Robin (valere.robin@wanadoo.fr)\n\
-*   Rob Buitenhuis (rob@buitenhs.demon.nl)\n\
-*   Tri Agus Prayitno (acuss@bk.or.id)\n\
-*   Matt Martin (matt.martin@ieee.org)\n\
-*   Stefan Heine (stefan.heinen@djh-freeweb.de)\n\
-*   Sabine Broda (sbb@ncc.up.pt)\n\
-*   Alberto Morales (amd77@gulic.org)\n\
-*   Martin Buck (m@rtin-buck.de)\n\
-*   David Kaplan (dmkaplan@ucdavis.edu)\n\
-*   Jean H Theoret (ve2za@rac.ca)\n\
-*   Paul Scorer (p.scorer@leedsmet.ac.uk)\n\
-*   Nigel Orr (gps@river-view.freeserve.co.uk)\n\
-*   David Gardner (djgardner@users.sourceforge.net)"
-
+*   Brian Baulch (baulchb_AT_onthenet.com.au)\n\
+*   Andreas Lange (Andreas.C.Lange_AT_GMX.de)\n\
+*   Alessandro Palmas (alpalmas_AT_tin.it)\n\
+*   Valere Robin (valere.robin_AT_wanadoo.fr)\n\
+*   Rob Buitenhuis (rob_AT_buitenhs.demon.nl)\n\
+*   Tri Agus Prayitno (acuss_AT_bk.or.id)\n\
+*   Matt Martin (matt.martin_AT_ieee.org)\n\
+*   Stefan Heine (stefan.heinen_AT_djh-freeweb.de)\n\
+*   Sabine Broda (sbb_AT_ncc.up.pt)\n\
+*   Alberto Morales (amd77_AT_gulic.org)\n\
+*   Martin Buck (m_AT_rtin-buck.de)\n\
+*   David Kaplan (dmkaplan_AT_ucdavis.edu)\n\
+*   Jean H Theoret (ve2za_AT_rac.ca)\n\
+*   Paul Scorer (p.scorer_AT_leedsmet.ac.uk)\n\
+*   Nigel Orr (gps_AT_river-view.freeserve.co.uk)\n\
+*   David Gardner (djgardner_AT_users.sourceforge.net)\n\
+*   Nikolai Kosyakoff (priroda.net_AT_gmail.com)\n\
+*   Benoit Steiner (benetsteph_AT_free.fr)\n\
+*   Sandor Laky (laky.sandor_AT_freemail.hu)"
 
     grid $frc.txt -column 0 -row 1 -sticky nesw
     grid $frc.tscrl -column 1 -row 1 -sticky nesw
@@ -233,6 +242,8 @@ if { $InitDir } {
     }
 }
 
+UserDefinitions
+
 ### if no preferences file force one being written
 if { $InitOpts || [OutDatedOptions] } {
     if { [SetOptions] } {
@@ -244,29 +255,24 @@ if { $InitOpts || [OutDatedOptions] } {
 
 ### read source files
 
-  # files setting receiver parameters
-foreach f $SRCFILESREC {
-    source [file join $SRCDIR $f.tcl]
-}
-
   # files that depend on receiver trade mark
 foreach f $SRCFILESFOR($MYGPS) {
-    source [file join $SRCDIR $f.tcl]
+    SourceEnc [file join $SRCDIR $f.tcl]
 }
 
   # files that may depend on the preferences file
 foreach f $SRCFILESEND {
-    source [file join $SRCDIR $f.tcl]
+    SourceEnc [file join $SRCDIR $f.tcl]
 }
 
   # conditional files
 foreach p $SRCFILESCOND {
     if { [set [lindex $p 0]] } {
-	source [file join $SRCDIR [lindex $p 1].tcl]
+	SourceEnc [file join $SRCDIR [lindex $p 1].tcl]
     }
 }
 
-  # user code
+  # user code assumed to be in system encoding
 set ucode [file join $USERDIR patch.tcl]
 if { [file exists $ucode] } {
     source $ucode
@@ -321,19 +327,18 @@ proc GlobalOptionsBindings {} {
 proc GMInit {} {
     # set up main window(s)
     global MapHeight MapWidth LISTWIDTH LISTHEIGHT COLOUR MAPCOLOUR \
-	    VERSION SRCDIR LPOSX LPOSY MPOSX MPOSY RPOSX RPOSY \
-	    MAPSCALE MAPDISTS MAPDISTVALS MAPSCLENGTH MWINDOWSCONF TYPES \
-	    RECTYPES MYGPS Temp1 List ListInds EdWindow GPSLabel \
-	    PositionFormat Datum GPSState Map MapBounds TXT MESS DISTUNIT \
-	    DTUNIT DSCALE SUBDTUNIT SUBDSCALE DLUNIT MAPDISTUNITS MapScale \
-	    MpW LsW RcW LsWTit MpWTit RcWTit WConf OVx OVy XCoord YCoord \
-	    MapZone MapProjTitle MapTransfTitle MapPFormat MapRange \
-	    MapWPMoving MapMakingRT MapLoading MapScInitVal MapImageItems \
-	    GetDispl MAPKNOWNPROJS RECPROTOCOLS SYMBOLIMAGE RcMenu \
-	    GPSProtocol GPSProtocolExt RealTimeLogAnim PVTState USvState \
-	    MAPFTSIZES GSHPVersion NoImgLib ImgOutFormats SmallLogo UNIX GMEd \
-	    FILEFORMAT MapScaleButton MapPFDatum AutoNumRts SUPPORTLAPS \
-	    FixedFont DATUMWIDTH GPSProtocolButton RECINFO
+	VERSION SRCDIR LPOSX LPOSY MPOSX MPOSY RPOSX RPOSY MAPSCALE MAPDISTS \
+	MAPDISTVALS MAPSCLENGTH MWINDOWSCONF TYPES RECTYPES MYGPS Temp1 List \
+	ListInds EdWindow GPSLabel PositionFormat Datum GPSState Map \
+	MapBounds TXT MESS DISTUNIT DTUNIT DSCALE SUBDTUNIT SUBDSCALE DLUNIT \
+	MAPDISTUNITS MapScale MpW LsW RcW LsWTit MpWTit RcWTit WConf OVx OVy \
+	XCoord YCoord MapZone MapProjTitle MapTransfTitle MapPFormat MapRange \
+	MapWPMoving MapMakingRT MapLoading MapScInitVal MapImageItems \
+	GetDispl MAPKNOWNPROJS RECPROTOCOLS SYMBOLIMAGE RcMenu GPSProtocol \
+	GPSProtocolExt RealTimeLogAnim PVTState USvState MAPFTSIZES \
+	GSHPVersion NoImgLib ImgOutFormats SmallLogo UNIX GMEd FILEFORMAT \
+	MapScaleButton MapPFDatum AutoNumRts SUPPORTLAPS FixedFont DATUMWIDTH \
+	GPSProtocolButton RECINFO SERIALPORT RECBAUDS
 
     set MapBounds "0 0 $MapWidth $MapHeight"
     set MapRange(x) $MapWidth ; set MapRange(y) $MapHeight
@@ -728,35 +733,38 @@ proc GMInit {} {
 	    $fr0.db.m add command -label "$TXT(search) ..." -command Search \
 		    -state disabled
 	    foreach i $ltypes {
+		set openits [format $TXT(openits) $i]
 		set m $fr0.db.m.e$i
 		$fr0.db.m add cascade -label $TXT(name$i) -menu $m
 		menu $m
 		if { $i == "GR" } {
-		    set tits [list $TXT(newGR) $TXT(clearall) \
+		    set tits [list $TXT(newGR) $openits $TXT(clearall) \
 			       "$TXT(loadgrels) ..." $TXT(count)]
-		    set coms "NewItem ClearList LoadGREls Count"
-		    set sts "normal disabled disabled normal"
-		    set im 3
+		    set coms [list NewItem OpenSelItems ClearList \
+				  LoadGREls Count]
+		    set sts "normal disabled disabled disabled normal"
+		    set im 4
 		    set imp importgrels ; set impst disabled
 		    set imppr ImportGREls
 		    set acts "save saveels"
 		    set prs "SaveFile SaveGREls"
 		    set exp exportels ; set exppr ExportGREls
 		} elseif { $i != "LAP" } {
-		    set tits [list $TXT(new$i) $TXT(clearall) $TXT(count)]
-		    set coms "NewItem ClearList Count"
-		    set sts "normal disabled normal"
-		    set im 2
+		    set tits [list $TXT(new$i) $openits $TXT(clearall) \
+				  $TXT(count)]
+		    set coms [list NewItem OpenSelItems ClearList Count]
+		    set sts "normal disabled disabled normal"
+		    set im 3
 		    set imp import ; set impst normal
 		    set imppr ImportFile
 		    set acts save ; set prs SaveFile
 		    set exp export ; set exppr ExportFile
 		} else {
 		    # LAP
-		    set tits [list $TXT(clearall) $TXT(count)]
-		    set coms "ClearList Count"
-		    set sts "disabled normal"
-		    set im 1
+		    set tits [list $openits $TXT(clearall) $TXT(count)]
+		    set coms "OpenSelItems ClearList Count"
+		    set sts "disabled disabled normal"
+		    set im 2
 		    set imp "" ; set impst "" ; set imppr ""
 		    set acts save ; set prs SaveFile
 		    set exp "" ; set exppr ""
@@ -946,6 +954,7 @@ proc GMInit {} {
     set tw [Measure $TXT(nameWP)]
     set bw [Measure $TXT(clear)]
     foreach i $ltypes {
+	set openits [format $TXT(openits) $i]	
 	set EdWindow($i) .gm$i ; set ListInds($i) ""
 	set GMEd($i,Show) 0
 
@@ -973,32 +982,33 @@ proc GMInit {} {
 
 	# order of menu entries is used elsewhere!
 	if { $i == "GR" } {
-	    set tits [list $TXT(newGR) $TXT(clearall) "$TXT(load) ..." \
-			       "$TXT(loadgrels) ..." $TXT(count)]
-	    set coms "NewItem ClearList LoadFile LoadGREls Count"
-	    set sts "normal disabled normal disabled normal"
-	    set im 4
+	    set tits [list $TXT(newGR) $openits $TXT(clearall) \
+			  "$TXT(load) ..." "$TXT(loadgrels) ..." $TXT(count)]
+	    set coms "NewItem OpenSelItems ClearList LoadFile LoadGREls Count"
+	    set sts "normal disabled disabled normal disabled normal"
+	    set im 5
 	    set imp importgrels ; set impst disabled
 	    set imppr ImportGREls
 	    set acts "save saveels"
 	    set prs "SaveFile SaveGREls"
 	    set exp exportels ; set exppr ExportGREls
 	} elseif { $i != "LAP" } {
-	    set tits [list $TXT(new$i) $TXT(clearall) "$TXT(load) ..." \
-		               $TXT(count)]
-	    set coms "NewItem ClearList LoadFile Count"
-	    set sts "normal disabled normal normal"
-	    set im 3
+	    set tits [list $TXT(new$i) $openits $TXT(clearall) \
+			  "$TXT(load) ..." $TXT(count)]
+	    set coms "NewItem OpenSelItems ClearList LoadFile Count"
+	    set sts "normal disabled disabled normal normal"
+	    set im 4
 	    set imp import ; set impst normal
 	    set imppr ImportFile
 	    set acts save ; set prs SaveFile
 	    set exp export ; set exppr ExportFile
 	} else {
 	    # LAP
-	    set tits [list $TXT(clearall) "$TXT(load) ..." $TXT(count)]
-	    set coms "ClearList LoadFile Count"
-	    set sts "disabled normal normal"
-	    set im 2
+	    set tits [list $openits $TXT(clearall) "$TXT(load) ..." \
+			  $TXT(count)]
+	    set coms "OpenSelItems ClearList LoadFile Count"
+	    set sts "disabled disabled normal normal"
+	    set im 3
 	    set imp "" ; set impst "" ; set imppr ""
 	    set acts save ; set prs SaveFile
 	    set exp "" ; set exppr ""
@@ -1054,13 +1064,37 @@ proc GMInit {} {
     }
 
     # receiver window; create and fill also receiver menu
+    # changes here should be reflected in procs DisableGPS and EnableGPs
+    #  in file gpsinfo.tcl
     menu $RcMenu
     $RcMenu add command -label $TXT(recwindow) \
 	    -command "ToggleWindow .rcw $RPOSX $RPOSY"
     $RcMenu add separator
+    menu $RcMenu.dev
     menu $RcMenu.pm
+    $RcMenu add cascade -label $TXT(optDEFSPORT) -menu $RcMenu.dev
     $RcMenu add cascade -label $TXT(protcl) -menu $RcMenu.pm
 
+    frame $RcW.frgps.dev -borderwidth 2 -bg $COLOUR(messbg)
+    set fdev $RcW.frgps.dev
+    # changing device when not connected
+    label $fdev.tdev -text $TXT(optDEFSPORT)
+    entry $fdev.dev -width 14 -textvariable SERIALPORT
+    $RcMenu.dev add command -label $TXT(chgdev) -command GPSChangeDevice
+    # changing baud rate when connected
+    if { $MYGPS == "Garmin" } {
+	menubutton $fdev.baud -text $TXT(optSERIALBAUD) \
+	    -menu $fdev.baud.mn -state disabled
+	menu $fdev.baud.mn
+	$RcMenu.dev add cascade -label $TXT(optSERIALBAUD) \
+	    -menu $RcMenu.dev.baud -state disabled
+	menu $RcMenu.dev.tbaud
+	foreach b $RECBAUDS {
+	    $fdev.baud.mn add command -label $b -command "GPSChangeBaud $b"
+	    $RcMenu.dev.tbaud add command -label $b -command "GPSChangeBaud $b"
+	}
+    }
+
     frame $RcW.frgps.prt -borderwidth 2 -bg $COLOUR(messbg)
     set fprt $RcW.frgps.prt
     menubutton $fprt.title -text $TXT(protcl) -menu $fprt.title.m
@@ -1127,8 +1161,7 @@ proc GMInit {} {
     $RcMenu add command -accelerator $TXT(check) \
 	    -image $SYMBOLIMAGE(diamond_red) -command CheckGPS
     button $RcW.frgps.bs.off -text $TXT(turnoff) -state disabled -width $r \
-	    -command "TurnOff ; \
-	    $RcW.frgps.bs.off configure -state normal"
+	    -command TurnOff
     $RcMenu add command -label $TXT(turnoff) -state disabled \
 	    -command TurnOff
     set r [Measure $TXT(nameLAP)]
@@ -1202,7 +1235,7 @@ proc GMInit {} {
     array set WConf $gmlst
     array set WConf $ptmlst
     set WConf(rec,getbs) [winfo children $RcW.frget.frget2]
-    set WConf(rec,putbs) [winfo children $RcW.frput]
+    set WConf(rec,putbs) [Delete [winfo children $RcW.frput] $RcW.frput.title]
     # BSB contribution
     if { $MYGPS == "Lowrance" } {
 	frame $RcW.frinfo -borderwidth 2
@@ -1309,13 +1342,17 @@ proc GMInit {} {
 	}
     }
 
+    grid $RcW.frgps.dev.tdev $RcW.frgps.dev.dev
+    if { $MYGPS == "Garmin" } {
+	grid $RcW.frgps.dev.baud -columnspan 2
+    }
     pack $RcW.frgps.prt.title $RcW.frgps.prt.prot -side left
     pack $RcW.frgps.bs.state $RcW.frgps.bs.off -side left -pady 2
     if { $MYGPS != "Magellan" } {
-	pack $RcW.frgps.title $RcW.frgps.prt $RcW.frgps.rlt $RcW.frgps.bs \
-		-side top -pady 5
+	pack $RcW.frgps.title $RcW.frgps.dev $RcW.frgps.prt $RcW.frgps.rlt \
+	    $RcW.frgps.bs -side top -pady 5
     } else {
-	pack $RcW.frgps.title $RcW.frgps.prt $RcW.frgps.bs \
+	pack $RcW.frgps.title $RcW.frgps.dev $RcW.frgps.prt $RcW.frgps.bs \
 		-side top -pady 5
     }
     pack $RcW.frget.frget1.title $RcW.frget.frget1.displ -side left -padx 5
@@ -1409,15 +1446,15 @@ proc GMStart {} {
 	TYPES PROCTYPES CursorsChanged MapWidth MapHeight MAPW2 MAPH2 \
 	AzimuthDegrees MapEmpty DataDefault DataIndex PositionFormat \
 	DEFAULTSYMBOL DEFAULTDISPOPT Datum EMPTYSTR Anim \
-	BalloonX BalloonY USERDIR UProjs UFile RealTimeLogOn \
+	BalloonX BalloonY USERDIR UProjs RealTimeLogOn \
 	RealTimeLogAnim PVTState USvState USvData USvMap \
 	BITMAPS SERIALPORT DEFSPORT tcl_platform DEFTRTWIDTH DEFTTRWIDTH \
 	DEFTLNWIDTH GPSProtocol RECPROTOCOLS GetDispl UNIX MAPCOLOUR \
 	MapFont MAPFONTSIZE Travelling Travel TRAVELFONTSIZE NAMEWIDTH \
 	MapMeasure DEFMAPPROJ DEFMAPPFRMT ALTUNIT AltUnit GMEd PlotWNo \
 	FILEFORMAT DEFTRECPROTOCOL MapPFDatum DEFMAPPFDATUM \
-	RealTimeGettingFix UDatums UEllipsoids UBackgrnds \
-	MAPWIDTH MAPHEIGHT
+	RealTimeGettingFix MAPWIDTH MAPHEIGHT GFShowInfo FromTimeOffset \
+	RecCanChgBaud
 
     # BSB contribution: globals needed for Lowrance receivers
     global UnusedICInx UnusedWPInx MAX MYGPS
@@ -1429,6 +1466,8 @@ proc GMStart {} {
 	set SERIALPORT $DEFSPORT
     }
 
+       # receiver supports changing baud rate when connected
+    set RecCanChgBaud 0
     if { $MYGPS == "Garmin" } {
 	set GPSProtocol $DEFTRECPROTOCOL
 	if { [regsub {^usb=} $SERIALPORT "" p] } {
@@ -1439,22 +1478,6 @@ proc GMStart {} {
     } else { set GPSProtocol [lindex $RECPROTOCOLS($MYGPS) 0] }
     set GetDispl 0
 
-    # user definitions:
-    # projections, datums and ellipsoids, map backgrounds, WP categories
-    set UDatums "" ; set UEllipsoids "" ; set UBackgrnds ""
-
-    if { [file readable [set UFile(datum,ell) [file join $USERDIR datums]]] } {
-	SetUpUserDatums
-    }
-    SetUpNZGrids
-    set UProjs {}
-    if { [file readable [set UFile(proj,grid) [file join $USERDIR projs]]] } {
-	SetupUserProjs
-    }
-    if { [file readable [set UFile(backgrs) [file join $USERDIR mapbaks]]] } {
-	SetUpUserBackgrnds
-    }
-
     # data-base
     set Number(Data) 0
            # the first element in Storage(_) must be identifier storage
@@ -1526,28 +1549,32 @@ proc GMStart {} {
     set USvState [file join $USERDIR sstate]
     set USvData [file join $USERDIR sdata]
     set USvMap [file join $USERDIR smap]
+    set FromTimeOffset ""
 
     # foreign formats
     set FILEFORMAT(_type,in,data) [set FILEFORMAT(_type,out,data) ""]
     foreach t $TYPES {
 	set FILEFORMAT(_type,in,$t) [set FILEFORMAT(_type,out,$t) ""]
     }	
-    foreach i [array names FILEFORMAT *,filetype] {
-	regsub {,.*$} $i "" fmt
+    foreach fmt $FILEFORMAT(names) {
 	if { $fmt == "GPSMan" || \
 		 ( ! [catch {set dep $FILEFORMAT($fmt,depends)}] && \
 		   ! [eval $dep] ) } {
 	    continue
 	}
-	set ts $FILEFORMAT($fmt,types)
-	if { ! [catch {set FILEFORMAT($fmt,GREls)}] } { lappend ts GR }
-	if { $FILEFORMAT($i) == "data" } {
+	if { [catch {set ts $FILEFORMAT($fmt,types)}] } {
+	    foreach "in_ts out_ts" $FILEFORMAT($fmt,io_types) { break }
+	} { set in_ts [set out_ts $ts] }
+	if { ! [catch {set FILEFORMAT($fmt,GREls)}] } {
+	    lappend in_ts GR ; lappend out_ts GR
+	}
+	if { $FILEFORMAT($fmt,filetype) == "data" } {
 	    foreach m $FILEFORMAT($fmt,mode) {
 		lappend FILEFORMAT(_type,$m,data) $fmt
 	    }
 	}
 	foreach m $FILEFORMAT($fmt,mode) {
-	    foreach t $ts {
+	    foreach t [set ${m}_ts] {
 		lappend FILEFORMAT(_type,$m,$t) $fmt
 	    }
 	}
@@ -1668,6 +1695,7 @@ proc GMStart {} {
     ChangeMapPFormat $DEFMAPPFRMT
 
     # varia
+    set GFShowInfo 1
     set AltUnit $ALTUNIT
     set PlotWNo 0
     set CursorsChanged 0
