@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1008-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: mapanim.tcl
-#  Last change:  18 May 2005
+#  Last change:  23 August 2008
 #
 
 proc InitAnimation {type title args} {
@@ -68,7 +68,8 @@ proc InitAnimation {type title args} {
     # this name is used explicitly elsewhere
     set w .anim$no
     toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "AnimAbort $no"
+    wm protocol $w WM_DELETE_WINDOW \
+	"set Anim(state,$no) abort ; destroy $w ; AnimAbort $no"
     wm title $w "$TXT(animation)/GPS Manager"
     wm transient $w
     wm geometry $w +$EPOSX+$EPOSY
@@ -87,7 +88,7 @@ proc InitAnimation {type title args} {
     frame $w.fr.frs
     label $w.fr.frs.sl -text $TXT(slow) -width 6
     scale $w.fr.frs.sp -orient horizontal -from -50 -to 50  -showvalue 0 \
-	    -width 8 -length 150 -variable Anim(speed,$no) -label xxx
+	    -width 8 -length 200 -variable Anim(speed,$no) -label xxx
     label $w.fr.frs.fst -text $TXT(fast) -width 6
     # must be here!
     if { $rtl } {
