@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,12 @@
 #      along with this program.
 #
 #  File: maptransf.tcl
-#  Last change:  16 April 2007
+#  Last change:  12 February 2008
 #
 
 ## Uses information kindly supplied by
 #     Jose Alberto Goncalves, Universidade do Porto
+#     J. B. Mehl
 ##
 
 ## transformations for geo-referencing of images
@@ -348,15 +349,23 @@ proc GaussReduce {n} {
     return 1
 }
 
-##### least-squares fit
-# from the equations provided by James B. Mehl
-#  with origin of pixel coordinates in the upper left corner of image
+### new version of least squares fit yielding one of the affine,
+#    affine conformal, or affine conformal without rotation  transformation
+## using equations worked out by J. B. Mehl 20070712, corrected 20070808
 #
 # 	(xt,yt) terrain coordinates
 # 	(xm,-ym) map coordinates (pixel, ym grows downwards!)
+#  with origin of pixel coordinates in the upper left corner of image
 #
 # 	(e,f) terrain coordinates of upper left corner, map (0,0)
 #
+#       with   n = number of points
+#              Sxm   = sum_i xm_i
+#              Sxtxm = sum_i xt_i xm_i
+#              ...
+#
+#  parameters of an affine conformal with no rotation transformation
+#
 # 	(xt,yt) = lambda (xm,ym) + (e,f)
 #
 # 	(e,f) = lambda (xm_0,H-ym_0) + (xt_0,yt_0)
@@ -364,82 +373,254 @@ proc GaussReduce {n} {
 #         map lower corner
 #
 #       for all control points replace vertical coordinate ym_i by
-#         H-ym_i
+#         H-ym-i
 #
-# 	f = sum_i (xt_i-xt_0-lambda xm_i)^2+(yt_i-yt_0-lambda ym_i)^2
+# 	F = sum_i (xt_i-xt_0-lambda xm_i)^2+(yt_i-yt_0-lambda ym_i)^2
 # 	min
 #
-# 	d(f,xt_0)=0 =>   S_xt - N xt_0 - lambda S_xm = 0
-# 		=>   xt_0 = (S_xt - lambda S_xm) / N
-# 	d(f,yt_0)=0 =>   S_yt - N yt_0 - lambda S_ym = 0
-# 		=>   yt_0 = (S_yt - lambda S_ym) / N
-# 	d(f,lambda)=0 =>   S_xtm - xt_0 S_xm - lambda S_xmm +
-# 				S_ytm - y_t0 S_ym - lambda S_ymm
-#       => lambda = (N (S_xtm + S_ytm) - S_xt S_xm - S_yt S_ym) /
-# 			(N (S_xmm + S_ymm) - S_xm^2 - S_ym^2)
+# 	d(F,xt_0)=0 =>   Sxt - n xt_0 - lambda Sxm = 0
+# 		=>   xt_0 = (Sxt - lambda Sxm) / n
+# 	d(F,yt_0)=0 =>   Syt - n yt_0 - lambda Sym = 0
+# 		=>   yt_0 = (Syt - lambda Sym) / n
+# 	d(F,lambda)=0 =>   Sxtxm - xt_0 Sxm - lambda Sxmxm +
+# 				Sytm - y_t0 Sym - lambda Symym
+#
+#       lambda = (n (Sxtxm + Sytym) - Sxt Sxm - Syt Sym) /
+# 		   (n (Sxmxm + Symym) - Sxm^2 - Sym^2)
+#
+#       e = (Sxt - lambda Sxm) / n
+#
+#       f = (Syt + lambda Sym) / n
+#
+#  parameters of an affine conformal transformation
+#
+#                 | a  b |
+#       (xt,yt) = | c  d | (xm,ym) + (e,f)
+#
+#       with   a = -d = s cos r    b = c = s sin r
+#       NB: as GPSMan procs use b = c = -s sin r, the equation for b below
+#           must be preceded by a minus sign
+#
+#       minimize sum_i d(xt_i)^2+d(yt_i)^2
+#       where
+#            d(xt_i) = xt_i - e - a xm_i - b ym_i
+#            d(yt_i) = yt_i - f - b xm_i + a ym_i
+#
+#            |  n    0      Sxm         Sym     | | e |   |     Sxt     |
+#            |  0    n     -Sym         Sxm     | | f |   |     Syt     |
+#        M = | Sxm -Sym Sxmxm+Symym      0      | | a | = | Sxtxm-Sytym |
+#            | Sym  Sxm      0      Sxmxm+Symym | | b |   | Sxtym+Sytxm |
+#
+#        e = (Sxm (Sxtxm-Sytym)+Sym (Sxtym+Sytxm)-Sxt (Sxmxm+Symym)) /
+#               (Sxm^2 + Sym^2 - n (Sxmxm+Symym))
+#
+#        f = (Sym (Sytym-Sxtxm)+Sxm (Sxtym+Sytxm)-Syt (Sxmxm+Symym)) /
+#               (Sxm^2 + Sym^2 - n (Sxmxm+Symym))
+#
+#        a = (Sxt Sxm - Syt Sym - n (Sxtxm - Sytym)) /
+#               (Sxm^2 + Sym^2 - n (Sxmxm+Symym))
+#
+#        b = (Sxt Sym + Syt Sxm - n (Sxtym + Sytxm)) /
+#               (Sxm^2 + Sym^2 - n (Sxmxm+Symym))
+#
+#  parameters of an affine transformation
+#
+#                 | a  b |
+#       (xt,yt) = | c  d | (xm,ym) + (e,f)
+#
+#       minimize sum_i d(xt_i)^2+d(yt_i)^2
+#       where
+#            d(xt_i) = xt_i - xt(xm_i,ym_i,a,...,f)
+#            similarly for d(yt_i)
+#
+#       => minimize sum_i (xt_i-e-a xm_i-ab ym_i)^2 +
+#                         (yt_i-f-ac xm_i-ad ym_i)^2
+#
+#           |  n    Sxm   Sym  |        | e |         |  Sxt  |
+#       M = | Sxm  Sxmxm Sxmym |   Vx = | a |    Cx = | Sxtxm |
+#           | Sym  Sxmym Symym |        | b |         | Sxtym |
+#
+#
+#                                       | f |         |  Syt  |
+#                                  Vy = | c |    Cy = | Sytxm |
+#                                       | d |         | Sytym |
+#
+#       equations:  M Vx = Cx, M Vy = Cy  yield [aij], e, f
 #
 
 proc MapInitLeastSquaresTransf {args} {
     # use datum and geodetic and pixel coordinates of points either
     #  from the graphical interface or from a GPSMan least-squares
-    #  info file to compute parameters of affine conformal
-    #  transformation with no rotation using a least-squares fit
+    #  info file to compute parameters of transformation using a
+    #  least-squares fit
+    #  $LSqsTransf  in {Affine, AffineConf, NoRot} is the transformation type
     #  $args==""  points are WPs, with $MapLoadWPs the list of
     #          indices of relevant WPs, used by proc MapGeoRefPoints
     #          that sets MapLoadPos(_,_) to the pixel coordinates
-    #       ==pair whose 2nd element is the projection and 1st elemet is
-    #          a pair with list of latd,longd,datum, and list of pairs with
-    #          pixel coordinates (x, y, in Tcl sign convention with origin
-    #          at upper left corner)
-    # return 0 on error or operation being cancelled
-    global MPData MTData MapScale MPData MapLoadWPs MapLoadPos MapImageHeight
+    #       ==pair whose 2nd element is the projection and 1st element is
+    #          a list with list of latd, longd and datum, a list of pairs
+    #          with pixel coordinates (x, y, in Tcl sign convention with
+    #          origin at upper left corner), a list with waypoints names (empty
+    #          for positions given explictly), and the input file path
+    # return list of WP names to be displayed or 0 on error or operation being
+    #  cancelled
+    global MPData MTData MapScale MPData MapLoadWPs MapLoadPos MapImageHeight \
+	 LSqsTransf Mat Rx SUBDTUNIT DSCALE SUBDSCALE TXT GFShowInfo GFVisible
 
+    set dispWPs ""
     if { $args == "" } {
+	# from interface: always show fit information, no WPs to display
+	set showinfo 1
+	set names ""
+	set fpath ""
 	set n [llength $MapLoadWPs]
 	if { [set tcs [MapGeoRefPoints $n]] == -1 } { return 0 }
 	set xys ""
 	for { set k 0 } { $k < $n } { incr k } {
 	    lappend xys [list $MapLoadPos($k,x) $MapLoadPos($k,y)]
 	}
+	foreach ix $MapLoadWPs {
+	    lappend names [NameOf WP $ix]
+	}
     } else {
+	# from file: show fit information and display WPs if required
+	set showinfo $GFShowInfo
 	foreach "p proj" $args { break }
-	foreach "llds xys" $p { break }
+	foreach "ldds xys names fpath" $p { break }
 	set tcs ""
-	foreach tr $llds {
-	    foreach "latd longd datum" $tr {}
+	foreach ldd $ldds {
+	    foreach "latd longd datum" $ldd {}
 	    lappend tcs [Proj${proj}Point MPData $latd $longd $datum]
 	}
-	set n [llength $llds]
+	set n [llength $names]
+	if { $GFVisible } { set dispWPs $names }
     }
     # least-squares on $tcs and $xys
-    foreach i "xt yt xm ym xtm ytm xtt ytt xmm ymm" { set s($i) 0 }
+    MapTransfIs $LSqsTransf
+    if { $LSqsTransf == "NoRot" } {
+	set ymoff $MapImageHeight ; set ymsign -1
+    } else { set ymoff 0 ; set ymsign 1 }
+    foreach i "xt xtxm xtym yt ytxm ytym xm xmxm xmym ym ymym" {
+	set s($i) 0.0
+    }
     foreach tc $tcs pc $xys {
 	foreach "xt yt" $tc {}
 	foreach "xm ym" $pc {}
-	set ym [expr $MapImageHeight-$ym]
+	set ym [expr $ymoff+$ymsign*$ym]
 	foreach i "xt yt xm ym" {
 	    set s($i) [expr $s($i)+[set $i]]
 	}
-	foreach i "x y" {
-	    set s(${i}tm) [expr $s(${i}tm)+[set ${i}t]*[set ${i}m]]
-	    set s(${i}tt) [expr $s(${i}tt)+[set ${i}t]*[set ${i}t]]
-	    set s(${i}mm) [expr $s(${i}mm)+[set ${i}m]*[set ${i}m]]
+	set s(xmym) [expr $s(xmym)+1.0*$xm*$ym]
+	foreach j "x y" {
+	    set z [set ${j}m]
+	    set w "${j}m${j}m"
+	    set s($w) [expr $s($w)+1.0*$z*$z]
+	    foreach i "x y" {
+		set w "${i}t${j}m"
+		set s($w) [expr $s($w)+1.0*[set ${i}t]*$z]
+	    }
 	}
     }
-    MapTransfIs NoRot
-    if { [catch {set k [expr 1.0*($n*($s(xtm)+$s(ytm)) - $s(xt)*$s(xm) - \
-				      $s(yt)*$s(ym)) /  \
-			    ($n*($s(xmm)+$s(ymm)) - $s(xm)*$s(xm) - \
-				 $s(ym)*$s(ym))]}] } {
-	return 0
+    set dfreedom [expr $n+$n]
+    set n [expr 1.0*$n]
+    switch $LSqsTransf {
+	Affine {
+	    incr dfreedom -6
+	    foreach d "xt yt" ps [list "e a b" "f c d"] {
+		catch {unset Mat}
+		set Mat(0,0) $n
+		set Mat(0,1) [set Mat(1,0) $s(xm)]
+		set Mat(0,2) [set Mat(2,0) $s(ym)]
+		set Mat(1,1) $s(xmxm)
+		set Mat(1,2) [set Mat(2,1) $s(xmym)]
+		set Mat(2,2) $s(ymym)
+		set Mat(0,3) $s($d)
+		set Mat(1,3) $s(${d}xm)
+		set Mat(2,3) $s(${d}ym)
+		if { [GaussReduce 3] != 1 } { return 0 }
+		foreach p $ps i "0 1 2" {
+		    set MTData($p) $Mat($Rx($i),3)
+		}
+	    }
+	    # the following parameters simplify computations
+	    set MTData(det) [expr $MTData(a)*$MTData(d)-$MTData(b)*$MTData(c)]
+	    set MTData(k2m1) [expr $MTData(b)*$MTData(f)-$MTData(d)*$MTData(e)]
+	    set MTData(k4m3) [expr $MTData(c)*$MTData(e)-$MTData(a)*$MTData(f)]
+	    # scale along the xm-axis when variation of ym=0
+	    set MapScale [expr abs($MTData(a))]
+	}
+	AffineConf {
+	    incr dfreedom -4
+	    set zxym [expr $s(xmxm)+$s(ymym)]
+	    set zuyvx [expr $s(xtym)+$s(ytxm)]
+	    set zuxMvy [expr $s(xtxm)-$s(ytym)]
+	    if { abs([set den [expr $s(xm)*$s(xm)+$s(ym)*$s(ym)-$n*$zxym]]) \
+		     < 1e-50 } { return 0 }
+ 	    set MTData(a) [expr ($s(xt)*$s(xm)-$s(yt)*$s(ym)-$n*$zuxMvy) \
+ 			       / $den]
+	    # b sign is changed in GPSMan affine conformal procs
+ 	    set MTData(b) [expr -($s(xt)*$s(ym)+$s(yt)*$s(xm)-$n*$zuyvx) /$den]
+ 	    set MTData(e) [expr ($s(xm)*$zuxMvy+$s(ym)*$zuyvx-$s(xt)*$zxym) \
+ 			       / $den]
+ 	    set MTData(f) [expr ($s(xm)*$zuyvx-$s(ym)*$zuxMvy-$s(yt)*$zxym) \
+ 			       / $den]
+	    # the following parameters make calculations easier
+ 	    set MTData(det) [expr $MTData(a)*$MTData(a)+$MTData(b)*$MTData(b)]
+ 	    set MTData(k2m1) [expr $MTData(b)*$MTData(f)-$MTData(a)*$MTData(e)]
+ 	    set MTData(k4m3) [expr $MTData(b)*$MTData(e)+$MTData(a)*$MTData(f)]
+	    # scale along the xm-axis when variation of ym=0
+	    set MapScale [expr abs($MTData(a))]
+	}
+	NoRot {
+	    incr dfreedom -3
+	    if { [catch {set k [expr 1.0*($n*($s(xtxm)+$s(ytym))- \
+					      $s(xt)*$s(xm)-$s(yt)*$s(ym)) /  \
+				    ($n*($s(xmxm)+$s(ymym)) - $s(xm)*$s(xm) - \
+					 $s(ym)*$s(ym))]}] } {
+		return 0
+	    }
+	    # assuming:
+	    # set MapLoadPos(origin,x) 0
+	    # set MapLoadPos(origin,y) 0
+	    set MTData(lambda) [set MapScale $k]
+	    set MTData(e) [expr 1.0*($s(xt)-$k*$s(xm))/$n]
+	    set MTData(f) [expr 1.0*($s(yt)-$k*$s(ym))/$n+$k*$MapImageHeight]
+	}
     }
-    # assuming:
-    # set MapLoadPos(origin,x) 0
-    # set MapLoadPos(origin,y) 0
-    set MTData(lambda) [set MapScale $k]
-    set MTData(e) [expr 1.0*($s(xt)-$k*$s(xm))/$n]
-    set MTData(f) [expr 1.0*($s(yt)-$k*$s(ym))/$n+$k*$MapImageHeight]
-    return 1
+    if { $showinfo } {
+	# deviations of control points in user units (m, ft)
+	set sc [expr $MapScale*$DSCALE/$SUBDSCALE/1000.0]
+    
+	append info $TXT(lstsqs) " / " $TXT(TRNSF$LSqsTransf) "\n"
+	if { $fpath != "" } {
+	    append info $TXT(file) ": " $fpath "\n"
+	}
+	set xt $TXT(xtcoord) ; set yt $TXT(ytcoord)
+	set delta $TXT(delta)
+	append info \
+	    "\t\t$xt\t$yt\t$delta $xt\t$delta $yt\t$delta $TXT(residual)\n" \
+	    "\t\tm\tm\t$SUBDTUNIT\t$SUBDTUNIT\t$SUBDTUNIT\n"
+	set sumdrt2 0
+	foreach tc $tcs pc $xys name $names {
+	    foreach "xt yt" $tc {}
+	    foreach "xm ym" $pc {}
+	    foreach "nxm nym" [MapApply${LSqsTransf}Transf $xt $yt] {}
+	    set dxt [expr $sc*($nxm-$xm)]
+	    set dyt [expr $sc*($nym-$ym)]
+	    set drt [expr sqrt($dxt*$dxt+$dyt*$dyt)]
+	    set sumdrt2 [expr $sumdrt2+$drt*$drt]
+	    foreach v "dxt dyt drt" { set $v [format %7.2f [set $v]] }
+	    append info $name "\t\t" [format %.2f $xt] "\t" [format %.2f $yt] \
+		"\t" $dxt "\t" $dyt "\t" $drt "\n"
+	}
+	set rms [expr sqrt($sumdrt2/($n+$n))]
+	set rmsdf [expr sqrt(1.0*$sumdrt2/$dfreedom)]
+	append info "$TXT(rmsxydev) = " [format %.2f $rms] $SUBDTUNIT "\n" \
+	    "$TXT(resstderr) = " [format %.2f $rmsdf] $SUBDTUNIT "\n"
+	DisplayInfo $info tabs \
+	    [list -10 right -24 right -38 right -46 right -54 right -62 right]
+    }
+    return $dispWPs
 }
 
 ##### TFW metadata file
