@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2007 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,12 +17,19 @@
 #      along with this program.
 #
 #  File: metadata.tcl
-#  Last change:  4 May 2007
+#  Last change:  25 September 2008
 #
 
 # abstract data used in command-mode, in configuring the graphical interface,
 #  and in parsing files
 
+         # year from which seconds are reckoned; MUST BE < 1990
+         #     not necessarily a leap year
+         #     dates with years less than YEAR0 will not be accepted
+         #     NB: Garmin protocol dates start at 1990 January 1st
+         #         Lowrance dates start at 1992 January 1st
+set YEAR0 1988
+
 ##### properties of known file formats
 #   indices as NAME,PROPERTY  where PROPERTY is
 #
@@ -31,9 +38,13 @@
 #                  declared), returning 0 on failure
 #    filetype     in {unique, single, data} meaning: only one possible type,
 #                 several types but each file has only one, other situations
-#    types        admissible types as a subset of $TYPES-{GR}; the order must
-#                 be that imposed by the format on the data in the file, if
-#                 there is such an order
+#    types        to be used only if there is a single mode or the types are
+#                 the same for in and out: admissible types as a subset of
+#                 $TYPES-{GR}; the order must be that imposed by the format
+#                 on the data in the file, if there is such an order
+#    io_types     to be used if the mode is {in out} and the admissible types
+#                 for in and out are different: pair with list of in types
+#                 and list of out types as described for "types"
 #    GREls        defined if there is support for dealing with GR elements
 #    MODE,params  list of parameter names
 #    MODE,pdefts  list of default values (or "ERROR" if value must be supplied)
@@ -50,7 +61,7 @@
 #                  each constraint and global variable are then checked/set
 #                  in the same order
 
-# includes VR contribution
+# includes VR contributions
 
 array set FILEFORMAT {
     GPSMan,mode           {in out}
@@ -155,6 +166,10 @@ array set FILEFORMAT {
     Kismet,in,params      {group}
     Kismet,in,pdefts      {0}
     Kismet,param,group    {GFOption Ignore { expr 1 } {@$TXT(nameGR)}}
+    KML,mode              {in out}
+    KML,filetype          data
+    KML,io_types          {WP  {WP RT TR}}
+    KML,GREls             1
     MapGuide,mode         in
     MapGuide,filetype     unique
     MapGuide,types        RT
@@ -183,9 +198,9 @@ array set FILEFORMAT {
                             expr ! [string compare $GPSREC "Garmin"] }
     NMEA,filetype         unique
     NMEA,types            TR
-    Ozi,mode              out
+    Ozi,mode              {in out}
     Ozi,filetype          single
-    Ozi,types             {WP TR}
+    Ozi,io_types          {WP {WP TR}}
     Ozi,GREls             1
     SimpleText,mode       {in out}
     SimpleText,filetype   unique
@@ -201,7 +216,7 @@ foreach n [array names FILEFORMAT *,mode] {
     lappend ffs $n
 }
 
-set FILEFORMAT(names) $ffs
+set FILEFORMAT(names) [lsort -dictionary $ffs]
 
 ### receiver protocols with external and internal representations
 
@@ -229,3 +244,16 @@ array set MAPTRANSFNPTS {
 
 set MAPKNOWNTRANSFS {Affine AffineConf NoRot}
 
+### source files that are not encoded in ascii
+
+array set ENCODED {
+    isolatin1.tcl   iso8859-1
+    i18n-utf8.tcl   utf-8
+    langdeutsch.tcl iso8859-1
+    langes.tcl      iso8859-1
+    langfr.tcl      iso8859-1
+    langit.tcl      iso8859-1
+    langnl.tcl      iso8859-1
+    langport.tcl    iso8859-1
+    langru.tcl      utf-8
+}
