@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: options.tcl
-#  Last change:  5 July 2005
+#  Last change:  27 September 2008
 #
 
 # when inserting new data here, define TXT(opt*)
@@ -77,7 +77,7 @@ set OPTSTRUCT {   GPSREC _GPSRecConf _Formats _sep
 
 set OPTTYPE(_Interf) group
 set OPTGRPL(_Interf) {MWINDOWSCONF LANG ISOLATIN1 DELETE USESLOWOPWINDOW
-                      BalloonHelp TRNUMBERINTVL TRINFO LNSREACT}
+                      BalloonHelp SHOWFILEITEMS TRNUMBERINTVL TRINFO LNSREACT}
 set OPTTYPE(MWINDOWSCONF) fixedtextmenu
 set OPTMENUCONTS(MWINDOWSCONF) {map lists}
 set OPTMENUNAMES(MWINDOWSCONF) TXT
@@ -90,6 +90,7 @@ set OPTTYPE(ISOLATIN1) boolean
 set OPTTYPE(DELETE) boolean
 set OPTTYPE(USESLOWOPWINDOW) boolean
 set OPTTYPE(BalloonHelp) boolean
+set OPTTYPE(SHOWFILEITEMS) boolean
 set OPTTYPE(TRNUMBERINTVL) nat
 set OPTTYPE(TRINFO) fixedtextmenu
 set OPTMENUCONTS(TRINFO) {number date}
@@ -253,7 +254,7 @@ proc OutDatedOptions {} {
 	# no longer supported after 5.2
 	set MWINDOWSCONF map ; set r 1
     }
-    if { $r } {
+    if { $r && "${VERSION}-patched" != $OPTFILEVERSION } {
 	AboutInfo ""
 	GMMessage $MESS(outdatedprefs)
 	return 1
@@ -358,15 +359,17 @@ proc SetOptions {} {
 			set res 0
 			break
 		    }
+		    regsub -- {-patched$} $VERSION "" version
 		    puts $f ""
 		    puts $f "# $MESS(written) GPSMan [NowTZ]"
 		    puts $f "# $MESS(editrisk)"
 		    puts $f ""
-		    puts $f "set OPTFILEVERSION $VERSION"
+		    puts $f "set OPTFILEVERSION $version"
 		    puts $f ""
 		    foreach v $OPTSTRUCT { GenOption $f $v }
 		    close $f
 		    set res 1
+		    GMMessage $MESS(goingdown)
 		    break
 		}
 	    }
@@ -423,13 +426,15 @@ proc ShowOption {v ref val type vf es lv row col} {
 	    set OptOld[set lv]($ref) [set $val]
 	    label $vf.l -text $TXT(opt$ref)
 	    pack $vf.l -anchor w
+	    set i 0
 	    foreach vl $OPTVALS($v) {
-		radiobutton $vf.r$vl -text $TXT($vl) -variable $val \
+		radiobutton $vf.r$i -text $TXT($vl) -variable $val \
 			-value $vl -anchor w -selectcolor $COLOUR(check)
 		if { [set $val] == $vl } {
-		    $vf.r$vl invoke
+		    $vf.r$i invoke
 		}
-		pack $vf.r$vl -side left -padx 2
+		pack $vf.r$i -side left -padx 2
+		incr i
 	    }
 	}
 	menu {
@@ -781,7 +786,13 @@ proc ChangeMenuOption {val w} {
 
 proc ChangeTextMenuOption {val w} {
     # change option to value $val presented as a menu, window $w
+    #  $w may be a submenu
     global OptMenuVar OptMenuText
+
+    while { [catch {set OptMenuText($w,names)}] && $w != "" } {
+	set w [winfo parent $w]
+    }
+    if { $w == "" } { BUG bad menu }
     global $OptMenuText($w,names) 
 
     $OptMenuText($w,label) configure -text \
