@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 #      along with this program.
 #
 #  File: recmodels.tcl
-#  Last change:  15 June 2005
+#  Last change:  26 February 2008
 #
 # Includes contributions by
-#  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
-#  - Matt Martin (matt.martin@ieee.org) marked "MGM contribution"
+#  - Brian Baulch (baulchb_AT_onthenet.com.au) marked "BSB contribution"
+#  - Matt Martin (matt.martin_AT_ieee.org) marked "MGM contribution"
 #  - Miguel Filgueiras (to code by others) marked "MF contribution"
 #
 
@@ -86,17 +86,19 @@ proc RecModelChange {tm} {
     #  configuration
     #  $tm is the receivers trade-mark in {Garmin, Lowrance, Magellan}
     global GPSREC OPTTYPE OPTGRPL OPTMENUPROC OPTMENUNAMES OPTMENUPREFIX \
-	    OPTMENUCONTS DISPOPTS RECPROTOCOLS
+	    OPTMENUCONTS DISPOPTS RECPROTOCOLS RECBAUDS
 
     set OPTTYPE(_GPSRecConf) group
     switch $tm {
 	Garmin {
-	    set OPTGRPL(_GPSRecConf) {DEFTRECPROTOCOL ACCEPTALLCHARS
+	    set OPTGRPL(_GPSRecConf) {DEFTRECPROTOCOL SERIALBAUD ACCEPTALLCHARS
 		      NAMELENGTH COMMENTLENGTH
 	              MAXWPOINTS MAXROUTES MAXWPINROUTE AutoNumRts MAXTPOINTS
 		      CREATIONDATE NOLOWERCASE DEFAULTSYMBOL DEFAULTDISPOPT
 	              SUPPORTLAPS}
             set OPTTYPE(DEFTRECPROTOCOL) fixedtextmenu
+	    set OPTTYPE(SERIALBAUD) fixedmenu
+	    set OPTMENUCONTS(SERIALBAUD) $RECBAUDS
             set OPTMENUCONTS(DEFTRECPROTOCOL) $RECPROTOCOLS(Garmin)
             set OPTMENUNAMES(DEFTRECPROTOCOL) TXT
             set OPTMENUPREFIX(DEFTRECPROTOCOL) {}
@@ -150,8 +152,8 @@ proc RecModelChange {tm} {
                       NOLOWERCASE DEFAULTSYMBOL DEFAULTDISPOPT}
             set OPTTYPE(NAMELENGTH) nat
 	    set OPTTYPE(SERIALBAUD) fixedmenu
-	    # MF contribution: added 4800 (used by Meridian Platinum)
-	    set OPTMENUCONTS(SERIALBAUD) [list 4800 9600 19200 57600 115200]
+	    # MF change: RECBAUDS is set in recdefs.tcl
+	    set OPTMENUCONTS(SERIALBAUD) $RECBAUDS
             set OPTTYPE(INTERVAL) nat
             set OPTTYPE(COMMENTLENGTH) nat
             set OPTTYPE(MAXWPOINTS) nat
@@ -173,6 +175,3 @@ proc RecModelChange {tm} {
     return
 }
 
-## set the options that depend on the receiver
-
-RecModelChange $MYGPS
