@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: serial.tcl
-#  Last change:  3 June 2006
+#  Last change:  23 October 2008
 #
-# Includes contributions by Matt Martin (matt.martin@ieee.org)
+# Includes contributions by Matt Martin (matt.martin_AT_ieee.org)
 #  marked "MGM contribution"
 #
 
@@ -209,7 +209,10 @@ proc OpenSerialFailed {baud} {
     # return 1 on failure
     global MESS SRLFILE SERIALPORT InBuff Polling Eof tcl_platform
 
-    if { [catch {set SRLFILE [open $SERIALPORT r+]}] } {
+    if { ! [file exists $SERIALPORT] || \
+	     ! [file readable $SERIALPORT] || \
+	     [catch {set SRLFILE [open $SERIALPORT r+]}] || \
+	     [regexp {^-} $SRLFILE] } {
 	GMMessage [format $MESS(badserial) $SERIALPORT]
 	return 1
     }
@@ -299,7 +302,11 @@ proc GPSConnection {args} {
 	    set ProcSendPacket SendUSBPacket
 	} else {
 	    # use as serial port
-	    if { [OpenSerialFailed $SERIALBAUD] } {
+	    if { $GPSProtocol == "garmin" } {
+		# baud rate is to be set to $SERIALBAUD in proc EndConnCheck
+		set baud 9600
+	    } else { set baud $SERIALBAUD }
+	    if { [OpenSerialFailed $baud] } {
 		eval [lindex $args 1]
 		return 0
 	    }
@@ -320,18 +327,21 @@ proc GPSConnection {args} {
 
 proc EndConnCheck {messid} {
     # end connection check successfully
-    # set GPSOpResult to 0
-    global MYGPS Request MESS CurrPSPID NotLogging GPSOpResult
+    # set GPSOpResult to 0 if ok
+    global MYGPS Request MESS CurrPSPID GPSOpResult RecCanChgBaud SERIALBAUD
 
-    CloseInProgrWindow
-    if { $MYGPS == "Garmin" && ! [catch {set pid $CurrPSPID(WPData)}] } {
-	SymbolsDOForProtocol $pid
-    }
     ResetSerial
     Log "ECC> $MESS($messid)"
+    if { $MYGPS == "Garmin" && ! [catch {set pid $CurrPSPID(WPData)}] } {
+	    SymbolsDOForProtocol $pid
+    }
+    CloseInProgrWindow
     regsub check= $Request "" as
     eval [lindex $as 0]
     set GPSOpResult 0
+    if { $MYGPS == "Garmin" && $RecCanChgBaud && $SERIALBAUD != 9600 } {
+	ChangeGarminBaud $SERIALBAUD
+    }
     return
 }
 
@@ -361,6 +371,7 @@ proc StartGPS {} {
 }
 
 proc GetGPS {wh} {
+    # get data of type $wh
     global GetSet
 
     set GetSet($wh) ""
@@ -368,10 +379,11 @@ proc GetGPS {wh} {
     return
 }
 
-proc GetGPSIn {wh ixs} {
+proc GetGPSIn {wh ixs args} {
     # get data of type $wh (in {WP, RT}), but only to replace items with
     #  given indices $ixs (that may contain -1, meaning that new items
     #  can be created)
+    #  $args not used but needed for compatibility with proc LoadGRElsIn
     global GetSet
 
     set GetSet($wh) $ixs
@@ -417,7 +429,7 @@ proc AbortComm {args} {
     # global $Request==get$wh  where $wh in {WP RT TR PosnData DtTMData}
     #                          (cf. SendData)
     #                         GPSOpResult is set to 1 (error)
-    #                ==check=$args  where 2nd arg should be executed as
+    #                ==check=$cargs  where 2nd arg should be executed as
     #                          connection is apparently down
     global Request Jobs MESS GPSOpResult
 
