@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 1998-2008 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: symbols.tcl
-#  Last change:  10 June 2005
+#  Last change:  10 February 2008
 #
 
 ## GPSMan symbols and display options
@@ -135,6 +135,8 @@ set SYMBOLS {
     cntct_sumo
     coast_guard
     controlled
+    cross
+    cross_3p
     crossing
     dam
     danger
@@ -331,7 +333,7 @@ set UNKNOWNSYMBOLS ""
 set SYDEFTMENU {=SYCATgeneral
     {WP_dot  danger skull  bell flag flag_pin_blue
         flag_pin_green  flag_pin_red traceback dollar
-	null null_2 ball dot  mark_x circle_x
+	null null_2 ball dot  cross cross_3p mark_x circle_x
 	diamond_blue diamond_green diamond_red
 	square_blue  square_green  square_red box_blue  box_green  box_red
 	pin_blue  pin_green  pin_red
@@ -1125,6 +1127,7 @@ proc LoadSymbolCustomMenu {} {
     # load user-defined symbol menu
     global UFile SYUSRMENU
 
+    # assumed to be in system encoding
     source $UFile(symenu)
     return
 }
