@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: util.tcl
-#  Last change:  18 February 2006
+#  Last change:  25 August 2008
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -708,6 +708,33 @@ proc MergeData {list ps vs} {
     return $list
 }
 
+proc MakeSplit {lls ixs} {
+    # split a list of lists into lists of lists according to the given
+    #  indices
+
+    set rs ""
+    set del 0
+    while 1 {
+	if { $ixs == "" } {
+	    lappend rs $lls
+	    break
+	}
+	set void 1
+	set ixn [expr [lindex $ixs 0]-$del] ; set ixs [lreplace $ixs 0 0]
+	incr del $ixn
+	set sl "" ; set rsl ""
+	foreach l $lls {
+	    lappend sl [lrange $l 0 [expr $ixn-1]]
+	    if { [set sll [lrange $l $ixn end]] != "" } { set void 0 }
+	    lappend rsl $sll
+	}
+	lappend rs $sl
+	if { $void } { break }
+	set lls $rsl
+    }
+    return $rs
+}
+
 proc Delete {l x} {
     # return list obtained from $l by deleting $x
 
@@ -861,6 +888,21 @@ proc MultSelect {w ix bxs} {
     return
 }
 
+proc MultExtSelect {bx bxs} {
+    # adjust extended selection in each listbox in $bxs that are siblings
+    #  of $bx
+
+    set s [$bx curselection]
+    set w [winfo parent $bx]
+    foreach l $bxs {
+	if { $l != $bx } {
+	    $w.$l selection clear 0 end
+	    foreach ix $s { $w.$l selection set $ix }
+	}
+    }
+    return
+}
+
 proc ScrollListIndex {box char} {
     # scroll listbox so that first element with initial >= $char is shown
     # this is case sensitive!
@@ -1168,7 +1210,7 @@ proc ResetCursor {ws} {
     return
 }
 
-### ISO characters; mainly from procs written by Lus Damas
+### ISO characters; mainly from procs written by Luis Damas
 
 proc TextBindings {w} {
     # set text bindings according to user options
